@@ -68,8 +68,11 @@ AAI::~AAI()
 	fprintf(file, "Unit production rate: %i\n\n", execute->unitProductionRate);
 
 	fprintf(file, "Requested constructors:\n");
-	for(list<int>::iterator fac = bt->units_of_category[STATIONARY_CONSTRUCTOR][side-1].begin(); fac != bt->units_of_category[STATIONARY_CONSTRUCTOR][side-1].end(); ++fac)
+	for(list<int>::iterator fac = bt->units_of_category[STATIONARY_CONSTRUCTOR][side-1].begin(); fac != bt->units_of_category[STATIONARY_CONSTRUCTOR][side-1].end(); ++fac) {
+		assert((*fac-1) < bt->numOfUnits);
+		assert((*fac)   < bt->units_dynamic.size());
 		fprintf(file, "%-24s: %i\n", bt->unitList[*fac-1]->humanName.c_str(), bt->units_dynamic[*fac].requested);
+	}
 	for(list<int>::iterator fac = bt->units_of_category[MOBILE_CONSTRUCTOR][side-1].begin(); fac != bt->units_of_category[MOBILE_CONSTRUCTOR][side-1].end(); ++fac)
 		fprintf(file, "%-24s: %i\n", bt->unitList[*fac-1]->humanName.c_str(), bt->units_dynamic[*fac].requested);
 
@@ -87,6 +90,7 @@ AAI::~AAI()
 	{
 		delete (*task);
 	}
+	build_tasks.clear();
 
 	// save mod learning data
 	bt->SaveBuildTable(brain->GetGamePeriod(), map->map_type);
@@ -99,18 +103,20 @@ AAI::~AAI()
 			(*group)->attack = 0;
 			delete (*group);
 		}
+		group_list[i].clear();
 	}
 
 
-	delete am; am = NULL;
-	delete brain; brain = NULL;
-	delete execute; execute = NULL;
-	delete ut; ut = NULL;
-	delete af; af = NULL;
-	delete map; map = NULL;
-	delete bt; bt = NULL;
-	delete profiler; profiler = NULL;
+	SafeDelete(am);
+	SafeDelete(brain);
+	SafeDelete(execute);
+	SafeDelete(ut);
+	SafeDelete(af);
+	SafeDelete(map);
+	SafeDelete(bt);
+	SafeDelete(profiler);
 
+	initialized = false;
 	fclose(file);
 }
 
@@ -383,7 +389,7 @@ void AAI::UnitFinished(int unit)
 					ut->units[(*task)->builder_id].cons->ConstructionFinished();
 
 				build_tasks.erase(task);
-				delete build_task;
+				SafeDelete(build_task);
 				break;
 			}
 		}
