@@ -13,7 +13,7 @@
 //#define SAFE_SPOT_DISTANCE_SLACK 700
 #define KMEANS_ENEMY_MAX_K 32
 #define KMEANS_BASE_MAX_K 32
-#define KMEANS_MINIMUM_LINE_LENGTH (8 * THREATRES)
+#define KMEANS_MINIMUM_LINE_LENGTH (THREATRES * SQUARE_SIZE)
 
 
 
@@ -46,8 +46,8 @@ CR_REG_METADATA(CAttackHandler, (
 CAttackHandler::CAttackHandler(AIClasses* aic): ai(aic) {
 	if (ai) {
 		// setting a position to the middle of the map
-		float mapWidth = ai->cb->GetMapWidth() * 8.0f;
-		float mapHeight = ai->cb->GetMapHeight() * 8.0f;
+		float mapWidth = ai->cb->GetMapWidth() * SQUARE_SIZE;
+		float mapHeight = ai->cb->GetMapHeight() * SQUARE_SIZE;
 		newGroupID = GROUND_GROUP_ID_START;
 
 		this->kMeansK = 1;
@@ -118,9 +118,9 @@ void CAttackHandler::UnitDestroyed(int unitID) {
 			// one of our (idle) attack units died but
 			// we somehow have lost track of it before
 			std::stringstream msg;
-				msg << "[CAttackHandler::UnitDestroyed()] frame " << (ai->cb->GetCurrentFrame()) << "\n";
+				msg << "[CAttackHandler::UnitDestroyed()][frame=" << ai->cb->GetCurrentFrame() << "]\n";
 				msg << "\tidle attack unit " << unitID << " was destroyed but already erased\n";
-			L(ai, msg.str());
+			ai->GetLogger()->Log(msg.str());
 		}
 	}
 
@@ -240,8 +240,6 @@ float3 CAttackHandler::FindSafeSpot(float3 myPos, float minSafety, float maxSafe
 		float3 pos = kMeansBase[startIndex] + float3((RANDINT % SAFE_SPOT_DISTANCE), 0, (RANDINT % SAFE_SPOT_DISTANCE));
 		pos.y = ai->cb->GetElevation(pos.x, pos.z);
 
-		// SNPRINTF(logMsg, logMsg_maxSize, "AH::FSA1 minS: %3.2f, maxS: %3.2f,", minSafety, maxSafety);
-		// PRINTF("%s", logMsg);
 		return pos;
 	}
 
@@ -276,7 +274,7 @@ float3 CAttackHandler::FindSafeSpot(float3 myPos, float minSafety, float maxSafe
 		//	if (size > (int)kMeansBase.size())
 		//		size = kMeansBase.size();
 
-		float dist = ai->pather->MakePath(posPath, subset[whichPath], subset[whichPath + 1], THREATRES * 8);
+		float dist = ai->pather->MakePath(posPath, subset[whichPath], subset[whichPath + 1], THREATRES * SQUARE_SIZE);
 		float3 res;
 
 		if (dist > 0) {
@@ -288,24 +286,10 @@ float3 CAttackHandler::FindSafeSpot(float3 myPos, float minSafety, float maxSafe
 			res = subset[whichPath];
 		}
 
-		/*
-		SNPRINTF(logMsg, logMsg_maxSize,
-				"AH::FSA-2 path:minS: %3.2f, maxS: %3.2f, pos:x: %f5.1 y: %f5.1 z: %f5.1",
-				minSafety, maxSafety, res.x, res.y, res.z);
-		PRINTF("%s", logMsg);
-		*/
 		return res;
-	}
-	else {
+	} else {
 		assert(whichPath < (int) subset.size());
-		float3 res = subset[whichPath];
-		/*
-		SNPRINTF(logMsg, logMsg_maxSize,
-				"AH::FSA-3 minS: %f, maxS: %f, pos:x: %f y: %f z: %f",
-				minSafety, maxSafety, res.x, res.y, res.z);
-		PRINTF("%s", logMsg);
-		*/
-		return res;
+		return (subset[whichPath]);
 	}
 }
 
@@ -327,13 +311,13 @@ float3 CAttackHandler::FindSafeArea(float3 pos) {
 float3 CAttackHandler::FindVerySafeArea(float3 pos) {
 	float min = 0.9f;
 	float max = 1.0f;
-	return (this->FindSafeSpot(pos, min, max));
+	return (FindSafeSpot(pos, min, max));
 }
 
 float3 CAttackHandler::FindUnsafeArea(float3 pos) {
 	float min = 0.1f;
 	float max = 0.3f;
-	return (this->FindSafeSpot(pos, min, max));
+	return (FindSafeSpot(pos, min, max));
 }
 
 
@@ -451,17 +435,22 @@ void CAttackHandler::UpdateKMeans(void) {
 		}
 
 		// hack to make it at least 1 unit, should only happen when you have no base
-		if (friendlyPositions.size() < 1) {
+		if (friendlyPositions.empty()) {
 			// it has to be a proper position, unless there are no proper positions
 			// in the latter case, use the position of the unit with ID 0 (?)
-			const CUNIT*   unit    = ai->GetUnit(ai->unitIDs[0]);
-			const UnitDef* unitDef = ai->cb->GetUnitDef(ai->unitIDs[0]);
+			// HOIJUI_NOTE - isn't it simply the first unit in the list?
+			const CUNIT*   unit    = NULL;
+			const UnitDef* unitDef = NULL;
+			if (ai->unitIDs[0] != -1) {
+				unit    = ai->GetUnit(ai->unitIDs[0]);
+				unitDef = ai->cb->GetUnitDef(ai->unitIDs[0]);
+			}
 
-			if (numFriendlies > 0 && unitDef != NULL && unit->owner() == 0) {
+			if (numFriendlies > 0 && unitDef != NULL && unit != NULL && unit->owner() == 0) {
 				friendlyPositions.push_back(unit->pos());
 			} else {
 				// when everything is dead
-				friendlyPositions.push_back(float3(RANDINT % (ai->cb->GetMapWidth() * 8), 1000, RANDINT % (ai->cb->GetMapHeight() * 8)));
+				friendlyPositions.push_back(float3(RANDINT % (ai->cb->GetMapWidth() * SQUARE_SIZE), 1000, RANDINT % (ai->cb->GetMapHeight() * SQUARE_SIZE)));
 			}
 		}
 
@@ -493,7 +482,7 @@ void CAttackHandler::UpdateKMeans(void) {
 		}
 		else {
 			// when everything is dead
-			enemyPositions.push_back(float3(RANDINT % (ai->cb->GetMapWidth() * 8), 1000, RANDINT % (ai->cb->GetMapHeight() * 8)));
+			enemyPositions.push_back(float3(RANDINT % (ai->cb->GetMapWidth() * SQUARE_SIZE), 1000, RANDINT % (ai->cb->GetMapHeight() * SQUARE_SIZE)));
 		}
 	}
 
@@ -506,7 +495,7 @@ void CAttackHandler::UpdateKMeans(void) {
 	// base k-means and enemy base k-means are updated
 	// approach: add up (max - distance) to enemies
 	std::vector<float> proximity(kMeansK, 0.0000001f);
-	const float mapDiagonal = sqrt(pow((float) ai->cb->GetMapHeight() * 8,2) + pow((float) ai->cb->GetMapWidth() * 8, 2) + 1.0f);
+	const float mapDiagonal = sqrt(pow((float) ai->cb->GetMapHeight() * SQUARE_SIZE, 2) + pow((float) ai->cb->GetMapWidth() * SQUARE_SIZE, 2) + 1.0f);
 
 	for (int f = 0; f < kMeansK; f++) {
 		for (int e = 0; e < kMeansEnemyK; e++) {
@@ -629,8 +618,8 @@ void CAttackHandler::AirPatrol(int currentFrame) {
 	}
 
 	for (std::list<int>::iterator it = armedAirUnits.begin(); it != armedAirUnits.end(); it++) {
-		CUNIT* u = ai->GetUnit(*it)
-;
+		CUNIT* u = ai->GetUnit(*it);
+
 		// do this first in case we are in the enemy base
 		u->Move(outerMeans[0] + float3(0, 50, 0));
 
@@ -845,14 +834,16 @@ void CAttackHandler::AssignTarget(CAttackGroup* group_in) {
 			ai->tm->GetThreatMapHeight()
 		);
 
+
 		// pick an enemy position and path to it
 		// KLOOTNOTE: should be more like KAI 0.23 by passing group DPS to FindBestPath()
-		ai->pather->FindBestPath(pathToTarget, groupPos, THREATRES * 8, enemyPositions);
+		ai->pather->FindBestPath(pathToTarget, groupPos, THREATRES * SQUARE_SIZE, enemyPositions);
+
+
 
 		if (pathToTarget.size() > 2) {
 			const int ATTACKED_AREA_RADIUS = 800;
-			int lastIndex = pathToTarget.size() - 1;
-			float3 endPos = pathToTarget[lastIndex];
+			const float3 endPos = pathToTarget[pathToTarget.size() - 1];
 
 			// get all enemies surrounding endpoint of found path
 			int enemiesInArea = ai->ccb->GetEnemyUnits(&ai->unitIDs[0], endPos, ATTACKED_AREA_RADIUS);
