@@ -104,15 +104,17 @@ void CBuildUp::GetEconState(EconState* es) const {
 	es->mOverflow = (es->mStorage / (es->mIncome + 0.01)) < (STORAGETIME * 2);
 
 	es->eLevelMed = (es->eLevel50 && es->makersOn);
-	es->mLevelLow =
-		es->mLevel50 ||
-		(es->mStall && es->eLevel80) ||
-		(!es->factFeasM && factoryTimer <= 0);
 
 	es->factFeasM =
 		(es->factoryDef != NULL)?
 		ai->math->MFeasibleConstruction(es->builderDef, es->factoryDef):
 		true;
+
+	es->mLevelLow =
+		es->mLevel50 ||
+		(es->mStall && es->eLevel80) ||
+		(!es->factFeasM && factoryTimer <= 0);
+
 	es->factFeasE =
 		(es->factoryDef != NULL)?
 		ai->math->EFeasibleConstruction(es->builderDef, es->factoryDef):
@@ -313,10 +315,10 @@ void CBuildUp::Buildup(int frame) {
 								BuildNow(econState.builderID, CAT_FACTORY, econState.factoryDef);
 							} else {
 								std::stringstream msg;
-									msg << "[CBuildUp::BuildUp()] frame " << frame << "\n";
+									msg << "[CBuildUp::BuildUp()][frame=" << frame << "]\n";
 									msg << "\tbuilder " << econState.builderID << " is currently in limbo";
 									msg << " (total number of idle builders: " << econState.nIdleBuilders << ")\n";
-								L(ai, msg.str());
+								ai->GetLogger()->Log(msg.str());
 							}
 						}
 					}
