@@ -2,9 +2,15 @@
 #define KAIK_LOGGER_HDR
 
 #include <string>
+//FIXME:compile hack for macosx
+#undef tm
 #include <fstream>
+#define tm GetThreatMap()
 
-class IAICallback;
+namespace springLegacyAI {
+	class IAICallback;
+} // namespace springLegacyAI
+using namespace springLegacyAI;
 
 enum LogLevel {
 	LOG_BASIC,
