@@ -5,7 +5,9 @@
 
 CSpringUnit::CSpringUnit(springai::OOAICallback* callback, springai::Unit* u, IGame* game)
 : callback(callback), unit(u), dead(false), game(game){
-	//
+	if(u == 0){
+		throw std::runtime_error("springai::unit must never be null when passed into the constructor of a CSpringUnit object! Bad bad coder");
+	}
 	
 }
 
