@@ -4,9 +4,9 @@
 
 
 extern "C" {
-	#include "lua/lua.h"
-	#include "lua/lualib.h"
-	#include "lua/lauxlib.h"
+	#include "lua.h"
+	#include "lualib.h"
+	#include "lauxlib.h"
 }
 #include "API/swig.h"
 
