@@ -103,11 +103,14 @@ local flexCallIns = {
   'GamePreload',
   'GameStart',
   'GameOver',
+  'GamePaused',
   'GameFrame',
   'GameSetup',
   'TeamDied',
   'TeamChanged',
   'PlayerChanged',
+  'PlayerAdded',
+  'PlayerRemoved',
   'ShockFront',
   'WorldTooltip',
   'MapDrawCmd',
@@ -145,7 +148,8 @@ local flexCallIns = {
   'DrawWorldReflection',
   'DrawWorldRefraction',
   'DrawScreenEffects',
-  'DrawInMiniMap'
+  'DrawInMiniMap',
+  'RecvSkirmishAIMessage',
 }
 local flexCallInMap = {}
 for _,ci in ipairs(flexCallIns) do
@@ -178,6 +182,7 @@ local callInLists = {
   'TweakMouseWheel',
   'TweakIsAbove',
   'TweakGetTooltip',
+  'RecvFromSynced',
 
 -- these use mouseOwner instead of lists
 --  'MouseMove',
@@ -233,7 +238,7 @@ function widgetHandler:LoadConfigData()
   if (chunk == nil) then
     return {}
   else
-    local tmp = {}
+    local tmp = {math = {huge = math.huge}}
     setfenv(chunk, tmp)
     self.orderList = chunk().order
     self.configData = chunk().data
@@ -478,6 +483,7 @@ function widgetHandler:NewWidget()
     for k,v in pairs(System) do
       widget[k] = v
     end
+    widget["SendToUnsynced"] = Spring.SendToUnsynced
   else
     -- use metatable redirection
     setmetatable(widget, {
@@ -522,6 +528,13 @@ function widgetHandler:NewWidget()
     return self.actionHandler:RemoveAction(widget, cmd, types)
   end
 
+  wh.AddSyncAction = function(_, cmd, func, help)
+    return self.actionHandler:AddSyncAction(widget, cmd, func, help)
+  end
+  wh.RemoveSyncAction = function(_, cmd)
+    return self.actionHandler:RemoveSyncAction(widget, cmd)
+  end
+
   wh.AddLayoutCommand = function (_, cmd)
     if (self.inCommandsChanged) then
       table.insert(self.customCommands, cmd)
@@ -546,6 +559,15 @@ function widgetHandler:NewWidget()
 end
 
 
+function widgetHandler:AddWidgetSyncAction(widget, cmd, func, help)
+  return self.actionHandler:AddSyncAction(widget, cmd, func, help)
+end
+
+function widgetHandler:RemoveWidgetSyncAction(widget, cmd)
+  return self.actionHandler:RemoveSyncAction(widget, cmd)
+end
+
+
 function widgetHandler:FinalizeWidget(widget, filename, basename)
   local wi = {}
 
@@ -746,6 +768,10 @@ function widgetHandler:RemoveWidget(widget)
     ArrayRemove(self[listname..'List'], widget)
   end
   self:UpdateCallIns()
+  
+  if (widget.whInfo.basename == SELECTOR_BASENAME) then 
+    Spring.SendCommands({"luaui update"})  
+  end
 end
 
 
@@ -761,7 +787,7 @@ function widgetHandler:UpdateCallIn(name)
   if ((#self[listName] > 0) or
       (not flexCallInMap[name]) or
       ((name == 'GotChatMsg')     and actionHandler.HaveChatAction()) or
-      ((name == 'RecvFromSynced') and actionHandler.HaveSyncAction())) then
+      ((name == 'RecvFromSynced'))) then
     -- always assign these call-ins
     local selffunc = self[name]
     _G[name] = function(...)
@@ -810,6 +836,14 @@ function widgetHandler:UpdateCallIns()
 end
 
 
+function widgetHandler:SelectorActive()
+  for _,w in ipairs(self.widgets) do
+    if (w.whInfo.basename == SELECTOR_BASENAME) then
+      return true
+    end
+  end
+  return false
+end
 --------------------------------------------------------------------------------
 
 function widgetHandler:EnableWidget(name)
@@ -829,6 +863,11 @@ function widgetHandler:EnableWidget(name)
     self:InsertWidget(w)
     self:SaveConfigData()
   end
+  
+  if (not self:SelectorActive()) then
+    Spring.SendCommands({"luaui update"})
+  end
+  
   return true
 end
 
@@ -847,6 +886,11 @@ function widgetHandler:DisableWidget(name)
     self.orderList[name] = 0 -- disable
     self:SaveConfigData()
   end
+  
+  if (not self:SelectorActive()) then
+    Spring.SendCommands({"luaui update"})
+  end
+  
   return true
 end
 
@@ -1072,10 +1116,8 @@ function widgetHandler:ConfigureLayout(command)
     self:SendConfigData()
     return true
   elseif (command == 'selector') then
-    for _,w in ipairs(self.widgets) do
-      if (w.whInfo.basename == SELECTOR_BASENAME) then
-        return true  -- there can only be one
-      end
+    if (self:SelectorActive()) then
+      return true  -- there can only be one
     end
     local sw = self:LoadWidget(LUAUI_DIRNAME .. SELECTOR_BASENAME)
     self:InsertWidget(sw)
@@ -1516,6 +1558,14 @@ function widgetHandler:GameOver()
 end
 
 
+function widgetHandler:GamePaused(playerID, paused)
+  for _,w in ipairs(self.GamePausedList) do
+    w:GamePaused(playerID, paused)
+  end
+  return
+end
+
+
 function widgetHandler:TeamDied(teamID)
   for _,w in ipairs(self.TeamDiedList) do
     w:TeamDied(teamID)
@@ -1540,6 +1590,22 @@ function widgetHandler:PlayerChanged(playerID)
 end
 
 
+function widgetHandler:PlayerAdded(playerID)
+  for _,w in ipairs(self.PlayerAddedList) do
+    w:PlayerAdded(playerID)
+  end
+  return
+end
+
+
+function widgetHandler:PlayerRemoved(playerID, reason)
+  for _,w in ipairs(self.PlayerRemovedList) do
+    w:PlayerRemoved(playerID, reason)
+  end
+  return
+end
+
+
 function widgetHandler:GameFrame(frameNum)
   for _,w in ipairs(self.GameFrameList) do
     w:GameFrame(frameNum)
@@ -1555,6 +1621,14 @@ function widgetHandler:ShockFront(power, dx, dy, dz)
   return
 end
 
+function widgetHandler:RecvSkirmishAIMessage(aiTeam, dataStr)
+  for _,w in ipairs(self.RecvSkirmishAIMessageList) do
+    local dataRet = w:RecvSkirmishAIMessage(aiTeam, dataStr)
+    if (dataRet) then
+      return dataRet
+    end
+  end
+end
 
 function widgetHandler:WorldTooltip(ttType, ...)
   for _,w in ipairs(self.WorldTooltipList) do
@@ -1818,6 +1892,20 @@ function widgetHandler:RecvLuaMsg(msg, playerID)
 end
 
 
+function widgetHandler:RecvFromSynced(...)
+  local retval = false
+  if (self.actionHandler:RecvFromSynced(...)) then
+    retval = true
+  end
+  for _,w in ipairs(self.RecvFromSyncedList) do
+    if (w:RecvFromSynced(...)) then
+      retval = true
+    end
+  end
+  return retval
+end
+
+
 function widgetHandler:StockpileChanged(unitID, unitDefID, unitTeam,
                                         weaponNum, oldCount, newCount)
   for _,w in ipairs(self.StockpileChangedList) do
