@@ -558,12 +558,13 @@ local function Wrap_AimWeapon(unitID, callins)
 	if (not AimWeapon) then return end
 
 	-- SetUnitShieldState wants true or false, while
-	-- SetUnitWeaponState wants 1 or 0, niiice =)
+	-- SetUnitWeaponState wants 1.0 or 0.0, niiice =)
 	local function AimWeaponThread(weaponNum, heading, pitch)
-		if AimWeapon(weaponNum, heading, pitch) then
-			-- SetUnitWeaponState counts weapons from 0
-			return sp_SetUnitWeaponState(unitID, weaponNum - 1, "aimReady", 1)
-		end
+		local bAimReady = AimWeapon(weaponNum, heading, pitch) or false
+		local fAimReady = (bAimReady and 1.0) or 0.0
+
+		-- SetUnitWeaponState counts weapons from 0
+		return sp_SetUnitWeaponState(unitID, weaponNum - 1, "aimReady", fAimReady)
 	end
 
 	callins["AimWeapon"] = function(weaponNum, heading, pitch)
