@@ -1179,8 +1179,7 @@ bool CAICallback::CanBuildAt(const UnitDef* unitDef, const float3& pos, int faci
 	CFeature* blockingF = NULL;
 	BuildInfo bi(unitDef, pos, facing);
 	bi.pos = helper->Pos2BuildPos(bi, false);
-	const int canBuildState = uh->TestUnitBuildSquare(bi, blockingF, teamHandler->AllyTeam(team), false);
-	return (canBuildState != 0);
+	return !!uh->TestUnitBuildSquare(bi, blockingF, teamHandler->AllyTeam(team), false);
 }
 
 
