@@ -46,7 +46,7 @@ static inline bool IsUnitInLosOrRadarOfAllyTeam(const CUnit& unit, const int all
 	//     (thus UnitCreated will not produce EnemyCreated,
 	//     etc. without this, even when globalLOS is enabled
 	//     (for non-cheating AI's))
-	return (gs->globalLOS || unit.losStatus[allyTeamId] & (LOS_INLOS | LOS_INRADAR));
+	return (gs->globalLOS[allyTeamId] || unit.losStatus[allyTeamId] & (LOS_INLOS | LOS_INRADAR));
 }
 
 /////////////////////////////
