@@ -1,7 +1,7 @@
 /* This file is part of the Spring engine (GPL v2 or later), see LICENSE.html */
 
-#ifndef _SKIRMISHAI_H
-#define _SKIRMISHAI_H
+#ifndef SKIRMISH_AI_H
+#define SKIRMISH_AI_H
 
 #include "SkirmishAIKey.h"
 
@@ -18,8 +18,7 @@ struct SSkirmishAICallback;
  */
 class CSkirmishAI {
 public:
-	CSkirmishAI(int teamId, int skirmishAIId,
-		const SkirmishAIKey& skirmishAIKey,
+	CSkirmishAI(int skirmishAIId, int teamId, const SkirmishAIKey& skirmishAIKey,
 		const SSkirmishAICallback* c_callback);
 	~CSkirmishAI();
 
@@ -28,6 +27,12 @@ public:
 	 */
 	int HandleEvent(int topic, const void* data) const;
 
+	/**
+	 * Initialize the AI instance.
+	 * This calls the native init() method, the InitAIEvent is sent afterwards.
+	 */
+	void Init();
+
 	/**
 	 * No events are forwarded to the Skirmish AI plugin
 	 * after this method has been called.
@@ -38,12 +43,13 @@ public:
 	void Dieing();
 
 private:
-	int teamId;
+	int skirmishAIId;
 	const SkirmishAIKey key;
 	const CSkirmishAILibrary* library;
+	const SSkirmishAICallback* callback;
 	const std::string timerName;
 	bool initOk;
 	bool dieing;
 };
 
-#endif // _SKIRMISHAI_H
+#endif // SKIRMISH_AI_H
