@@ -1,5 +1,7 @@
-#ifndef __OVERHEAD_CONTROLLER_H__
-#define __OVERHEAD_CONTROLLER_H__
+/* This file is part of the Spring engine (GPL v2 or later), see LICENSE.html */
+
+#ifndef _OVERHEAD_CONTROLLER_H
+#define _OVERHEAD_CONTROLLER_H
 
 #include "CameraController.h"
 
@@ -12,8 +14,8 @@ public:
 	const std::string GetName() const { return "ta"; }
 
 	void KeyMove(float3 move);
-	void MousePress(int, int, int) { /* empty */ }
-	void MouseRelease(int, int, int) { /* empty */ }
+	void MousePress(int x, int y, int button) { /* empty */ }
+	void MouseRelease(int x, int y, int button) { /* empty */ }
 	void MouseMove(float3 move);
 	void ScreenEdgeMove(float3 move);
 	void MouseWheelMove(float move);
@@ -31,6 +33,7 @@ public:
 	bool flipped;
 
 private:
+	float middleClickScrollSpeed;
 	float zscale;
 	float3 dir;
 	float height;
@@ -40,4 +43,4 @@ private:
 	float tiltSpeed;
 };
 
-#endif
+#endif // _OVERHEAD_CONTROLLER_H
