@@ -1,7 +1,7 @@
 /* This file is part of the Spring engine (GPL v2 or later), see LICENSE.html */
 
-#ifndef __OV_CONTROLLER_H__
-#define __OV_CONTROLLER_H__
+#ifndef _OV_CONTROLLER_H
+#define _OV_CONTROLLER_H
 
 #include "CameraController.h"
 
@@ -33,4 +33,4 @@ private:
 	bool minimizeMinimap;
 };
 
-#endif // __OV_CONTROLLER_H__
+#endif // _OV_CONTROLLER_H
