@@ -1,31 +1,30 @@
 /* This file is part of the Spring engine (GPL v2 or later), see LICENSE.html */
 
-#include "StdAfx.h"
-
+#include <boost/cstdint.hpp>
 #include <SDL_keysym.h>
 
-#include "mmgr.h"
-#include <boost/cstdint.hpp>
+#include "System/mmgr.h"
 
 #include "TWController.h"
-
-#include "ConfigHandler.h"
 #include "Game/Camera.h"
-#include "LogOutput.h"
 #include "Map/Ground.h"
 #include "Game/UI/MouseHandler.h"
-#include "GlobalUnsynced.h"
 #include "Rendering/GlobalRendering.h"
-#include "myMath.h"
+#include "System/Config/ConfigHandler.h"
+#include "System/Log/ILog.h"
+#include "System/myMath.h"
+#include "System/Input/KeyInput.h"
 
-extern boost::uint8_t *keys;
+CONFIG(int, TWScrollSpeed).defaultValue(10);
+CONFIG(bool, TWEnabled).defaultValue(true);
+CONFIG(float, TWFOV).defaultValue(45.0f);
 
 
 CTWController::CTWController()
 {
-	scrollSpeed = configHandler->Get("TWScrollSpeed",10) * 0.1f;
-	enabled = !!configHandler->Get("TWEnabled",1);
-	fov = configHandler->Get("TWFOV", 45.0f);
+	scrollSpeed = configHandler->GetInt("TWScrollSpeed") * 0.1f;
+	enabled = configHandler->GetBool("TWEnabled");
+	fov = configHandler->GetFloat("TWFOV");
 }
 
 
@@ -42,9 +41,7 @@ void CTWController::KeyMove(float3 move)
 
 void CTWController::MouseMove(float3 move)
 {
-	float dist = -camera->rot.x * 1500;
-	float pixelsize = camera->GetTanHalfFov() * 2/globalRendering->viewSizeY * dist * 2;
-	move *= (1+keys[SDLK_LSHIFT]*3) * pixelsize;
+	move *= (1 + keyInput->GetKeyState(SDLK_LSHIFT) * 3) * pixelSize;
 
 	float3 flatForward = camera->forward;
 	flatForward.y = 0;
@@ -71,13 +68,14 @@ void CTWController::MouseWheelMove(float move)
 
 void CTWController::Update()
 {
+	pixelSize = (camera->GetTanHalfFov() * 2.0f) / globalRendering->viewSizeY * (-camera->rot.x * 1500) * 2.0f;
 }
 
 float3 CTWController::GetPos()
 {
 	pos.x = Clamp(pos.x, 0.01f, gs->mapx*SQUARE_SIZE-0.01f);
 	pos.z = Clamp(pos.z, 0.01f, gs->mapy*SQUARE_SIZE-0.01f);
-	pos.y = ground->GetHeight(pos.x,pos.z);
+	pos.y = ground->GetHeightAboveWater(pos.x, pos.z, false);
 
 	camera->rot.x = Clamp(camera->rot.x, -PI*0.4f, -0.1f);
 
@@ -90,8 +88,8 @@ float3 CTWController::GetPos()
 	float dist = -camera->rot.x * 1500;
 
 	float3 cpos = pos - dir * dist;
-	if(cpos.y < ground->GetHeight(cpos.x,cpos.z) + 5)
-		cpos.y = ground->GetHeight(cpos.x,cpos.z) + 5;
+	if (cpos.y < ground->GetHeightAboveWater(cpos.x, cpos.z, false) + 5)
+		cpos.y = ground->GetHeightAboveWater(cpos.x, cpos.z, false) + 5;
 
 	return cpos;
 }
@@ -117,7 +115,7 @@ float3 CTWController::SwitchFrom() const
 void CTWController::SwitchTo(bool showText)
 {
 	if (showText) {
-		logOutput.Print("Switching to Total War style camera");
+		LOG("Switching to Total War style camera");
 	}
 }
 
