@@ -139,6 +139,7 @@
 #include "System/Exceptions.h"
 #include "System/Sync/FPUCheck.h"
 #include "System/GlobalConfig.h"
+#include "System/myMath.h"
 #include "System/NetProtocol.h"
 #include "System/SpringApp.h"
 #include "System/Util.h"
@@ -175,7 +176,7 @@ CONFIG(bool, ShowFPS).defaultValue(false);
 CONFIG(bool, ShowClock).defaultValue(true);
 CONFIG(bool, ShowSpeed).defaultValue(false);
 CONFIG(bool, ShowMTInfo).defaultValue(true);
-CONFIG(float, MTInfoThreshold).defaultValue(0.25f);
+CONFIG(float, MTInfoThreshold).defaultValue(1.0f);
 CONFIG(int, ShowPlayerInfo).defaultValue(1);
 CONFIG(float, GuiOpacity).defaultValue(0.8f);
 CONFIG(std::string, InputTextGeo).defaultValue("");
@@ -228,7 +229,7 @@ CR_REG_METADATA(CGame,(
 	CR_MEMBER(playing),
 //	CR_MEMBER(lastFrameTime),
 //	CR_MEMBER(leastQue),
-//	CR_MEMBER(timeLeft),
+//	CR_MEMBER(msgProcTimeLeft),
 //	CR_MEMBER(consumeSpeed),
 //	CR_MEMBER(lastframe),
 //	CR_MEMBER(leastQue),
@@ -259,7 +260,7 @@ CGame::CGame(const std::string& mapName, const std::string& modName, ILoadSaveHa
 	, playing(false)
 	, chatting(false)
 	, leastQue(0)
-	, timeLeft(0.0f)
+	, msgProcTimeLeft(0.0f)
 	, consumeSpeed(1.0f)
 	, lastframe(spring_gettime())
 	, skipStartFrame(0)
@@ -804,6 +805,13 @@ int CGame::KeyPressed(unsigned short key, bool isRepeat)
 		}
 	}
 
+	// maybe a widget is interested?
+	if (guihandler != NULL) {
+		for (unsigned int i = 0; i < actionList.size(); ++i) {
+			guihandler->PushLayoutCommand(actionList[i].rawline, false);
+		}
+	}
+
 	return 0;
 }
 
@@ -854,7 +862,7 @@ bool CGame::Update()
 		if (!gameServer) {
 			consumeSpeed = GAME_SPEED * gs->speedFactor + leastQue - 2;
 			leastQue = 10000;
-			timeLeft = 0.0f;
+			msgProcTimeLeft = 0.0f;
 		}
 	}
 
@@ -910,6 +918,18 @@ bool CGame::UpdateUnsynced()
 	}
 	updateDeltaSeconds = dif;
 
+	// Update simFPS
+	{
+		static int lsf = gs->frameNum;
+		static spring_time lsft = currentTime;
+		const float diffsecs_ = spring_diffsecs(currentTime, lsft);
+		if (diffsecs_ >= 1.0f) {
+			gu->simFPS = (gs->frameNum - lsf) / diffsecs_;
+			lsft = currentTime;
+			lsf = gs->frameNum;
+		}
+	}
+
 	// FastForwarding
 	if (skipping) {
 		const float diff = spring_tomsecs(currentTime - skipLastDraw);
@@ -1013,6 +1033,8 @@ bool CGame::UpdateUnsynced()
 
 			// TODO call only when camera changed
 			sound->UpdateListener(camera->pos, camera->forward, camera->up, deltaSec);
+
+			profiler.Update();
 		}
 	}
 
@@ -1274,6 +1296,8 @@ bool CGame::Draw() {
 
 	CTeamHighlight::Disable();
 
+	gu->avgDrawFrameTime = mix(gu->avgDrawFrameTime, float(spring_tomsecs(spring_gettime() - currentTime)), 0.1f);
+
 	return true;
 }
 
@@ -1448,7 +1472,6 @@ void CGame::SimFrame() {
 		for (size_t a = 0; a < grouphandlers.size(); a++) {
 			grouphandlers[a]->Update();
 		}
-		profiler.Update();
 
 		(playerHandler->Player(gu->myPlayerNum)->fpsController).SendStateUpdate(camMove);
 
@@ -1479,6 +1502,8 @@ void CGame::SimFrame() {
 
 	DumpState(-1, -1, 1);
 
+	gu->avgSimFrameTime = mix(gu->avgSimFrameTime, float(spring_tomsecs(spring_gettime() - lastFrameTime)), 0.1f);
+
 	LEAVE_SYNCED_CODE();
 }
 
@@ -2277,6 +2302,20 @@ void CGame::ReloadGame()
 }
 
 
+bool CGame::ProcessAction(const Action& action, unsigned int key, bool isRepeat)
+{
+	if (ActionPressed(key, action, isRepeat)) {
+		return true;
+	}
+
+	// maybe a widget is interested?
+	if (guihandler != NULL) {
+		guihandler->PushLayoutCommand(action.rawline, false); //FIXME add return argument!
+	}
+
+	return false;
+}
+
 
 void CGame::ActionReceived(const Action& action, int playerID)
 {
@@ -2299,8 +2338,9 @@ bool CGame::ActionPressed(unsigned int key, const Action& action, bool isRepeat)
 	if (executor != NULL) {
 		// an executor for that action was found
 		UnsyncedAction unsyncedAction(action, key, isRepeat);
-		executor->ExecuteAction(unsyncedAction);
-		return true; // XXX catch exceptions thrown in ExecuteAction to deside what to return here?
+		if (executor->ExecuteAction(unsyncedAction)) {
+			return true;
+		}
 	}
 
 	static std::set<std::string> serverCommands = std::set<std::string>(commands, commands+numCommands);
@@ -2314,8 +2354,5 @@ bool CGame::ActionPressed(unsigned int key, const Action& action, bool isRepeat)
 		return true;
 	}
 
-	if (guihandler != NULL) // maybe a widget is interested?
-		guihandler->PushLayoutCommand(action.rawline, false);
-
 	return false;
 }
