@@ -106,7 +106,7 @@ std::string GetAdditional()
 	#define GV_ADD_SPACE " "
 #endif
 
-#if defined HEADLESS
+#if defined HEADLESS && !defined DEDICATED
 	GV_ADD_SPACE "Headless"
 	#undef  GV_ADD_SPACE
 	#define GV_ADD_SPACE " "
@@ -176,7 +176,8 @@ const std::string& GetBuildEnvironment()
 
 bool IsRelease()
 {
-	return (GetBranch() == "master");
+	static const bool release = SPRING_VERSION_ENGINE_RELEASE;
+	return release;
 }
 
 const std::string& Get()
