@@ -58,16 +58,17 @@ void CGame::ClientReadNet()
 
 	boost::shared_ptr<const netcode::RawPacket> packet;
 
-	// compute new timeLeft to "smooth" out SimFrame() calls
+	// compute new msgProcTimeLeft to "smooth" out SimFrame() calls
 	if (!gameServer) {
 		const spring_time currentFrame = spring_gettime();
 
 		if (skipping) {
-			timeLeft = 0.01f;
+			msgProcTimeLeft = 0.01f;
 		} else {
-			if (timeLeft > 1.0f)
-				timeLeft -= 1.0f;
-			timeLeft += consumeSpeed * (spring_tomsecs(currentFrame - lastframe) / 1000.0f);
+			if (msgProcTimeLeft > 1.0f)
+				msgProcTimeLeft -= 1.0f;
+
+			msgProcTimeLeft += consumeSpeed * (spring_tomsecs(currentFrame - lastframe) / 1000.0f);
 		}
 
 		lastframe = currentFrame;
@@ -97,19 +98,40 @@ void CGame::ClientReadNet()
 
 		if (que < leastQue)
 			leastQue = que;
-	}
-	else
-	{
+	} else {
 		// make sure ClientReadNet returns at least every 15 game frames
 		// so CGame can process keyboard input, and render etc.
-		timeLeft = GAME_SPEED/float(gu->minFPS) * gs->userSpeedFactor;
+		msgProcTimeLeft = GAME_SPEED / float(gu->minFPS) * gs->userSpeedFactor;
 	}
 
+	const spring_time msgProcStartTime = spring_gettime();
+
+	// balance the time spent in simulation & drawing (esp. when reconnecting)
 	// always render at least 2FPS (will otherwise be highly unresponsive when catching up after a reconnection)
-	const spring_time procstarttime = spring_gettime();
+	// else use the following algo: i.e. with gu->reconnectSimDrawBalance = 0.2f
+	//  -> try to spend minimum 20% of the time in drawing
+	//  -> use remaining 80% for reconnecting
+	// (maxSimFPS / minDrawFPS) is desired number of simframes per drawframe
+	const float maxSimFPS    = (1.0f - gu->reconnectSimDrawBalance) * 1000.0f / std::max(0.01f, gu->avgSimFrameTime);
+	const float minDrawFPS   =         gu->reconnectSimDrawBalance  * 1000.0f / std::max(0.01f, gu->avgDrawFrameTime);
+	const float simDrawRatio = maxSimFPS / minDrawFPS;
+	const float msgProcTimeLimit = Clamp(simDrawRatio * gu->avgSimFrameTime, 5.0f, 1000.0f / gu->minFPS);
+
 	// really process the messages
-	while (timeLeft > 0.0f && spring_tomsecs(spring_gettime() - procstarttime) < 500 && (packet = net->GetData(gs->frameNum)))
-	{
+	while (true) {
+		const float msgProcTimeSpent = spring_tomsecs(spring_gettime() - msgProcStartTime);
+		const bool allowMsgProcessing =
+			(msgProcTimeLeft  >              0.0f) && // smooths simframes across the full second
+			(msgProcTimeSpent <= msgProcTimeLimit);   // balance the time spent in sim & drawing
+
+		if (!allowMsgProcessing)
+			break;
+
+		// get netpacket from the queue
+		packet = net->GetData(gs->frameNum);
+		if (!packet)
+			break;
+
 		const unsigned char* inbuf = packet->data;
 		const unsigned dataLength = packet->length;
 		const unsigned char packetCode = inbuf[0];
@@ -350,7 +372,7 @@ void CGame::ClientReadNet()
 					if (playerCheckSum != localCheckSum) {
 						LOG_L(L_WARNING, // XXX maybe use a "Desync" section here?
 								"[DESYNC WARNING] path-checksum %08x for player %d (%s)"
-								"does not match local checksum %08x; stale PathEstimator-cache?",
+								" does not match local checksum %08x; stale PathEstimator-cache?",
 								playerCheckSum, playerNum, player->name.c_str(), localCheckSum);
 					}
 				}
@@ -366,7 +388,7 @@ void CGame::ClientReadNet()
 				// Fall-through
 			}
 			case NETMSG_NEWFRAME: {
-				timeLeft -= 1.0f;
+				msgProcTimeLeft -= 1.0f;
 				SimFrame();
 				// both NETMSG_SYNCRESPONSE and NETMSG_NEWFRAME are used for ping calculation by server
 #ifdef SYNCCHECK
