@@ -1,7 +1,7 @@
 /* This file is part of the Spring engine (GPL v2 or later), see LICENSE.html */
 
-#ifndef __PLAYER_BASE_H
-#define __PLAYER_BASE_H
+#ifndef PLAYER_BASE_H
+#define PLAYER_BASE_H
 
 #include "Game/TeamController.h"
 
@@ -20,6 +20,20 @@ public:
 	 * @brief Constructor assigning standard values
 	 */
 	PlayerBase();
+	
+	void SetValue(const std::string& key, const std::string& value);
+	const customOpts& GetAllValues() const {
+		return customValues;
+	}
+
+	const char* GetType(const bool capital = true) const {
+
+		if (capital) {
+			return spectator ? "Spectator" : "Player";
+		}
+		return spectator ? "spectator" : "player";
+	}
+
 
 	int rank;
 	std::string countryCode;
@@ -28,20 +42,9 @@ public:
 	bool readyToStart;
 	bool desynced;
 	float cpuUsage;
-	
-	void SetValue(const std::string& key, const std::string& value);
-	const customOpts& GetAllValues() const {
-		return customValues;
-	}
-
-	const char *GetType(const bool capital = true) const {
-		if(capital)
-			return spectator ? "Spectator" : "Player";
-		return spectator ? "spectator" : "player";
-	}
 
 private:
 	customOpts customValues;
 };
 
-#endif // __PLAYER_BASE_H
+#endif // PLAYER_BASE_H
