@@ -1,19 +1,15 @@
 /* This file is part of the Spring engine (GPL v2 or later), see LICENSE.html */
 
-/* based on code from GlobalSynced.{cpp,h} */
+#ifndef PLAYER_HANDLER_H
+#define PLAYER_HANDLER_H
 
-#ifndef PLAYERHANDLER_H
-#define PLAYERHANDLER_H
+#include "System/creg/creg_cond.h"
 
-#include <assert.h>
+#include <cassert>
 #include <vector>
 
-#include "creg/creg_cond.h"
-#include "Player.h"
-
-#define PATHING_FLAG 0xFFFFFFFF
-
 class CGameSetup;
+class CPlayer;
 
 
 class CPlayerHandler
@@ -28,12 +24,12 @@ public:
 
 	/**
 	 * @brief Player
-	 * @param i index to fetch
+	 * @param id index to fetch
 	 * @return CPlayer pointer
 	 *
 	 * Accesses a CPlayer instance at a given index
 	 */
-	CPlayer* Player(int i) { assert(unsigned(i) < players.size()); return players[i]; }
+	CPlayer* Player(int id) { assert(unsigned(id) < players.size()); return players[id]; }
 
 	/**
 	 * @brief Player
@@ -44,14 +40,14 @@ public:
 	 */
 	int Player(const std::string& name) const;
 
-	void PlayerLeft(int playernum, unsigned char reason);
+	void PlayerLeft(int id, unsigned char reason);
 
 	/**
 	 * @brief Number of players the game was created for
 	 * 
-	 * Will change during at runtime when a new spectator joins
+	 * Will change at runtime, for example if a new spectator joins
 	 */
-	int ActivePlayers() const { return players.size(); };
+	int ActivePlayers() const { return players.size(); }
 
 	/**
 	 * @brief Number of players in a team
@@ -61,6 +57,15 @@ public:
 	 */
 	std::vector<int> ActivePlayersInTeam(int teamId) const;
 
+	/**
+	 * @brief is the supplied id a valid playerId?
+	 * 
+	 * Will change during at runtime when a new spectator joins
+	 */
+	bool IsValidPlayer(int id) const {
+		return ((id >= 0) && (id < ActivePlayers()));
+	}
+
 	void GameFrame(int frameNum);
 
 	/**
@@ -68,10 +73,10 @@ public:
 	 *
 	 * This resizes the playerlist adding stubs if there's gaps to his playerNum
 	 */
-	void AddPlayer( const CPlayer& player );
+	void AddPlayer(const CPlayer& player);
 
 private:
-	typedef std::vector<CPlayer *> playerVec;
+	typedef std::vector<CPlayer*> playerVec;
 	/**
 	 * @brief players
 	 *
@@ -82,4 +87,4 @@ private:
 
 extern CPlayerHandler* playerHandler;
 
-#endif // !PLAYERHANDLER_H
+#endif // !PLAYER_HANDLER_H
