@@ -51,23 +51,26 @@ CSelectedUnitsAI::CSelectedUnitsAI()
 inline void CSelectedUnitsAI::AddUnitSetMaxSpeedCommand(CUnit* unit,
                                                         unsigned char options)
 {
-	// sets the wanted speed of this unit to its max speed
+	// sets the wanted speed of this unit (via the
+	// CommandAI --> MoveType chain) to its maximum
+	// theoretical speed
 	CCommandAI* cai = unit->commandAI;
+
 	if (cai->CanSetMaxSpeed()) {
 		Command c(CMD_SET_WANTED_MAX_SPEED, options);
-		c.AddParam(unit->moveType->GetMaxSpeed());
+		c.AddParam(unit->moveType->GetMaxSpeedDef());
 		cai->GiveCommand(c, false);
 	}
 }
 
-
 inline void CSelectedUnitsAI::AddGroupSetMaxSpeedCommand(CUnit* unit,
                                                          unsigned char options)
 {
-	// sets the wanted speed of this unit to the group minimum
-	// (note: was being divided by GAME_SPEED, but minMaxSpeed
-	// is already in units per frame)
+	// sets the wanted speed of this unit to that of
+	// the group's current-slowest member (minMaxSpeed
+	// is derived from GetMaxSpeed, not GetMaxSpeedDef)
 	CCommandAI* cai = unit->commandAI;
+
 	if (cai->CanSetMaxSpeed()) {
 		Command c(CMD_SET_WANTED_MAX_SPEED, options);
 		c.AddParam(minMaxSpeed);
