@@ -141,7 +141,7 @@ float TraceRay(const float3& start, const float3& dir, float length, int collisi
 
 		qf->GetQuadsOnRay(start, dir, length, begQuad, endQuad);
 
-		//! feature intersection
+		// feature intersection
 		if (!ignoreFeatures) {
 			for (int* quadPtr = begQuad; quadPtr != endQuad; ++quadPtr) {
 				const CQuadField::Quad& quad = qf->GetQuad(*quadPtr);
@@ -149,16 +149,17 @@ float TraceRay(const float3& start, const float3& dir, float length, int collisi
 				for (std::list<CFeature*>::const_iterator ui = quad.features.begin(); ui != quad.features.end(); ++ui) {
 					CFeature* f = *ui;
 
-					if (!f->blocking || f->collisionVolume == NULL) {
-						//! NOTE: why check the blocking property?
+					// NOTE:
+					//     if f is non-blocking, ProjectileHandler will not test
+					//     for collisions with projectiles so we can skip it here
+					if (!f->blocking || f->collisionVolume == NULL)
 						continue;
-					}
 
-					if (CCollisionHandler::Intersect(f, start, start + dir * length, &cq)) {
+					if (CCollisionHandler::DetectHit(f, start, start + dir * length, &cq, true)) {
 						const float3& intPos = (cq.b0)? cq.p0: cq.p1;
-						const float len = (intPos - start).dot(dir); //! same as (intPos - start).Length()
+						const float len = (intPos - start).dot(dir); // same as (intPos - start).Length()
 
-						//! we want the closest feature (intersection point) on the ray
+						// we want the closest feature (intersection point) on the ray
 						if (len < length) {
 							length = len;
 							hitFeature = f;
@@ -168,7 +169,7 @@ float TraceRay(const float3& start, const float3& dir, float length, int collisi
 			}
 		}
 
-		//! unit intersection
+		// unit intersection
 		if (!ignoreUnits) {
 			for (int* quadPtr = begQuad; quadPtr != endQuad; ++quadPtr) {
 				const CQuadField::Quad& quad = qf->GetQuad(*quadPtr);
@@ -185,11 +186,11 @@ float TraceRay(const float3& start, const float3& dir, float length, int collisi
 					if (ignoreEnemies && u->allyteam != owner->allyteam)
 						continue;
 
-					if (CCollisionHandler::Intersect(u, start, start + dir * length, &cq)) {
+					if (CCollisionHandler::DetectHit(u, start, start + dir * length, &cq, true)) {
 						const float3& intPos = (cq.b0)? cq.p0: cq.p1;
-						const float len = (intPos - start).dot(dir); //! same as (intPos - start).Length()
+						const float len = (intPos - start).dot(dir); // same as (intPos - start).Length()
 
-						//! we want the closest unit (intersection point) on the ray
+						// we want the closest unit (intersection point) on the ray
 						if (len < length) {
 							length = len;
 							hitUnit = u;
@@ -203,8 +204,8 @@ float TraceRay(const float3& start, const float3& dir, float length, int collisi
 	}
 
 	if (!ignoreGround) {
-		//! ground intersection
-		float groundLength = ground->LineGroundCol(start, start + dir * length);
+		// ground intersection
+		const float groundLength = ground->LineGroundCol(start, start + dir * length);
 		if (length > groundLength && groundLength > 0) {
 			length = groundLength;
 			hitUnit = NULL;
@@ -225,11 +226,14 @@ float GuiTraceRay(const float3 &start, const float3 &dir, float length, bool use
 		return -1.0f;
 	}
 
+	float origlength = length;
+	float length2 = length;
+
 	bool hover_factory = false;
 	CollisionQuery cq;
 
 	{
-		GML_RECMUTEX_LOCK(quad); //! GuiTraceRay
+		GML_RECMUTEX_LOCK(quad); // GuiTraceRay
 
 		int* begQuad = NULL;
 		int* endQuad = NULL;
@@ -242,7 +246,7 @@ float GuiTraceRay(const float3 &start, const float3 &dir, float length, bool use
 		for (int* quadPtr = begQuad; quadPtr != endQuad; ++quadPtr) {
 			const CQuadField::Quad& quad = qf->GetQuad(*quadPtr);
 
-			//! Unit Intersection
+			// Unit Intersection
 			for (ui = quad.units.begin(); ui != quad.units.end(); ++ui) {
 				CUnit* unit = *ui;
 				if (unit == exclude) {
@@ -257,36 +261,34 @@ float GuiTraceRay(const float3 &start, const float3 &dir, float length, bool use
 					CollisionVolume cv(unit->collisionVolume);
 
 					if (unit->isIcon) {
-						//! for iconified units, just pretend the collision
-						//! volume is a sphere of radius <unit->IconRadius>
+						// for iconified units, just pretend the collision
+						// volume is a sphere of radius <unit->IconRadius>
 						cv.Init(unit->iconRadius);
 					}
 
-					if (CCollisionHandler::MouseHit(unit, start, start + dir * length, &cv, &cq)) {
-						//! get the distance to the ray-volume ingress point
-						const float3& intPos = (cq.b0)? cq.p0 : cq.p1;
-						const float len = (intPos - start).dot(dir); //! same as (intPos - start).Length()
+					if (CCollisionHandler::MouseHit(unit, start, start + dir * origlength, &cv, &cq)) {
+						// get the distance to the ray-volume ingress point
+						const float3& intPos = (cq.b0) ? cq.p0 : cq.p1;
+						const float len = (intPos - start).dot(dir); // same as (intPos - start).Length()
 						const bool isfactory = dynamic_cast<CFactory*>(unit);
+						const float3& intPos2 = (cq.b1) ? cq.p1 : cq.p0;
+						const float len2 = (intPos2 - start).dot(dir); // same as (intPos2 - start).Length()
 
-						if (len < length) {
-							if (!isfactory || !hitUnit || hover_factory) {
+						// give units in a factory a higher priority than the factory itself
+						if (!hitUnit ||
+							(isfactory && ((hover_factory && len < length) || (!hover_factory && len2 < length))) ||
+							(!isfactory && ((hover_factory && len < length2) || (!hover_factory && len < length)))) {
 								hover_factory = isfactory;
 								length = len;
+								length2 = len2;
 								hitUnit = unit;
 								hitFeature = NULL;
-							}
-						} else if (!isfactory && hover_factory) { // FIXME still check if the unit is BEHIND (and not IN) the factory!
-							//! give an unit in a factory a higher priority than the factory itself
-							hover_factory = isfactory;
-							length = len;
-							hitUnit = unit;
-							hitFeature = NULL;
 						}
 					}
 				}
 			}
 
-			//! Feature Intersection
+			// Feature Intersection
 			// NOTE: switch this to custom volumes fully?
 			// (not used for any LOF checks, maybe wasteful)
 			for (fi = quad.features.begin(); fi != quad.features.end(); ++fi) {
@@ -303,18 +305,14 @@ float GuiTraceRay(const float3 &start, const float3 &dir, float length, bool use
 					continue;
 				}
 
-				if (CCollisionHandler::Intersect(f, start, start + dir * length, &cq)) {
+				if (CCollisionHandler::DetectHit(f, start, start + dir * origlength, &cq, true)) {
 					const float3& intPos = (cq.b0)? cq.p0 : cq.p1;
-					const float len = (intPos - start).dot(dir); //! same as (intPos - start).Length()
+					const float len = (intPos - start).dot(dir); // same as (intPos - start).Length()
 
-					//! we want the closest feature (intersection point) on the ray
-					if (len < length) {
-						hover_factory = false;
-						length = len;
-						hitFeature = f;
-						hitUnit = NULL;
-					} else if (hover_factory) { // FIXME still check if the unit is BEHIND (and not IN) the factory!
-						//! give features in a factory a higher priority than the factory itself
+					// we want the closest feature (intersection point) on the ray
+					// give features in a factory (?) a higher priority than the factory itself
+					if (!hitUnit ||
+						((hover_factory && len < length2) || (!hover_factory && len < length))) {
 						hover_factory = false;
 						length = len;
 						hitFeature = f;
@@ -325,8 +323,8 @@ float GuiTraceRay(const float3 &start, const float3 &dir, float length, bool use
 		}
 	}
 
-	//! ground intersection
-	float groundLen = ground->LineGroundCol(start, start + dir * length, false);
+	// ground intersection
+	float groundLen = ground->LineGroundCol(start, start + dir * origlength, false);
 	if (groundLen > 0.0f) {
 		if ((groundLen + 200.0f) < length) {
 			length     = groundLen;
@@ -344,7 +342,7 @@ float GuiTraceRay(const float3 &start, const float3 &dir, float length, bool use
 // called by CWeapon::TryTarget()
 bool LineFeatureCol(const float3& start, const float3& dir, float length)
 {
-	GML_RECMUTEX_LOCK(quad); // GuiTraceRayFeature
+	GML_RECMUTEX_LOCK(quad); // LineFeatureCol
 
 	int* begQuad = NULL;
 	int* endQuad = NULL;
@@ -358,15 +356,12 @@ bool LineFeatureCol(const float3& start, const float3& dir, float length)
 		const CQuadField::Quad& quad = qf->GetQuad(*quadPtr);
 
 		for (std::list<CFeature*>::const_iterator ui = quad.features.begin(); ui != quad.features.end(); ++ui) {
-			CFeature* f = *ui;
-			CollisionVolume* cv = f->collisionVolume;
+			const CFeature* f = *ui;
 
-			if (!f->blocking || cv == NULL) {
-				// NOTE: why check the blocking property?
+			if (!f->blocking || f->collisionVolume == NULL)
 				continue;
-			}
 
-			if (CCollisionHandler::Intersect(f, start, start + dir * length, &cq)) {
+			if (CCollisionHandler::DetectHit(f, start, start + dir * length, &cq, true)) {
 				return true;
 			}
 		}
@@ -388,6 +383,8 @@ bool TestCone(
 	bool testFeatures,
 	CUnit* owner)
 {
+	GML_RECMUTEX_LOCK(quad); // TestCone
+
 	int* begQuad = NULL;
 	int* endQuad = NULL;
 
@@ -438,6 +435,9 @@ bool TestCone(
 
 				if (f->collisionVolume == NULL)
 					continue;
+				if (!f->blocking)
+					continue;
+
 				if (TestConeHelper(from, dir, length, spread, f))
 					return true;
 			}
@@ -463,6 +463,8 @@ bool TestTrajectoryCone(
 	bool testFeatures,
 	CUnit* owner)
 {
+	GML_RECMUTEX_LOCK(quad); // TestTrajectoryCone
+
 	int* begQuad = NULL;
 	int* endQuad = NULL;
 
@@ -516,6 +518,9 @@ bool TestTrajectoryCone(
 
 				if (f->collisionVolume == NULL)
 					continue;
+				if (!f->blocking)
+					continue;
+
 				if (TestTrajectoryConeHelper(from, dir, length, linear, quadratic, spread, baseSize, f))
 					return true;
 			}
