@@ -1,7 +1,7 @@
 /* This file is part of the Spring engine (GPL v2 or later), see LICENSE.html */
 
-#ifndef __END_GAME_BOX_H__
-#define __END_GAME_BOX_H__
+#ifndef _END_GAME_BOX_H_
+#define _END_GAME_BOX_H_
 
 #include "InputReceiver.h"
 #include "Rendering/GL/myGL.h"
@@ -21,7 +21,7 @@ namespace std {
 class CEndGameBox : public CInputReceiver
 {
 public:
-	CEndGameBox();
+	CEndGameBox(const std::vector<unsigned char>& winningAllyTeams);
 	~CEndGameBox();
 
 	virtual bool MousePress(int x, int y, int button);
@@ -31,7 +31,7 @@ public:
 	virtual bool IsAbove(int x, int y);
 	virtual std::string GetTooltip(int x, int y);
 
-	static bool disabled;
+	static bool enabled;
 
 protected:
 	void FillTeamStats();
@@ -73,9 +73,11 @@ protected:
 		std::vector< std::vector<float> > values;
 	};
 
+	std::vector<unsigned char> winners;
+
 	std::vector<Stat> stats;
 	GLuint graphTex;
 	CBitmap bm;
 };
 
-#endif // __END_GAME_BOX_H__
+#endif // _END_GAME_BOX_H_
