@@ -35,12 +35,10 @@ class CKeyBindings : public CommandReceiver
 		const HotkeyList& GetHotkeys(const std::string& action) const;
 
 		virtual void PushAction(const Action&);
-		bool Command(const std::string& line);
+		bool ExecuteCommand(const std::string& line);
 
 		int GetFakeMetaKey() const { return fakeMetaKey; }
 
-		int GetDebug() const { return debug; }
-
 	public:
 		static const char NamedKeySetChar = '&';
 
@@ -84,7 +82,6 @@ class CKeyBindings : public CommandReceiver
 		// commands that use both Up and Down key presses
 		std::set<std::string> statefulCommands;
 
-		int debug;
 		int fakeMetaKey;
 		bool userCommand;
 };
