@@ -21,9 +21,9 @@
 #include "Game/GlobalUnsynced.h"
 #include "Game/Player.h"
 #include "Game/SelectedUnits.h"
-#include "Game/UI/LuaUI.h" // FIXME: for GML
 #include "Game/UI/UnitTracker.h"
 #include "Sim/Misc/TeamHandler.h"
+#include "Lua/LuaUI.h" // FIXME: for GML
 #include "Lua/LuaUnsyncedCtrl.h"
 #include "Map/BaseGroundDrawer.h"
 #include "Map/Ground.h"
@@ -55,8 +55,6 @@
 
 #include <boost/cstdint.hpp>
 
-#define PLAY_SOUNDS 1
-
 CONFIG(std::string, MiniMapGeometry).defaultValue("2 2 200 200");
 CONFIG(bool, MiniMapFullProxy).defaultValue(true);
 CONFIG(int, MiniMapButtonSize).defaultValue(16);
@@ -502,16 +500,9 @@ void CMiniMap::UpdateGeometry()
 
 void CMiniMap::MoveView(int x, int y)
 {
-	const float3& pos = camera->pos;
-	const float3& dir = camera->forward;
-	float dist = ground->LineGroundCol(pos, pos + (dir * globalRendering->viewRange * 1.4f), false);
-	float3 dif(0,0,0);
-	if (dist > 0) {
-		dif = dir * dist;
-	}
 	float3 clickPos;
-	clickPos.x = (float(x - xpos)) / width * gs->mapx * 8;
-	clickPos.z = (float(y - (globalRendering->viewSizeY - ypos - height))) / height * gs->mapy * 8;
+	clickPos.x = ((float(x -                               xpos          )) /  width) * (gs->mapx * SQUARE_SIZE);
+	clickPos.z = ((float(y - (globalRendering->viewSizeY - ypos - height))) / height) * (gs->mapy * SQUARE_SIZE);
 	camHandler->GetCurrentController().SetPos(clickPos);
 	unitTracker.Disable();
 }
