@@ -7,10 +7,11 @@
 #include <string>
 #include <list>
 #include "InputReceiver.h"
-#include "Rendering/GL/myGL.h"
 
 class CUnit;
-class CIconData;
+namespace icon {
+	class CIconData;
+}
 
 
 class CMiniMap : public CInputReceiver {
@@ -71,8 +72,7 @@ class CMiniMap : public CInputReceiver {
 		void DrawUnitHighlight(const CUnit* unit);
 		void DrawCircle(const float3& pos, float radius);
 		void DrawSquare(const float3& pos, float xsize, float zsize);
-		const CIconData* GetUnitIcon(const CUnit* unit, float& scale) const;
-		void GetFrustumSide(float3& side);
+		const icon::CIconData* GetUnitIcon(const CUnit* unit, float& scale) const;
 		
 	protected:
 		static void DrawSurfaceCircle(const float3& pos, float radius, unsigned int resolution);
@@ -134,18 +134,9 @@ class CMiniMap : public CInputReceiver {
 		unsigned char allyColor[4];
 		unsigned char enemyColor[4];
 
-		GLuint buttonsTexture;
+		unsigned int buttonsTexture;
 		unsigned int circleLists; // 8 - 256 divs
 		static const int circleListsCount = 6;
-				
-		struct fline {
-			float base;
-			float dir;
-			int left;
-			float minz;
-			float maxz;
-		};
-		std::vector<fline> left;
 
 		struct Notification {
 			float creationTime;
