@@ -2,12 +2,11 @@
 
 /* exports the #defines from CobDefines.h to Lua */
 
-#include "StdAfx.h"
-#include "mmgr.h"
+#include "System/mmgr.h"
 #include "LuaConstCOB.h"
 #include "LuaInclude.h"
 #include "LuaUtils.h"
-#include "Sim/Units/COB/CobDefines.h"
+#include "Sim/Units/Scripts/CobDefines.h"
 #include "Sim/Projectiles/PieceProjectile.h"
 
 
