@@ -1,11 +1,10 @@
 /* This file is part of the Spring engine (GPL v2 or later), see LICENSE.html */
 
-#include "StdAfx.h"
 
 #include <set>
 #include <cctype>
 
-#include "mmgr.h"
+#include "System/mmgr.h"
 
 #include "LuaHandleSynced.h"
 
@@ -33,20 +32,23 @@
 #include "LuaVFS.h"
 #include "LuaZip.h"
 
-#include "Game/Game.h"
+#include "System/Config/ConfigHandler.h"
 #include "Game/WordCompletion.h"
 #include "Sim/Misc/GlobalSynced.h"
 #include "Sim/Misc/TeamHandler.h"
+#include "Sim/Features/FeatureHandler.h"
 #include "Sim/Units/Unit.h"
 #include "Sim/Units/UnitDef.h"
+#include "Sim/Units/UnitDefHandler.h"
 #include "Sim/Units/CommandAI/Command.h"
-#include "Sim/Units/COB/CobInstance.h"
-#include "Sim/Units/COB/LuaUnitScript.h"
+#include "Sim/Units/Scripts/CobInstance.h"
+#include "Sim/Units/Scripts/LuaUnitScript.h"
 #include "Sim/Weapons/WeaponDefHandler.h"
-#include "EventHandler.h"
-#include "LogOutput.h"
-#include "FileSystem/FileHandler.h"
-#include "FileSystem/FileSystem.h"
+#include "System/EventHandler.h"
+#include "System/GlobalConfig.h"
+#include "System/Log/ILog.h"
+#include "System/FileSystem/FileHandler.h"
+#include "System/FileSystem/FileSystem.h"
 
 
 static const LuaHashString unsyncedStr("UNSYNCED");
@@ -55,23 +57,16 @@ LuaRulesParams::Params  CLuaHandleSynced::gameParams;
 LuaRulesParams::HashMap CLuaHandleSynced::gameParamsMap;
 
 
-#if (LUA_VERSION_NUM < 500)
-#  define LUA_OPEN_LIB(L, lib) lib(L)
-#else
-#  define LUA_OPEN_LIB(L, lib) \
-     lua_pushcfunction((L), lib); \
-     lua_pcall((L), 0, 0, 0);
-#endif
-
 
 /******************************************************************************/
 /******************************************************************************/
 
 CLuaHandleSynced::CLuaHandleSynced(const string& _name, int _order)
 : CLuaHandle(_name, _order, false),
-  allowChanges(false),
   teamsLocked(false)
 {
+	UpdateThreading();
+	SetAllowChanges(false, true);
 	printTracebacks = true;
 }
 
@@ -80,23 +75,38 @@ CLuaHandleSynced::~CLuaHandleSynced()
 {
 	// kill all unitscripts running in this handle
 	CLuaUnitScript::HandleFreed(this);
+
+	watchUnitDefs.clear();
+	watchFeatureDefs.clear();
+	watchWeaponDefs.clear();
 }
 
 
 /******************************************************************************/
 
+
+void CLuaHandleSynced::UpdateThreading() {
+	int mtl = globalConfig->GetMultiThreadLua();
+	useDualStates = (mtl == MT_LUA_DUAL_EXPORT || mtl == MT_LUA_DUAL || mtl == MT_LUA_DUAL_ALL || mtl == MT_LUA_DUAL_UNMANAGED);
+	singleState = (mtl == MT_LUA_NONE || mtl == MT_LUA_SINGLE || mtl == MT_LUA_SINGLE_BATCH);
+	copyExportTable = (mtl == MT_LUA_DUAL_EXPORT);
+	useEventBatch = false;
+	purgeCallsFromSyncedBatch = !singleState && (mtl != MT_LUA_DUAL_UNMANAGED);
+}
+
+
 void CLuaHandleSynced::Init(const string& syncedFile,
                             const string& unsyncedFile,
                             const string& modes)
 {
-	if (L == NULL) {
+	if (!IsValid()) {
 		return;
 	}
 
-	if (fullCtrl) {
-		for (int w = 0; w < weaponDefHandler->numWeaponDefs; w++) {
-			watchWeapons.push_back(false);
-		}
+	if (GetFullCtrl()) {
+		watchUnitDefs.resize(unitDefHandler->unitDefs.size() + 1, false);
+		watchFeatureDefs.resize(featureHandler->GetFeatureDefs().size(), false);
+		watchWeaponDefs.resize(weaponDefHandler->numWeaponDefs, false);
 	}
 
 	const string syncedCode   = LoadFile(syncedFile, modes);
@@ -106,6 +116,8 @@ void CLuaHandleSynced::Init(const string& syncedFile,
 		return;
 	}
 
+	BEGIN_ITERATE_LUA_STATES();
+
 	// load the standard libraries
 	LUA_OPEN_LIB(L, luaopen_base);
 	LUA_OPEN_LIB(L, luaopen_math);
@@ -133,34 +145,37 @@ void CLuaHandleSynced::Init(const string& syncedFile,
 
 	// use gs->randFloat() for the synchronized code, and disable randomseed()
 	// (this first copies the original functions to the registry for unsynced)
-	if (!SyncifyRandomFuncs()) {
+	if (!SyncifyRandomFuncs(L)) {
 		KillLua();
 		return;
 	}
 
-	CLuaHandle* origHandle = activeHandle;
-	SetActiveHandle();
+	CLuaHandle* origHandle = CLuaHandle::GetActiveHandle();
+	SetActiveHandle(L);
 
-	allowChanges = true;
-	synced = true;
+	SetAllowChanges(true, true);
+	SetSynced(true, true);
 
-	const bool haveSynced = SetupSynced(syncedCode, syncedFile);
-	if (L == NULL) {
+	const bool haveSynced = SetupSynced(L, syncedCode, syncedFile);
+	if (!IsValid()) {
 		SetActiveHandle(origHandle);
 		return;
 	}
 
-	allowChanges = false;
-	synced = false;
+	SetAllowChanges(false, true);
+	SetSynced(false, true);
 
-	const bool haveUnsynced = SetupUnsynced(unsyncedCode, unsyncedFile);
-	if (L == NULL) {
+	// FIXME: for the split lua state, we currently add synced AND unsynced code to both states
+	// to make sure HasCallIn et al do not return different results depending on active state.
+	// The problem is that synchronization is needed if HasCallIn would query both states.
+	const bool haveUnsynced = SetupUnsynced(L, unsyncedCode, unsyncedFile);
+	if (!IsValid()) {
 		SetActiveHandle(origHandle);
 		return;
 	}
 
-	synced = true;
-	allowChanges = true;
+	SetSynced(true, true);
+	SetAllowChanges(true, true);
 
 	if (!haveSynced && !haveUnsynced) {
 		KillLua();
@@ -172,26 +187,36 @@ void CLuaHandleSynced::Init(const string& syncedFile,
 	eventHandler.AddClient(this);
 
 	SetActiveHandle(origHandle);
+
+	END_ITERATE_LUA_STATES();
 }
 
 
-bool CLuaHandleSynced::SetupSynced(const string& code, const string& filename)
+bool CLuaHandleSynced::SetupSynced(lua_State *L, const string& code, const string& filename)
 {
-	if ((L == NULL) || code.empty()) {
+	if (!IsValid() || code.empty()) {
 		return false;
 	}
 
 	lua_pushvalue(L, LUA_GLOBALSINDEX);
 
-	AddBasicCalls(); // into Global
+	HSTR_PUSH(L, "EXPORT");
+	lua_newtable(L);
+	lua_rawset(L, -3);
 
-	lua_pushstring(L, "Script");
+	AddBasicCalls(L); // into Global
+
+	lua_pushliteral(L, "Script");
 	lua_rawget(L, -2);
 	LuaPushNamedCFunc(L, "AddActionFallback",    AddSyncedActionFallback);
 	LuaPushNamedCFunc(L, "RemoveActionFallback", RemoveSyncedActionFallback);
 	LuaPushNamedCFunc(L, "UpdateCallIn",         CallOutSyncedUpdateCallIn);
-	LuaPushNamedCFunc(L, "GetWatchWeapon",       GetWatchWeapon);
-	LuaPushNamedCFunc(L, "SetWatchWeapon",       SetWatchWeapon);
+	LuaPushNamedCFunc(L, "GetWatchUnit",         GetWatchUnitDef);
+	LuaPushNamedCFunc(L, "SetWatchUnit",         SetWatchUnitDef);
+	LuaPushNamedCFunc(L, "GetWatchFeature",      GetWatchFeatureDef);
+	LuaPushNamedCFunc(L, "SetWatchFeature",      SetWatchFeatureDef);
+	LuaPushNamedCFunc(L, "GetWatchWeapon",       GetWatchWeaponDef);
+	LuaPushNamedCFunc(L, "SetWatchWeapon",       SetWatchWeaponDef);
 	lua_pop(L, 1);
 
 	// add the custom file loader
@@ -217,20 +242,22 @@ bool CLuaHandleSynced::SetupSynced(const string& code, const string& filename)
 	    !AddEntriesToTable(L, "CMD",         LuaConstCMD::PushEntries)     ||
 	    !AddEntriesToTable(L, "CMDTYPE",     LuaConstCMDTYPE::PushEntries) ||
 	    !AddEntriesToTable(L, "COB",         LuaConstCOB::PushEntries)     ||
-	    !AddEntriesToTable(L, "SFX",         LuaConstSFX::PushEntries)) {
+	    !AddEntriesToTable(L, "SFX",         LuaConstSFX::PushEntries)     ||
+	    !AddEntriesToTable(L, "LOG",         LuaUtils::PushLogEntries)
+	) {
 		KillLua();
 		return false;
 	}
 
 	// add code from the sub-class
-	if (!AddSyncedCode()) {
+	if (!AddSyncedCode(L)) {
 		KillLua();
 		return false;
 	}
 
 	lua_settop(L, 0);
 
-	if (!LoadCode(code, filename)) {
+	if (!LoadCode(L, code, filename)) {
 		KillLua();
 		return false;
 	}
@@ -239,9 +266,9 @@ bool CLuaHandleSynced::SetupSynced(const string& code, const string& filename)
 }
 
 
-bool CLuaHandleSynced::SetupUnsynced(const string& code, const string& filename)
+bool CLuaHandleSynced::SetupUnsynced(lua_State *L, const string& code, const string& filename)
 {
-	if ((L == NULL) || code.empty()) {
+	if (!IsValid() || code.empty()) {
 		return false;
 	}
 
@@ -252,18 +279,18 @@ bool CLuaHandleSynced::SetupUnsynced(const string& code, const string& filename)
 
 	unsyncedStr.GetRegistry(L);
 
-	AddBasicCalls(); // into UNSYNCED
+	AddBasicCalls(L); // into UNSYNCED
 
 	// remove Script.Kill()
-	lua_pushstring(L, "Script");
+	lua_pushliteral(L, "Script");
 	lua_rawget(L, -2);
-	lua_pushstring(L, "Kill");
+	lua_pushliteral(L, "Kill");
 	lua_pushnil(L);
 	lua_rawset(L, -3);
 	LuaPushNamedCFunc(L, "UpdateCallIn", CallOutUnsyncedUpdateCallIn);
 	lua_pop(L, 1);
 
-	lua_pushstring(L, "_G");
+	lua_pushliteral(L, "_G");
 	unsyncedStr.GetRegistry(L);
 	lua_rawset(L, -3);
 
@@ -287,28 +314,30 @@ bool CLuaHandleSynced::SetupUnsynced(const string& code, const string& filename)
 	    !AddEntriesToTable(L, "GL",          LuaConstGL::PushEntries)      ||
 	    !AddEntriesToTable(L, "Game",        LuaConstGame::PushEntries)    ||
 	    !AddEntriesToTable(L, "CMD",         LuaConstCMD::PushEntries)     ||
-	    !AddEntriesToTable(L, "CMDTYPE",     LuaConstCMDTYPE::PushEntries)) {
+	    !AddEntriesToTable(L, "CMDTYPE",     LuaConstCMDTYPE::PushEntries) ||
+	    !AddEntriesToTable(L, "LOG",         LuaUtils::PushLogEntries)
+	) {
 		KillLua();
 		return false;
 	}
 
-	lua_pushstring(L, "math"); lua_newtable(L);
-	lua_getglobal(L, "math"); LightCopyTable(-2, -1); lua_pop(L, 1);
+	lua_pushliteral(L, "math"); lua_newtable(L);
+	lua_getglobal(L, "math"); LightCopyTable(L, -2, -1); lua_pop(L, 1);
 	lua_rawset(L, -3);
 
-	lua_pushstring(L, "table"); lua_newtable(L);
-	lua_getglobal(L, "table"); LightCopyTable(-2, -1); lua_pop(L, 1);
+	lua_pushliteral(L, "table"); lua_newtable(L);
+	lua_getglobal(L, "table"); LightCopyTable(L, -2, -1); lua_pop(L, 1);
 	lua_rawset(L, -3);
 
-	lua_pushstring(L, "string"); lua_newtable(L);
-	lua_getglobal(L, "string"); LightCopyTable(-2, -1); lua_pop(L, 1);
+	lua_pushliteral(L, "string"); lua_newtable(L);
+	lua_getglobal(L, "string"); LightCopyTable(L, -2, -1); lua_pop(L, 1);
 	lua_rawset(L, -3);
 
-	lua_pushstring(L, "coroutine"); lua_newtable(L);
-	lua_getglobal(L, "coroutine"); LightCopyTable(-2, -1); lua_pop(L, 1);
+	lua_pushliteral(L, "coroutine"); lua_newtable(L);
+	lua_getglobal(L, "coroutine"); LightCopyTable(L, -2, -1); lua_pop(L, 1);
 	lua_rawset(L, -3);
 
-	if (!CopyRealRandomFuncs()) {
+	if (!CopyRealRandomFuncs(L)) {
 		KillLua();
 		return false;
 	}
@@ -331,33 +360,33 @@ bool CLuaHandleSynced::SetupUnsynced(const string& code, const string& filename)
 		NULL
 	};
 	for (const char** l = labels; *l != NULL; l++) {
-		CopyGlobalToUnsynced(*l);
+		CopyGlobalToUnsynced(L, *l);
 	}
 
 	// add code from the sub-class
 	unsyncedStr.GetRegistry(L);
-	if (!AddUnsyncedCode()) {
+	if (!AddUnsyncedCode(L)) {
 		KillLua();
 		return false;
 	}
 	lua_settop(L, 0);
 
-	if (!LoadUnsyncedCode(code, filename)) {
+	if (!LoadUnsyncedCode(L, code, filename)) {
 		KillLua();
 		return false;
 	}
 
-	if (!SetupUnsyncedFunction("RecvFromSynced")      ||
-	    !SetupUnsyncedFunction("Update")              ||
-	    !SetupUnsyncedFunction("DrawGenesis")         ||
-	    !SetupUnsyncedFunction("DrawWorld")           ||
-	    !SetupUnsyncedFunction("DrawWorldPreUnit")    ||
-	    !SetupUnsyncedFunction("DrawWorldShadow")     ||
-	    !SetupUnsyncedFunction("DrawWorldReflection") ||
-	    !SetupUnsyncedFunction("DrawWorldRefraction") ||
-	    !SetupUnsyncedFunction("DrawScreenEffects")   ||
-	    !SetupUnsyncedFunction("DrawScreen")          ||
-	    !SetupUnsyncedFunction("DrawInMiniMap")) {
+	if (!SetupUnsyncedFunction(L, "RecvFromSynced")      ||
+	    !SetupUnsyncedFunction(L, "Update")              ||
+	    !SetupUnsyncedFunction(L, "DrawGenesis")         ||
+	    !SetupUnsyncedFunction(L, "DrawWorld")           ||
+	    !SetupUnsyncedFunction(L, "DrawWorldPreUnit")    ||
+	    !SetupUnsyncedFunction(L, "DrawWorldShadow")     ||
+	    !SetupUnsyncedFunction(L, "DrawWorldReflection") ||
+	    !SetupUnsyncedFunction(L, "DrawWorldRefraction") ||
+	    !SetupUnsyncedFunction(L, "DrawScreenEffects")   ||
+	    !SetupUnsyncedFunction(L, "DrawScreen")          ||
+	    !SetupUnsyncedFunction(L, "DrawInMiniMap")) {
 		return false;
 	}
 
@@ -365,34 +394,34 @@ bool CLuaHandleSynced::SetupUnsynced(const string& code, const string& filename)
 }
 
 
-bool CLuaHandleSynced::SyncifyRandomFuncs()
+bool CLuaHandleSynced::SyncifyRandomFuncs(lua_State *L)
 {
 	// adjust the math.random() and math.randomseed() calls
 	lua_getglobal(L, "math");
 	if (!lua_istable(L, -1)) {
-		logOutput.Print("lua.math does not exist\n");
+		LOG_L(L_WARNING, "lua.math does not exist");
 		return false;
 	}
 
 	// copy the original random() into the registry
-	lua_pushstring(L, "random");
-	lua_pushstring(L, "random");
+	lua_pushliteral(L, "random");
+	lua_pushliteral(L, "random");
 	lua_rawget(L, -3); // math table
 	lua_rawset(L, LUA_REGISTRYINDEX);
 
 	// copy the original randomseed() into the registry
-	lua_pushstring(L, "randomseed");
-	lua_pushstring(L, "randomseed");
+	lua_pushliteral(L, "randomseed");
+	lua_pushliteral(L, "randomseed");
 	lua_rawget(L, -3); // math table
 	lua_rawset(L, LUA_REGISTRYINDEX);
 
 	// install our custom random()
-	lua_pushstring(L, "random");
+	lua_pushliteral(L, "random");
 	lua_pushcfunction(L, SyncedRandom);
 	lua_rawset(L, -3);
 
 	// remove randomseed()
-	lua_pushstring(L, "randomseed");
+	lua_pushliteral(L, "randomseed");
 	lua_pushnil(L);
 	lua_rawset(L, -3);
 
@@ -402,18 +431,18 @@ bool CLuaHandleSynced::SyncifyRandomFuncs()
 }
 
 
-bool CLuaHandleSynced::CopyRealRandomFuncs()
+bool CLuaHandleSynced::CopyRealRandomFuncs(lua_State *L)
 {
-	lua_pushstring(L, "math");
+	lua_pushliteral(L, "math");
 	lua_rawget(L, -2);
 
-	lua_pushstring(L, "random");
-	lua_pushstring(L, "random");
+	lua_pushliteral(L, "random");
+	lua_pushliteral(L, "random");
 	lua_rawget(L, LUA_REGISTRYINDEX);
 	lua_rawset(L, -3);
 
-	lua_pushstring(L, "randomseed");
-	lua_pushstring(L, "randomseed");
+	lua_pushliteral(L, "randomseed");
+	lua_pushliteral(L, "randomseed");
 	lua_rawget(L, LUA_REGISTRYINDEX);
 	lua_rawset(L, -3);
 
@@ -423,7 +452,7 @@ bool CLuaHandleSynced::CopyRealRandomFuncs()
 }
 
 
-bool CLuaHandleSynced::SetupUnsyncedFunction(const char* funcName)
+bool CLuaHandleSynced::SetupUnsyncedFunction(lua_State *L, const char* funcName)
 {
 	// copy the function from UNSYNCED into
 	// the registry, and setfenv() it to UNSYNCED
@@ -431,7 +460,7 @@ bool CLuaHandleSynced::SetupUnsyncedFunction(const char* funcName)
 	unsyncedStr.GetRegistry(L);
 	if (!lua_istable(L, -1)) {
 		lua_settop(L, 0);
-//FIXME		logOutput.Print("ERROR: missing UNSYNCED table for %s", name.c_str());
+// FIXME		LOG_L(L_ERROR, "missing UNSYNCED table for %s", name.c_str());
 		return false;
 	}
 	const int unsynced = lua_gettop(L);
@@ -447,7 +476,8 @@ bool CLuaHandleSynced::SetupUnsyncedFunction(const char* funcName)
 	}
 	else if (!lua_isfunction(L, -1)) {
 		lua_settop(L, 0);
-		logOutput.Print("%s in %s is not a function", funcName, GetName().c_str());
+		LOG_L(L_WARNING, "%s in %s is not a function",
+				funcName, GetName().c_str());
 		return false;
 	}
 	lua_pushvalue(L, unsynced);
@@ -460,7 +490,7 @@ bool CLuaHandleSynced::SetupUnsyncedFunction(const char* funcName)
 }
 
 
-bool CLuaHandleSynced::CopyGlobalToUnsynced(const char* name)
+bool CLuaHandleSynced::CopyGlobalToUnsynced(lua_State *L, const char* name)
 {
 	lua_settop(L, 0);
 	unsyncedStr.GetRegistry(L);
@@ -475,7 +505,7 @@ bool CLuaHandleSynced::CopyGlobalToUnsynced(const char* name)
 }
 
 
-bool CLuaHandleSynced::LightCopyTable(int dstIndex, int srcIndex)
+bool CLuaHandleSynced::LightCopyTable(lua_State *L, int dstIndex, int srcIndex)
 {
 	// use positive indices
 	if (dstIndex < 0) { dstIndex = lua_gettop(L) + dstIndex + 1; }
@@ -503,15 +533,15 @@ bool CLuaHandleSynced::LightCopyTable(int dstIndex, int srcIndex)
 }
 
 
-bool CLuaHandleSynced::LoadUnsyncedCode(const string& code, const string& debug)
+bool CLuaHandleSynced::LoadUnsyncedCode(lua_State *L, const string& code, const string& debug)
 {
 	lua_settop(L, 0);
 
 	int error;
 	error = luaL_loadbuffer(L, code.c_str(), code.size(), debug.c_str());
 	if (error != 0) {
-		logOutput.Print("error = %i, %s, %s\n",
-		                error, debug.c_str(), lua_tostring(L, -1));
+		LOG_L(L_ERROR, "error = %i, %s, %s",
+				error, debug.c_str(), lua_tostring(L, -1));
 		lua_settop(L, 0);
 		return false;
 	}
@@ -523,14 +553,14 @@ bool CLuaHandleSynced::LoadUnsyncedCode(const string& code, const string& debug)
 	}
 	lua_setfenv(L, -2);
 
-	CLuaHandle* orig = activeHandle;
-	SetActiveHandle();
+	CLuaHandle* orig = GetActiveHandle();
+	SetActiveHandle(L);
 	error = lua_pcall(L, 0, 0, 0);
 	SetActiveHandle(orig);
 
 	if (error != 0) {
-		logOutput.Print("error = %i, %s, %s\n",
-		                error, debug.c_str(), lua_tostring(L, -1));
+		LOG_L(L_ERROR, "error = %i, %s, %s",
+				error, debug.c_str(), lua_tostring(L, -1));
 		lua_settop(L, 0);
 		return false;
 	}
@@ -558,26 +588,37 @@ string CLuaHandleSynced::LoadFile(const string& filename,
 }
 
 
-bool CLuaHandleSynced::HasCallIn(const string& name)
+bool CLuaHandleSynced::HasCallIn(lua_State *L, const string& name)
 {
-	if (L == NULL) {
+	if (!IsValid()) {
 		return false;
 	}
 
-	int tableIndex;
-	if ((name != "DrawUnit") &&
-	    (name != "DrawFeature") &&
-	    (name != "AICallIn") &&
-	    (name != "RecvFromSynced") &&
-	    !eventHandler.IsUnsynced(name)) {
-		tableIndex = LUA_GLOBALSINDEX;  // synced call-ins in GLOBAL
-	} else {
-		tableIndex = LUA_REGISTRYINDEX; // unsynced call-ins in REGISTRY
+	static const std::string unsyncedNames[] = {
+		"DrawUnit",
+		"DrawFeature",
+		"DrawShield",
+		"RecvSkirmishAIMessage",
+		"RecvFromSynced",
+	};
+
+	// unsynced call-ins in REGISTRY
+	int tableIndex = LUA_REGISTRYINDEX;
+	bool unsynced = false;
+
+	for (unsigned int n = 0; n < (sizeof(unsyncedNames) / sizeof(std::string)); n++) {
+		if (name == unsyncedNames[n]) {
+			unsynced = true; break;
+		}
 	}
 
+	// synced call-ins in GLOBAL
+	if (!unsynced && !eventHandler.IsUnsynced(name))
+		tableIndex = LUA_GLOBALSINDEX;
+
 	bool haveFunc = true;
 	lua_settop(L, 0);
-	lua_pushstring(L, name.c_str());
+	lua_pushsstring(L, name);
 	lua_gettable(L, tableIndex);
 	if (!lua_isfunction(L, -1)) {
 		haveFunc = false;
@@ -588,13 +629,13 @@ bool CLuaHandleSynced::HasCallIn(const string& name)
 }
 
 
-bool CLuaHandleSynced::SyncedUpdateCallIn(const string& name)
+bool CLuaHandleSynced::SyncedUpdateCallIn(lua_State *L, const string& name)
 {
 	if ((name == "RecvFromSynced") ||
 	    eventHandler.IsUnsynced(name)) {
 		return false;
 	}
-	if (HasCallIn(name)) {
+	if (HasCallIn(L, name)) {
 		eventHandler.InsertEvent(this, name);
 	} else {
 		eventHandler.RemoveEvent(this, name);
@@ -603,20 +644,20 @@ bool CLuaHandleSynced::SyncedUpdateCallIn(const string& name)
 }
 
 
-bool CLuaHandleSynced::UnsyncedUpdateCallIn(const string& name)
+bool CLuaHandleSynced::UnsyncedUpdateCallIn(lua_State *L, const string& name)
 {
 	if ((name != "RecvFromSynced") &&
 	    !eventHandler.IsUnsynced(name)) {
 		  return false;
 	}
 	if (name != "RecvFromSynced") {
-		if (HasCallIn(name)) {
+		if (HasCallIn(L, name)) {
 			eventHandler.InsertEvent(this, name);
 		} else {
 			eventHandler.RemoveEvent(this, name);
 		}
 	}
-	SetupUnsyncedFunction(name.c_str());
+	SetupUnsyncedFunction(L, name.c_str());
 	return true;
 }
 
@@ -636,10 +677,10 @@ bool CLuaHandleSynced::Initialize(const string& syncData)
 		return true;
 	}
 
-	int errfunc = SetupTraceback() ? -2 : 0;
-	logOutput.Print("Initialize errfunc=%d\n", errfunc);
+	int errfunc = SetupTraceback(L) ? -2 : 0;
+	LOG("Initialize errfunc=%d", errfunc);
 
-	lua_pushlstring(L, syncData.c_str(), syncData.size());
+	lua_pushsstring(L, syncData);
 
 	// call the routine
 	if (!RunCallInTraceback(cmdStr, 1, 1, errfunc)) {
@@ -714,7 +755,7 @@ bool CLuaHandleSynced::GotChatMsg(const string& msg, int playerID)
 		return true; // the call is not defined
 	}
 
-	lua_pushstring(L, msg.c_str());
+	lua_pushsstring(L, msg);
 	lua_pushnumber(L, playerID);
 
 	// call the routine
@@ -726,37 +767,49 @@ bool CLuaHandleSynced::GotChatMsg(const string& msg, int playerID)
 
 /******************************************************************************/
 
-void CLuaHandleSynced::RecvFromSynced(int args)
+
+
+void CLuaHandleSynced::RecvFromSynced(lua_State *srcState, int args)
 {
-	//LUA_CALL_IN_CHECK(L); -- not valid here
-	static const LuaHashString cmdStr("RecvFromSynced");
-	if (!cmdStr.GetRegistryFunc(L)) {
-		return; // the call is not defined
+	SELECT_UNSYNCED_LUA_STATE();
+
+#if ((LUA_MT_OPT & LUA_STATE) && (LUA_MT_OPT & LUA_MUTEX))
+	if (!SingleState() && srcState != L) { // Sim thread sends to unsynced --> delay it
+		DelayRecvFromSynced(srcState, args);
+		return;
 	}
+	// Draw thread, delayed already, execute it
+#endif
+
+	static const LuaHashString cmdStr("RecvFromSynced");
+	//LUA_CALL_IN_CHECK(L); -- not valid here
+
+	if (!cmdStr.GetRegistryFunc(L))
+		return; // the call is not defined
 	lua_insert(L, 1); // place the function
 
 	// call the routine
-	allowChanges = false;
-	synced = false;
+	SetAllowChanges(false);
+	SetSynced(L, false);
 
+	lua_State* L_Prev = ForceUnsyncedState();
 	RunCallIn(cmdStr, args, 0);
+	RestoreState(L_Prev);
 
-	synced = true;
-	allowChanges = true;
-
-	return;
+	SetSynced(L, true);
+	SetAllowChanges(true);
 }
 
 
 bool CLuaHandleSynced::RecvLuaMsg(const string& msg, int playerID)
 {
 	//FIXME: is there a reason to disallow gamestate changes in RecvLuaMsg?
-	const bool prevAllowChanges = allowChanges;
-	allowChanges = false;
+	const bool prevAllowChanges = GetAllowChanges();
+	SetAllowChanges(false);
 
 	const bool retval = CLuaHandle::RecvLuaMsg(msg, playerID);
 
-	allowChanges = prevAllowChanges;
+	SetAllowChanges(prevAllowChanges);
 
 	return retval;
 }
@@ -770,12 +823,19 @@ bool CLuaHandleSynced::RecvLuaMsg(const string& msg, int playerID)
 
 bool CLuaHandleSynced::HasSyncedXCall(const string& funcName)
 {
+	SELECT_LUA_STATE();
+
+	if (L != L_Sim)
+		return false;
+
+	GML_DRCMUTEX_LOCK(lua); // HasSyncedXCall
+
 	lua_pushvalue(L, LUA_GLOBALSINDEX);
 	if (!lua_istable(L, -1)) {
 		lua_pop(L, 1);
 		return false;
 	}
-	lua_pushstring(L, funcName.c_str()); // push the function name
+	lua_pushsstring(L, funcName); // push the function name
 	lua_rawget(L, -2);                   // get the function
 	const bool haveFunc = lua_isfunction(L, -1);
 	lua_pop(L, 2);
@@ -783,14 +843,18 @@ bool CLuaHandleSynced::HasSyncedXCall(const string& funcName)
 }
 
 
-bool CLuaHandleSynced::HasUnsyncedXCall(const string& funcName)
+bool CLuaHandleSynced::HasUnsyncedXCall(lua_State* srcState, const string& funcName)
 {
+	SELECT_UNSYNCED_LUA_STATE();
+
+	GML_DRCMUTEX_LOCK(lua); // HasUnsyncedXCall
+
 	unsyncedStr.GetRegistry(L); // push the UNSYNCED table
 	if (!lua_istable(L, -1)) {
 		lua_pop(L, 1);
 		return false;
 	}
-	lua_pushstring(L, funcName.c_str()); // push the function name
+	lua_pushsstring(L, funcName); // push the function name
 	lua_rawget(L, -2);                   // get the function
 	const bool haveFunc = lua_isfunction(L, -1);
 	lua_pop(L, 2);
@@ -798,7 +862,7 @@ bool CLuaHandleSynced::HasUnsyncedXCall(const string& funcName)
 }
 
 
-int CLuaHandleSynced::XCall(lua_State* srcState, const string& funcName)
+int CLuaHandleSynced::XCall(lua_State* L, lua_State* srcState, const string& funcName)
 {
 	// expecting an environment table
 	if (!lua_istable(L, -1)) {
@@ -854,19 +918,30 @@ int CLuaHandleSynced::XCall(lua_State* srcState, const string& funcName)
 
 int CLuaHandleSynced::SyncedXCall(lua_State* srcState, const string& funcName)
 {
+	SELECT_LUA_STATE();
+
+	if (L != L_Sim)
+		return 0;
+
+	GML_DRCMUTEX_LOCK(lua); // SyncedXCall
+
 	lua_pushvalue(L, LUA_GLOBALSINDEX);
-	const int retval = XCall(srcState, funcName);
+	const int retval = XCall(L, srcState, funcName);
 	return retval;
 }
 
 
 int CLuaHandleSynced::UnsyncedXCall(lua_State* srcState, const string& funcName)
 {
-	const bool prevSynced = synced;
-	synced = false;
+	SELECT_UNSYNCED_LUA_STATE();
+
+	GML_DRCMUTEX_LOCK(lua); // UnsyncedXCall
+
+	const bool prevSynced = GetSynced(L);
+	SetSynced(L, false);
 	unsyncedStr.GetRegistry(L); // push the UNSYNCED table
-	const int retval = XCall(srcState, funcName);
-	synced = prevSynced;
+	const int retval = XCall(L, srcState, funcName);
+	SetSynced(L, prevSynced);
 	return retval;
 }
 
@@ -930,29 +1005,9 @@ int CLuaHandleSynced::LoadStringData(lua_State* L)
 }
 
 
-int CLuaHandleSynced::SendToUnsynced(lua_State* L)
-{
-	const int args = lua_gettop(L);
-	if (args <= 0) {
-		luaL_error(L, "Incorrect arguments to SendToUnsynced()");
-	}
-	for (int i = 1; i <= args; i++) {
-		if (!lua_isnil(L, i)    &&
-		    !lua_isnumber(L, i) &&
-		    !lua_isstring(L, i) &&
-		    !lua_isboolean(L, i)) {
-			luaL_error(L, "Incorrect data type for SendToUnsynced(), arg %d", i);
-		}
-	}
-	CLuaHandleSynced* lhs = GetActiveHandle();
-	lhs->RecvFromSynced(args);
-	return 0;
-}
-
-
 int CLuaHandleSynced::CallAsTeam(lua_State* L)
 {
-	CLuaHandleSynced* lhs = GetActiveHandle();
+	CLuaHandleSynced* lhs = GetActiveHandle(L);
 	if (lhs->teamsLocked) {
 		luaL_error(L, "CallAsTeam() called when teams are locked");
 	}
@@ -962,12 +1017,12 @@ int CLuaHandleSynced::CallAsTeam(lua_State* L)
 	}
 
 	// save the current access
-	const bool prevFullCtrl    = lhs->fullCtrl;
-	const bool prevFullRead    = lhs->fullRead;
-	const int prevCtrlTeam     = lhs->ctrlTeam;
-	const int prevReadTeam     = lhs->readTeam;
-	const int prevReadAllyTeam = lhs->readAllyTeam;
-	const int prevSelectTeam   = lhs->selectTeam;
+	const bool prevFullCtrl    = GetFullCtrl(L);
+	const bool prevFullRead    = GetFullRead(L);
+	const int prevCtrlTeam     = GetCtrlTeam(L);
+	const int prevReadTeam     = GetReadTeam(L);
+	const int prevReadAllyTeam = GetReadAllyTeam(L);
+	const int prevSelectTeam   = GetSelectTeam(L);
 
 	// parse the new access
 	if (lua_isnumber(L, 1)) {
@@ -976,16 +1031,16 @@ int CLuaHandleSynced::CallAsTeam(lua_State* L)
 			luaL_error(L, "Bad teamID in SetCtrlTeam");
 		}
 		// ctrl
-		lhs->ctrlTeam = teamID;
-		lhs->fullCtrl = (lhs->ctrlTeam == CEventClient::AllAccessTeam);
+		SetCtrlTeam(L, teamID);
+		SetFullCtrl(L, GetCtrlTeam(L) == CEventClient::AllAccessTeam);
 		// read
-		lhs->readTeam = teamID;
-		lhs->readAllyTeam = (teamID < 0) ? teamID : teamHandler->AllyTeam(teamID);
-		lhs->fullRead = (lhs->readAllyTeam == CEventClient::AllAccessTeam);
-		activeFullRead     = lhs->fullRead;
-		activeReadAllyTeam = lhs->readAllyTeam;
+		SetReadTeam(L, teamID);
+		SetReadAllyTeam(L, (teamID < 0) ? teamID : teamHandler->AllyTeam(teamID));
+		SetFullRead(L, GetReadAllyTeam(L) == CEventClient::AllAccessTeam);
+		SetActiveFullRead(GetFullRead(L));
+		SetActiveReadAllyTeam(GetReadAllyTeam(L));
 		// select
-		lhs->selectTeam = teamID;
+		SetSelectTeam(L, teamID);
 	}
 	else if (lua_istable(L, 1)) {
 		const int table = 1;
@@ -1000,18 +1055,18 @@ int CLuaHandleSynced::CallAsTeam(lua_State* L)
 			}
 
 			if (key == "ctrl") {
-				lhs->ctrlTeam = teamID;
-				lhs->fullCtrl = (lhs->ctrlTeam == CEventClient::AllAccessTeam);
+				SetCtrlTeam(L, teamID);
+				SetFullCtrl(L, GetCtrlTeam(L) == CEventClient::AllAccessTeam);
 			}
 			else if (key == "read") {
-				lhs->readTeam = teamID;
-				lhs->readAllyTeam = (teamID < 0) ? teamID : teamHandler->AllyTeam(teamID);
-				lhs->fullRead = (lhs->readAllyTeam == CEventClient::AllAccessTeam);
-				activeFullRead     = lhs->fullRead;
-				activeReadAllyTeam = lhs->readAllyTeam;
+				SetReadTeam(L, teamID);
+				SetReadAllyTeam(L, (teamID < 0) ? teamID : teamHandler->AllyTeam(teamID));
+				SetFullRead(L, GetReadAllyTeam(L) == CEventClient::AllAccessTeam);
+				SetActiveFullRead(GetFullRead(L));
+				SetActiveReadAllyTeam(GetReadAllyTeam(L));
 			}
 			else if (key == "select") {
-				lhs->selectTeam = teamID;
+				SetSelectTeam(L, teamID);
 			}
 		}
 	}
@@ -1023,21 +1078,21 @@ int CLuaHandleSynced::CallAsTeam(lua_State* L)
 	const int funcArgs = lua_gettop(L) - 2;
 
 	// protected call so that the permissions are always reverted
-	const int error = lua_pcall(lhs->L, funcArgs, LUA_MULTRET, 0);
+	const int error = lua_pcall(lhs->GetActiveState(), funcArgs, LUA_MULTRET, 0);
 
 	// revert the permissions
-	lhs->fullCtrl      = prevFullCtrl;
-	lhs->fullRead      = prevFullRead;
-	lhs->ctrlTeam      = prevCtrlTeam;
-	lhs->readTeam      = prevReadTeam;
-	lhs->readAllyTeam  = prevReadAllyTeam;
-	lhs->selectTeam    = prevSelectTeam;
-	activeFullRead     = prevFullRead;
-	activeReadAllyTeam = prevReadAllyTeam;
+	SetFullCtrl(L, prevFullCtrl);
+	SetFullRead(L, prevFullRead);
+	SetCtrlTeam(L, prevCtrlTeam);
+	SetReadTeam(L, prevReadTeam);
+	SetReadAllyTeam(L, prevReadAllyTeam);
+	SetSelectTeam(L, prevSelectTeam);
+	SetActiveFullRead(prevFullRead);
+	SetActiveReadAllyTeam(prevReadAllyTeam);
 
 	if (error != 0) {
-		logOutput.Print("error = %i, %s, %s\n",
-		                error, "CallAsTeam", lua_tostring(L, -1));
+		LOG_L(L_ERROR, "error = %i, %s, %s",
+				error, "CallAsTeam", lua_tostring(L, -1));
 		lua_error(L);
 	}
 
@@ -1065,9 +1120,9 @@ int CLuaHandleSynced::AddSyncedActionFallback(lua_State* L)
 		return 1;
 	}
 
-	CLuaHandleSynced* lhs = GetActiveHandle();
+	CLuaHandleSynced* lhs = GetActiveHandle(L);
 	lhs->textCommands[cmd] = lua_tostring(L, 2);
-	game->wordCompletion->AddWord(cmdRaw, true, false, false);
+	wordCompletion->AddWord(cmdRaw, true, false, false);
 	lua_pushboolean(L, true);
 	return 1;
 }
@@ -1093,12 +1148,12 @@ int CLuaHandleSynced::RemoveSyncedActionFallback(lua_State* L)
 		return 1;
 	}
 
-	CLuaHandleSynced* lhs = GetActiveHandle();
+	CLuaHandleSynced* lhs = GetActiveHandle(L);
 
 	map<string, string>::iterator it = lhs->textCommands.find(cmd);
 	if (it != lhs->textCommands.end()) {
 		lhs->textCommands.erase(it);
-		game->wordCompletion->RemoveWord(cmdRaw);
+		wordCompletion->RemoveWord(cmdRaw);
 		lua_pushboolean(L, true);
 	} else {
 		lua_pushboolean(L, false);
@@ -1109,32 +1164,42 @@ int CLuaHandleSynced::RemoveSyncedActionFallback(lua_State* L)
 
 /******************************************************************************/
 
-int CLuaHandleSynced::GetWatchWeapon(lua_State* L)
-{
-	CLuaHandleSynced* lhs = GetActiveHandle();
-	const int weaponID = luaL_checkint(L, 1);
-	if ((weaponID < 0) || (weaponID >= (int)lhs->watchWeapons.size())) {
-		return 0;
+#define GetWatchDef(DefType)                                          \
+	int CLuaHandleSynced::GetWatch ## DefType ## Def(lua_State* L) {  \
+		CLuaHandleSynced* lhs = GetActiveHandle(L);                   \
+		const unsigned int defID = luaL_checkint(L, 1);               \
+		if (defID >= lhs->watch ## DefType ## Defs.size()) {          \
+			return 0;                                                 \
+		}                                                             \
+		lua_pushboolean(L, lhs->watch ## DefType ## Defs[defID]);     \
+		return 1;                                                     \
 	}
-	lua_pushboolean(L, lhs->watchWeapons[weaponID]);
-	return 1;
-}
 
-
-int CLuaHandleSynced::SetWatchWeapon(lua_State* L)
-{
-	CLuaHandleSynced* lhs = GetActiveHandle();
-	const int weaponID = luaL_checkint(L, 1);
-	if ((weaponID < 0) || (weaponID >= (int)lhs->watchWeapons.size())) {
-		return 0;
+#define SetWatchDef(DefType)                                          \
+	int CLuaHandleSynced::SetWatch ## DefType ## Def(lua_State* L) {  \
+		CLuaHandleSynced* lhs = GetActiveHandle(L);                   \
+		const unsigned int defID = luaL_checkint(L, 1);               \
+		if (defID >= lhs->watch ## DefType ## Defs.size()) {          \
+			return 0;                                                 \
+		}                                                             \
+		if (!lua_isboolean(L, 2)) {                                   \
+			luaL_error(L, "Incorrect arguments to %s", __FUNCTION__); \
+			return 0;                                                 \
+		}                                                             \
+		lhs->watch ## DefType ## Defs[defID] = lua_toboolean(L, 2);   \
+		return 0;                                                     \
 	}
-	if (!lua_isboolean(L, 2)) {
-		luaL_error(L, "Incorrect arguments to SetWatchWeapon()");
-	}
-	lhs->watchWeapons[weaponID] = lua_toboolean(L, 2);
-	return 0;
-}
 
+GetWatchDef(Unit)
+GetWatchDef(Feature)
+GetWatchDef(Weapon)
+
+SetWatchDef(Unit)
+SetWatchDef(Feature)
+SetWatchDef(Weapon)
+
+#undef GetWatchDef
+#undef SetWatchDef
 
 /******************************************************************************/
 /******************************************************************************/
