@@ -1,13 +1,12 @@
 /* This file is part of the Spring engine (GPL v2 or later), see LICENSE.html */
 
-#include "StdAfx.h"
 
 #include <string>
 
-#include "mmgr.h"
+#include "System/mmgr.h"
 
 #include "LuaInputReceiver.h"
-#include "EventHandler.h"
+#include "System/EventHandler.h"
 
 
 LuaInputReceiver* luaInputReceiver = NULL;
