@@ -121,7 +121,8 @@ void LuaParser::SetupEnv()
 	AddFunc("DontMessWithMyCase", DontMessWithMyCase);
 
 	GetTable("Spring");
-	AddFunc("Echo", Echo);
+	AddFunc("Echo", LuaUtils::Echo);
+	AddFunc("Log", LuaUtils::Log);
 	AddFunc("TimeCheck", TimeCheck);
 	EndTable();
 
@@ -132,6 +133,10 @@ void LuaParser::SetupEnv()
 	AddFunc("LoadFile",   LoadFile);
 	AddFunc("FileExists", FileExists);
 	EndTable();
+
+	GetTable("LOG");
+	LuaUtils::PushLogEntries(L);
+	EndTable();
 }
 
 
@@ -417,12 +422,6 @@ void LuaParser::AddString(int key, const string& value)
 //  call-outs
 //
 
-int LuaParser::Echo(lua_State* L)
-{
-	return LuaUtils::Echo(L);
-}
-
-
 int LuaParser::TimeCheck(lua_State* L)
 {
 	if (!lua_isstring(L, 1) || !lua_isfunction(L, 2)) {
