@@ -1,8 +1,7 @@
 /* This file is part of the Spring engine (GPL v2 or later), see LICENSE.html */
 
-#include "StdAfx.h"
 
-#include "mmgr.h"
+#include "System/mmgr.h"
 
 #include "LuaRBOs.h"
 
@@ -12,8 +11,6 @@
 #include "LuaHashString.h"
 #include "LuaUtils.h"
 
-#include "LogOutput.h"
-
 
 /******************************************************************************/
 /******************************************************************************/
@@ -85,7 +82,7 @@ void LuaRBOs::RBO::Init()
 }
 
 
-void LuaRBOs::RBO::Free()
+void LuaRBOs::RBO::Free(lua_State *L)
 {
 	if (id == 0) {
 		return;
@@ -94,7 +91,7 @@ void LuaRBOs::RBO::Free()
 	glDeleteRenderbuffersEXT(1, &id);
 	id = 0;
 
-	CLuaHandle::GetActiveRBOs().rbos.erase(this);
+	CLuaHandle::GetActiveRBOs(L).rbos.erase(this);
 }
 
 
@@ -104,7 +101,7 @@ void LuaRBOs::RBO::Free()
 int LuaRBOs::meta_gc(lua_State* L)
 {
 	RBO* rbo = (RBO*)luaL_checkudata(L, 1, "RBO");
-	rbo->Free();
+	rbo->Free(L);
 	return 0;
 }
 
@@ -175,7 +172,7 @@ int LuaRBOs::CreateRBO(lua_State* L)
 	lua_setmetatable(L, -2);
 
 	if (rboPtr->id != 0) {
-		CLuaHandle::GetActiveRBOs().rbos.insert(rboPtr);
+		CLuaHandle::GetActiveRBOs(L).rbos.insert(rboPtr);
 	}
 
 	return 1;
@@ -188,7 +185,7 @@ int LuaRBOs::DeleteRBO(lua_State* L)
 		return 0;
 	}
 	RBO* rbo = (RBO*)luaL_checkudata(L, 1, "RBO");
-	rbo->Free();
+	rbo->Free(L);
 	return 0;
 }
 
