@@ -27,6 +27,7 @@
 #include "Sim/Misc/GlobalSynced.h"
 #include "Sim/Misc/TeamHandler.h"
 #include "Sim/Projectiles/Projectile.h"
+#include "Sim/Units/BuildInfo.h"
 #include "Sim/Units/Unit.h"
 #include "Sim/Units/UnitDef.h"
 #include "Sim/Units/UnitHandler.h"
@@ -120,9 +121,11 @@ CLuaRules::CLuaRules()
 
 	haveDrawUnit    = HasCallIn(L, "DrawUnit");
 	haveDrawFeature = HasCallIn(L, "DrawFeature");
+	haveDrawShield  = HasCallIn(L, "DrawShield");
 
 	SetupUnsyncedFunction(L, "DrawUnit");
 	SetupUnsyncedFunction(L, "DrawFeature");
+	SetupUnsyncedFunction(L, "DrawShield");
 	SetupUnsyncedFunction(L, "RecvSkirmishAIMessage");
 
 	END_ITERATE_LUA_STATES();
@@ -209,6 +212,7 @@ bool CLuaRules::UnsyncedUpdateCallIn(lua_State *L, const string& name)
 {
 	     if (name == "DrawUnit"   ) { haveDrawUnit    = HasCallIn(L, "DrawUnit"   ); }
 	else if (name == "DrawFeature") { haveDrawFeature = HasCallIn(L, "DrawFeature"); }
+	else if (name == "DrawShield" ) { haveDrawShield  = HasCallIn(L, "DrawShield" ); }
 
 	return CLuaHandleSynced::UnsyncedUpdateCallIn(L, name);
 }
@@ -309,13 +313,13 @@ bool CLuaRules::AllowCommand(const CUnit* unit, const Command& cmd, bool fromSyn
 
 
 bool CLuaRules::AllowUnitCreation(const UnitDef* unitDef,
-                                  const CUnit* builder, const float3* pos)
+                                  const CUnit* builder, const BuildInfo* buildInfo)
 {
 	if (!haveAllowUnitCreation)
 		return true; // the call is not defined
 
 	LUA_CALL_IN_CHECK(L);
-	lua_checkstack(L, 8);
+	lua_checkstack(L, 9);
 	static const LuaHashString cmdStr("AllowUnitCreation");
 	if (!cmdStr.GetGlobalFunc(L))
 		return true; // the call is not defined
@@ -323,14 +327,16 @@ bool CLuaRules::AllowUnitCreation(const UnitDef* unitDef,
 	lua_pushnumber(L, unitDef->id);
 	lua_pushnumber(L, builder->id);
 	lua_pushnumber(L, builder->team);
-	if (pos) {
-		lua_pushnumber(L, pos->x);
-		lua_pushnumber(L, pos->y);
-		lua_pushnumber(L, pos->z);
+
+	if (buildInfo != NULL) {
+		lua_pushnumber(L, buildInfo->pos.x);
+		lua_pushnumber(L, buildInfo->pos.y);
+		lua_pushnumber(L, buildInfo->pos.z);
+		lua_pushnumber(L, buildInfo->buildFacing);
 	}
 
 	// call the function
-	if (!RunCallIn(cmdStr, pos ? 6 : 3, 1))
+	if (!RunCallIn(cmdStr, (buildInfo != NULL)? 7 : 3, 1))
 		return true;
 
 	// get the results
@@ -899,25 +905,25 @@ bool CLuaRules::DrawUnit(int unitID)
 
 	LUA_CALL_IN_CHECK(L);
 	lua_checkstack(L, 4);
+
 	static const LuaHashString cmdStr("DrawUnit");
+
 	if (!cmdStr.GetRegistryFunc(L))
 		return false;
 
-	const bool oldGLState = LuaOpenGL::IsDrawingEnabled();
+	const bool oldDrawState = LuaOpenGL::IsDrawingEnabled();
 	LuaOpenGL::SetDrawingEnabled(true);
 
 	lua_pushnumber(L, unitID);
 	lua_pushnumber(L, game->GetDrawMode());
 
 	const bool success = RunCallIn(cmdStr, 2, 1);
-
-	LuaOpenGL::SetDrawingEnabled(oldGLState);
+	LuaOpenGL::SetDrawingEnabled(oldDrawState);
 
 	if (!success)
 		return false;
-
 	if (!lua_isboolean(L, -1)) {
-		LOG_L(L_WARNING, "%s() bad return value", cmdStr.GetString().c_str());
+		LOG_L(L_WARNING, "%s() bad return-type (bool expected, got %s)", (cmdStr.GetString()).c_str(), lua_typename(L, lua_type(L, -1)));
 		lua_pop(L, 1);
 		return false;
 	}
@@ -934,25 +940,61 @@ bool CLuaRules::DrawFeature(int featureID)
 
 	LUA_CALL_IN_CHECK(L);
 	lua_checkstack(L, 4);
+
 	static const LuaHashString cmdStr("DrawFeature");
+
 	if (!cmdStr.GetRegistryFunc(L))
 		return false;
 
-	const bool oldGLState = LuaOpenGL::IsDrawingEnabled();
+	const bool oldDrawState = LuaOpenGL::IsDrawingEnabled();
 	LuaOpenGL::SetDrawingEnabled(true);
 
 	lua_pushnumber(L, featureID);
 	lua_pushnumber(L, game->GetDrawMode());
 
 	const bool success = RunCallIn(cmdStr, 2, 1);
-
-	LuaOpenGL::SetDrawingEnabled(oldGLState);
+	LuaOpenGL::SetDrawingEnabled(oldDrawState);
 
 	if (!success)
 		return false;
-
 	if (!lua_isboolean(L, -1)) {
-		LOG_L(L_WARNING, "%s() bad return value", cmdStr.GetString().c_str());
+		LOG_L(L_WARNING, "%s() bad return-type (bool expected, got %s)", (cmdStr.GetString()).c_str(), lua_typename(L, lua_type(L, -1)));
+		lua_pop(L, 1);
+		return false;
+	}
+
+	const bool retval = !!lua_toboolean(L, -1);
+	lua_pop(L, 1);
+	return retval;
+}
+
+bool CLuaRules::DrawShield(int unitID, int weaponID)
+{
+	if (!haveDrawShield)
+		return false;
+
+	LUA_CALL_IN_CHECK(L);
+	lua_checkstack(L, 5);
+
+	static const LuaHashString cmdStr("DrawShield");
+
+	if (!cmdStr.GetRegistryFunc(L))
+		return false;
+
+	const bool oldDrawState = LuaOpenGL::IsDrawingEnabled();
+	LuaOpenGL::SetDrawingEnabled(true);
+
+	lua_pushnumber(L, unitID);
+	lua_pushnumber(L, weaponID);
+	lua_pushnumber(L, game->GetDrawMode());
+
+	const bool success = RunCallIn(cmdStr, 3, 1);
+	LuaOpenGL::SetDrawingEnabled(oldDrawState);
+
+	if (!success)
+		return false;
+	if (!lua_isboolean(L, -1)) {
+		LOG_L(L_WARNING, "%s() bad return-type (bool expected, got %s)", (cmdStr.GetString()).c_str(), lua_typename(L, lua_type(L, -1)));
 		lua_pop(L, 1);
 		return false;
 	}
