@@ -104,20 +104,6 @@ static inline CUnit* ParseUnit(lua_State* L, const char* caller, int index)
 }
 
 
-static inline CUnit* ParseControlledUnit(lua_State* L,
-                                         const char* caller, int index)
-{
-	CUnit* unit = ParseUnit(L, caller, index);
-	if (unit == NULL) {
-		return NULL;
-	}
-	if (!unit->usingScriptMoveType) {
-		return NULL;
-	}
-	return unit;
-}
-
-
 static inline CScriptMoveType* ParseMoveType(lua_State* L,
                                              const char* caller, int index)
 {
@@ -128,7 +114,7 @@ static inline CScriptMoveType* ParseMoveType(lua_State* L,
 	if (!unit->usingScriptMoveType) {
 		return NULL;
 	}
-	return (CScriptMoveType*)unit->moveType;
+	return static_cast<CScriptMoveType*>(unit->moveType);
 }
 
 
@@ -556,8 +542,6 @@ static inline bool SetGenericMoveTypeValue(AMoveType* mt, const string& key, flo
 	// can't set goal here, need a different function that calls mt->SetGoal
 	// FIXME should use setter methods here and in other Set*MoveTypeValue functoins, but they mostly don't exist
 	if (key == "maxSpeed") {
-		if (value > 0)
-			mt->owner->maxSpeed = value / GAME_SPEED;
 		mt->SetMaxSpeed(value / GAME_SPEED); return true;
 	} else if (key == "maxWantedSpeed") {
 		mt->SetWantedMaxSpeed(value / GAME_SPEED); return true;
@@ -576,7 +560,6 @@ static inline bool SetGenericMoveTypeValue(AMoveType* mt, const string& key, boo
 /******************************************************************************/
 /* CStrafeAirMoveType handling */
 
-
 static inline bool SetAirMoveTypeValue(CStrafeAirMoveType* mt, const string& key, float value)
 {
 	if (SetGenericMoveTypeValue(mt, key, value))
@@ -617,20 +600,19 @@ static inline bool SetAirMoveTypeValue(CStrafeAirMoveType* mt, const string& key
 }
 
 
-static inline void SetSingleAirMoveTypeValue(lua_State *L, int keyidx, int validx, CStrafeAirMoveType *moveType)
+static inline void SetSingleAirMoveTypeValue(lua_State* L, int keyidx, int validx, CStrafeAirMoveType* moveType)
 {
 	const string key = lua_tostring(L, keyidx);
-	bool failedToAssign = false;
+	bool assigned = true;
+
 	if (lua_isnumber(L, validx)) {
-		const float value = lua_tofloat(L, validx);
-		failedToAssign = !SetAirMoveTypeValue(moveType, key, value);
+		assigned = SetAirMoveTypeValue(moveType, key, lua_tofloat(L, validx));
 	} else if (lua_isboolean(L, validx)) {
-		bool value = lua_toboolean(L, validx);
-		failedToAssign = !SetAirMoveTypeValue(moveType, key, value);
+		assigned = SetAirMoveTypeValue(moveType, key, lua_toboolean(L, validx));
 	}
-	if (failedToAssign) {
-		LOG_L(L_WARNING, "Can not assign key \"%s\" to AirMoveType",
-				key.c_str());
+
+	if (!assigned) {
+		LOG_L(L_WARNING, "Can not assign key \"%s\" to AirMoveType", key.c_str());
 	}
 }
 
@@ -663,7 +645,6 @@ int LuaSyncedMoveCtrl::SetAirMoveTypeData(lua_State *L)
 /******************************************************************************/
 /* CGroundMoveType handling */
 
-
 static inline bool SetGroundMoveTypeValue(CGroundMoveType* mt, const string& key, float value)
 {
 	if (SetGenericMoveTypeValue(mt, key, value))
@@ -678,7 +659,6 @@ static inline bool SetGroundMoveTypeValue(CGroundMoveType* mt, const string& key
 	} else if (key == "maxReverseSpeed") {
 		// use setter?
 		mt->maxReverseSpeed = value / GAME_SPEED;
-		mt->owner->maxReverseSpeed = value / GAME_SPEED;
 		return true;
 	} else if (key == "wantedSpeed") {
 		// use setter?
@@ -698,20 +678,19 @@ static inline bool SetGroundMoveTypeValue(CGroundMoveType* mt, const string& key
 	return false;
 }
 
-static inline void SetSingleGroundMoveTypeValue(lua_State *L, int keyidx, int validx, CGroundMoveType *moveType)
+static inline void SetSingleGroundMoveTypeValue(lua_State* L, int keyidx, int validx, CGroundMoveType* moveType)
 {
 	const string key = lua_tostring(L, keyidx);
-	bool failedToAssign = false;
+	bool assigned = true;
+
 	if (lua_isnumber(L, validx)) {
-		const float value = lua_tofloat(L, validx);
-		failedToAssign = !SetGroundMoveTypeValue(moveType, key, value);
+		assigned = SetGroundMoveTypeValue(moveType, key, lua_tofloat(L, validx));
 	} else if (lua_isboolean(L, validx)) {
-		bool value = lua_toboolean(L, validx);
-		failedToAssign = !SetGroundMoveTypeValue(moveType, key, value);
+		assigned = SetGroundMoveTypeValue(moveType, key, lua_toboolean(L, validx));
 	}
-	if (failedToAssign) {
-		LOG_L(L_WARNING, "Can not assign key \"%s\" to GroundMoveType",
-				key.c_str());
+
+	if (!assigned) {
+		LOG_L(L_WARNING, "Can not assign key \"%s\" to GroundMoveType", key.c_str());
 	}
 }
 
@@ -745,13 +724,11 @@ int LuaSyncedMoveCtrl::SetGroundMoveTypeData(lua_State *L)
 /******************************************************************************/
 /* CHoverAirMoveType handling */
 
-
-
 static inline bool SetHoverAirMoveTypeValue(CHoverAirMoveType* mt, const string& key, float value)
 {
 	if (SetGenericMoveTypeValue(mt, key, value)) {
 		if (key == "maxSpeed") {
-			mt->brakeDistance = (mt->maxSpeed * mt->maxSpeed) / mt->decRate;
+			mt->brakeDistance = (mt->GetMaxSpeed() * mt->GetMaxSpeed()) / mt->decRate;
 		}
 		return true;
 	}
@@ -764,7 +741,7 @@ static inline bool SetHoverAirMoveTypeValue(CHoverAirMoveType* mt, const string&
 		mt->accRate = value; return true;
 	} else if (key == "decRate") {
 		mt->decRate = value;
-		mt->brakeDistance = (mt->maxSpeed * mt->maxSpeed) / mt->decRate;
+		mt->brakeDistance = (mt->GetMaxSpeed() * mt->GetMaxSpeed()) / mt->decRate;
 		return true;
 	} else if (key == "altitudeRate") {
 		mt->altitudeRate = value; return true;
