@@ -7,10 +7,10 @@
 #include "LuaInclude.h"
 
 #include "LuaHandle.h"
-#include "Game/UI/LuaUI.h"
 #include "LuaGaia.h"
 #include "LuaRules.h"
 #include "LuaHashString.h"
+#include "LuaUI.h"
 #include "LuaUtils.h"
 
 #include <set>
