@@ -110,6 +110,7 @@ bool LuaUnsyncedCtrl::PushEntries(lua_State* L)
 	lua_rawset(L, -3)
 
 	REGISTER_LUA_CFUNC(Echo);
+	REGISTER_LUA_CFUNC(Log);
 
 	REGISTER_LUA_CFUNC(SendMessage);
 	REGISTER_LUA_CFUNC(SendMessageToPlayer);
@@ -423,6 +424,11 @@ int LuaUnsyncedCtrl::Echo(lua_State* L)
 	return LuaUtils::Echo(L);
 }
 
+int LuaUnsyncedCtrl::Log(lua_State* L)
+{
+	return LuaUtils::Log(L);
+}
+
 static string ParseMessage(lua_State* L, const string& msg)
 {
 	string::size_type start = msg.find("<PLAYER");
@@ -2107,7 +2113,7 @@ int LuaUnsyncedCtrl::Restart(lua_State* L)
 		scriptfile << script;
 		scriptfile.close();
 
-		processArgs.push_back(Quote(scriptFullName));
+		processArgs.push_back(scriptFullName);
 	}
 
 #ifdef _WIN32
@@ -2904,15 +2910,18 @@ int LuaUnsyncedCtrl::SendSkirmishAIMessage(lua_State* L) {
 
 	std::vector<const char*> outData;
 
-	lua_checkstack(L, outData.size() + 1);
+	lua_checkstack(L, 2);
 	lua_pushboolean(L, eoh->SendLuaMessages(aiTeam, inData, outData));
+	lua_createtable(L, outData.size(), 0);
 
-	// push the response(s)
+	// push the AI response(s)
 	for (unsigned int n = 0; n < outData.size(); n++) {
+		lua_pushnumber(L, n + 1);
 		lua_pushstring(L, outData[n]);
+		lua_rawset(L, -3);
 	}
 
-	return (outData.size() + 1);
+	return 2;
 }
 
 /******************************************************************************/
@@ -2932,4 +2941,3 @@ int LuaUnsyncedCtrl::ClearWatchDogTimer(lua_State* L) {
 
 	return 0;
 }
-
