@@ -1,16 +1,18 @@
 /* This file is part of the Spring engine (GPL v2 or later), see LICENSE.html */
 
-#ifndef LUAZIP_H_
-#define LUAZIP_H_
-
+#ifndef _LUA_ZIP_H_
+#define _LUA_ZIP_H_
 
 #include <string>
 
-
-typedef void* zipFile;
-class CArchiveBase;
+class IArchive;
 struct lua_State;
 
+#ifndef zipFile
+	// might be defined through zip.h already
+	typedef void* zipFile;
+#endif
+
 
 class LuaZipFileWriter {
 public:
@@ -37,7 +39,7 @@ public:
 
 	static bool PushSynced(lua_State* L);
 	static bool PushUnsynced(lua_State* L);
-	static bool PushNew(lua_State* L, const std::string& filename, CArchiveBase* archive);
+	static bool PushNew(lua_State* L, const std::string& filename, IArchive* archive);
 
 private: // metatable methods
 	static bool CreateMetatable(lua_State* L);
@@ -48,4 +50,4 @@ private: // metatable methods
 };
 
 
-#endif /* LUAZIP_H_ */
+#endif /* _LUA_ZIP_H_ */
