@@ -1,9 +1,10 @@
 /* This file is part of the Spring engine (GPL v2 or later), see LICENSE.html */
 
-#ifndef __BASE_GROUND_DRAWER_H__
-#define __BASE_GROUND_DRAWER_H__
+#ifndef _BASE_GROUND_DRAWER_H
+#define _BASE_GROUND_DRAWER_H
 
 #include <map>
+#include "MapDrawPassTypes.h"
 #include "Rendering/GL/myGL.h"
 #include "Rendering/GL/LightHandler.h"
 #include "Rendering/GL/PBO.h"
@@ -14,16 +15,6 @@ class CHeightLinePalette;
 class CBaseGroundTextures;
 class CCamera;
 
-struct DrawPass {
-	enum e {
-		Normal,
-		Shadow,
-		WaterReflection,
-		WaterRefraction,
-		UnitReflection
-	};
-};
-
 class CBaseGroundDrawer
 {
 public:
@@ -125,4 +116,4 @@ public:
 	CBaseGroundTextures* groundTextures;
 };
 
-#endif // __BASE_GROUND_DRAWER__
+#endif // _BASE_GROUND_DRAWER_H
