@@ -15,6 +15,7 @@
 #include "TerrainTexture.h"
 #include "TerrainNode.h"
 #include "System/FileSystem/FileHandler.h"
+#include "System/FileSystem/FileSystem.h"
 #include "System/Log/ILog.h"
 #include "System/Util.h"
 #include <assert.h>
@@ -161,7 +162,7 @@ namespace terrain {
 		int vertexSize = GetVertexSize();
 
 		// Bind the vertex buffer components
-		Vector3* vbuf = (Vector3*) renderData->vertexBuffer.Bind();
+		Vector3* vbuf = static_cast<Vector3*>(renderData->vertexBuffer.Bind());
 		glEnableClientState(GL_VERTEX_ARRAY);
 		glVertexPointer(3, GL_FLOAT, vertexSize, vbuf ++);
 		if (vda & VRT_Normal)
@@ -930,7 +931,7 @@ namespace terrain {
 			throw content_error("No heightmap given");
 		}
 
-		std::string extension = heightMapName.substr(heightMapName.length() - 3, heightMapName.length());
+		std::string extension = FileSystem::GetExtension(heightMapName);
 
 		if (extension == "raw") {
 			heightmap = LoadHeightmapFromRAW(heightMapName, cb);
@@ -938,7 +939,7 @@ namespace terrain {
 			heightmap = LoadHeightmapFromImage(heightMapName, cb);
 		}
 
-		if (heightmap->dataSynced == NULL) {
+		if (heightmap->dataSynced.empty()) {
 			throw content_error("Failed to load heightmap " + heightMapName);
 		}
 
@@ -1129,8 +1130,8 @@ namespace terrain {
 		CacheTextures();
 	}
 
-	const float* Terrain::GetCornerHeightMapSynced() const { return heightmap->dataSynced; }
-	      float* Terrain::GetCornerHeightMapUnsynced()     { return heightmap->dataUnsynced; }
+	std::vector<float>* Terrain::GetCornerHeightMapSynced()   { return &heightmap->dataSynced; }
+	std::vector<float>* Terrain::GetCornerHeightMapUnsynced() { return &heightmap->dataUnsynced; }
 
 
 	void Terrain::SetShadowParams(ShadowMapParams* smp)
