@@ -2,25 +2,14 @@
 
 #include "LegacyMeshDrawer.h"
 #include "Game/Camera.h"
-#include "Map/MapInfo.h"
-#include "Map/ReadMap.h"
 #include "Map/SMF/SMFReadMap.h"
 #include "Map/SMF/SMFGroundDrawer.h"
-#include "Map/SMF/SMFGroundTextures.h"
-#include "Rendering/GroundDecalHandler.h"
 #include "Rendering/GlobalRendering.h"
 #include "Rendering/ProjectileDrawer.h"
-#include "Rendering/ShadowHandler.h"
-#include "Rendering/Env/ISky.h"
-#include "Rendering/Env/CubeMapHandler.h"
 #include "Rendering/GL/myGL.h"
 #include "Rendering/GL/VertexArray.h"
-#include "Rendering/Shaders/ShaderHandler.h"
-#include "Rendering/Shaders/Shader.h"
-#include "Sim/Misc/SmoothHeightMesh.h"
 #include "System/Config/ConfigHandler.h"
 #include "System/FastMath.h"
-#include "System/Log/ILog.h"
 #include "System/myMath.h"
 #include "System/mmgr.h"
 #include "System/Util.h"
