@@ -8,12 +8,7 @@
 
 class CSMFReadMap;
 class IMeshDrawer;
-
-
-namespace Shader {
-	struct IProgramObject;
-}
-
+struct ISMFRenderState;
 
 enum {
 	SMF_MESHDRAWER_LEGACY = 0,
@@ -36,23 +31,25 @@ public:
 	void Draw(const DrawPass::e& drawPass);
 	void DrawShadowPass();
 
-	// for non-GLSL clients
-	void SetupBaseDrawPass(void) { smfShaderCurrARB = smfShaderBaseARB; }
-	void SetupReflDrawPass(void) { smfShaderCurrARB = smfShaderReflARB; }
-	void SetupRefrDrawPass(void) { smfShaderCurrARB = smfShaderRefrARB; }
-
 	void Update();
 	void UpdateSunDir();
+	void SetupBigSquare(const int bigSquareX, const int bigSquareY);
+
+	// for ARB-only clients
+	void SetupBaseDrawPass(void);
+	void SetupReflDrawPass(void);
+	void SetupRefrDrawPass(void);
 
 	void IncreaseDetail();
 	void DecreaseDetail();
 	int GetGroundDetail(const DrawPass::e& drawPass = DrawPass::Normal) const;
 
-	GL::LightHandler* GetLightHandler() { return &lightHandler; }
+	const CSMFReadMap* GetReadMap() const { return smfMap; }
+	      CSMFReadMap* GetReadMap()       { return smfMap; }
+	const GL::LightHandler* GetLightHandler() const { return &lightHandler; }
+	      GL::LightHandler* GetLightHandler()       { return &lightHandler; }
 
-	void SetupBigSquare(const int bigSquareX, const int bigSquareY);
-
-	void SwitchMeshDrawer(int mode = -1);
+	IMeshDrawer* SwitchMeshDrawer(int mode = -1);
 
 private:
 	bool LoadMapShaders();
@@ -71,18 +68,11 @@ protected:
 	GLuint waterPlaneCamOutDispList;
 	GLuint waterPlaneCamInDispList;
 
-	Shader::IProgramObject* smfShaderBaseARB;   // default (V+F) SMF ARB shader
-	Shader::IProgramObject* smfShaderReflARB;   // shader (V+F) for the DynamicWater reflection pass
-	Shader::IProgramObject* smfShaderRefrARB;   // shader (V+F) for the DynamicWater refraction pass
-	Shader::IProgramObject* smfShaderCurrARB;   // currently active ARB shader
-	Shader::IProgramObject* smfShaderDefGLSL;   // GLSL shader used when shadows are on
-	Shader::IProgramObject* smfShaderAdvGLSL;   // GLSL shader used when shadows are off
-	Shader::IProgramObject* smfShaderCurGLSL;   // currently active GLSL shader
+	ISMFRenderState* smfRenderStateSSP; // default shader-driven rendering path
+	ISMFRenderState* smfRenderStateFFP; // fallback shader-less rendering path
+	ISMFRenderState* smfRenderState;
 
 	GL::LightHandler lightHandler;
-
-	bool useShaders;
-	bool waterDrawn;
 };
 
 #endif // _SMF_GROUND_DRAWER_H_
