@@ -8,6 +8,7 @@
 #include "Game/GameVersion.h"
 #include "System/Log/ILog.h"
 #include "System/SpringApp.h"
+#include "System/Platform/Threading.h"
 
 #include <windows.h>
 
@@ -404,6 +405,8 @@ bool CAVIGenerator::readOpenglPixelDataThreaded() {
 
 void CAVIGenerator::AVIGeneratorThreadProc() {
 
+	Threading::SetThreadName("avi-recorder");
+
 	//Run init from the encoding thread because custom controls displayed by codecs
 	//sends window messages to the thread it started from, thus deadlocking if
 	//sending to the main thread whilst it is blocking on readOpenglPixelDataThreaded().
