@@ -37,9 +37,8 @@ DebugDrawerAI* DebugDrawerAI::GetInstance() {
 
 
 void DebugDrawerAI::Draw() {
-#if defined(USE_GML) && GML_ENABLE_SIM
-	return;
-#endif
+	if (GML::SimEnabled())
+		return;
 	if (!draw || !gu->spectating) {
 		return;
 	}
@@ -393,9 +392,8 @@ int DebugDrawerAI::TexSet::AddTexture(const float* data, int w, int h) {
 }
 
 void DebugDrawerAI::TexSet::UpdateTexture(int texHandle, const float* data, int x, int y, int w, int h) {
-#if defined(USE_GML) && GML_ENABLE_SIM
-	return;
-#endif
+	if (GML::SimEnabled())
+		return;
 	std::map<int, TexSet::Texture*>::iterator it = textures.find(texHandle);
 
 	if (it == textures.end()) {
@@ -488,9 +486,8 @@ DebugDrawerAI::TexSet::Texture::Texture(int w, int h, const float* data):
 	labelWidth(0.0f),
 	labelHeight(0.0f)
 {
-#if defined(USE_GML) && GML_ENABLE_SIM
-	return;
-#endif
+	if (GML::SimEnabled())
+		return;
 	const int intFormat = GL_RGBA;  // note: data only holds the red component
 	const int extFormat = GL_RED;
 	const int dataType  = GL_FLOAT;
@@ -506,9 +503,8 @@ DebugDrawerAI::TexSet::Texture::Texture(int w, int h, const float* data):
 }
 
 DebugDrawerAI::TexSet::Texture::~Texture() {
-#if defined(USE_GML) && GML_ENABLE_SIM
-	return;
-#endif
+	if (GML::SimEnabled())
+		return;
 	glDeleteTextures(1, &id);
 }
 
