@@ -17,6 +17,13 @@ public:
 	void DrawAll() const;
 	void UpdateExtraTexture(int, int, int, int, unsigned char*) const;
 
+	enum BuildSquareStatus {
+		NOLOS          = 0,
+		FREE           = 1,
+		OBJECTBLOCKED  = 2,
+		TERRAINBLOCKED = 3,
+	};
+
 private:
 	void Draw() const;
 	void Draw(const CPathFinderDef*) const;
