@@ -1,8 +1,8 @@
 /* This file is part of the Spring engine (GPL v2 or later), see LICENSE.html */
 
 
-#ifndef __FARTEXTURE_HANDLER_H__
-#define __FARTEXTURE_HANDLER_H__
+#ifndef _FARTEXTURE_HANDLER_H
+#define _FARTEXTURE_HANDLER_H
 
 #include <vector>
 #include "System/Vec2.h"
@@ -39,12 +39,14 @@ private:
 	unsigned int farTextureID;
 	unsigned int usedFarTextures;
 
-	float2 GetTextureCoords(const int& farTextureNum, const int& orientation);
+	bool HaveFarIcon(const CSolidObject* obj) const;
+	bool CheckResizeAtlas();
+	float2 GetTextureCoords(const int& farTextureNum, const int& orientation) const;
 	void DrawFarTexture(const CSolidObject* obj, CVertexArray*);
-	int2 GetTextureCoordsInt(const int& farTextureNum, const int& orientation);
+	int2 GetTextureCoordsInt(const int& farTextureNum, const int& orientation) const;
 	void CreateFarTexture(const CSolidObject* obj);
 };
 
 extern CFarTextureHandler* farTextureHandler;
 
-#endif // __FARTEXTURE_HANDLER_H__
+#endif // _FARTEXTURE_HANDLER_H
