@@ -4,7 +4,7 @@
 
 struct IPathDrawer {
 	virtual ~IPathDrawer() {}
-	virtual void Draw() const {}
+	virtual void DrawAll() const {}
 
 	virtual void UpdateExtraTexture(int, int, int, int, unsigned char*) const {}
 
@@ -15,3 +15,4 @@ struct IPathDrawer {
 extern IPathDrawer* pathDrawer;
 
 #endif
+
