@@ -1,32 +1,34 @@
 /* This file is part of the Spring engine (GPL v2 or later), see LICENSE.html */
 
-#include "StdAfx.h"
+#include "3DOParser.h"
+
+#include "System/mmgr.h"
+
+#include "Game/GlobalUnsynced.h"
+#include "Rendering/GL/myGL.h"
+#include "Rendering/GL/VertexArray.h"
+#include "Sim/Misc/CollisionVolume.h"
+#include "Sim/Projectiles/ProjectileHandler.h"
+#include "System/Util.h"
+#include "System/Exceptions.h"
+#include "System/Matrix44f.h"
+#include "System/Log/ILog.h"
+#include "System/FileSystem/VFSHandler.h"
+#include "System/FileSystem/FileHandler.h"
+#include "System/FileSystem/SimpleParser.h"
+#include "System/Platform/byteorder.h"
+
 #include <vector>
 #include <set>
 #include <algorithm>
 #include <cctype>
 #include <locale>
 #include <stdexcept>
-#include "mmgr.h"
-
-#include "3DOParser.h"
-#include "Rendering/GL/myGL.h"
-#include "Rendering/GL/VertexArray.h"
-#include "Sim/Misc/CollisionVolume.h"
-#include "Sim/Projectiles/ProjectileHandler.h"
-#include "Sim/Units/COB/CobInstance.h"
-#include "System/Util.h"
-#include "System/Exceptions.h"
-#include "System/GlobalUnsynced.h"
-#include "System/LogOutput.h"
-#include "System/Matrix44f.h"
-#include "System/FileSystem/VFSHandler.h"
-#include "System/FileSystem/FileHandler.h"
-#include "System/FileSystem/SimpleParser.h"
-#include "System/Platform/byteorder.h"
 #include <boost/cstdint.hpp>
 
-using namespace std;
+using std::list;
+using std::map;
+
 
 static const float  scaleFactor = 1 / (65536.0f);
 static const float3 DownVector  = -UpVector;
@@ -117,11 +119,12 @@ C3DOParser::C3DOParser()
 		teamtex.insert(StringToLower(parser.GetLine()));
 	}
 
+	curOffset = 0;
 	fileBuf = NULL;
 }
 
 
-S3DModel* C3DOParser::Load(const string& name)
+S3DModel* C3DOParser::Load(const std::string& name)
 {
 	CFileHandler file(name);
 	if (!file.FileExists()) {
@@ -143,13 +146,13 @@ S3DModel* C3DOParser::Load(const string& name)
 		model->name = name;
 		model->type = MODELTYPE_3DO;
 		model->textureType = 0;
-		model->numobjects  = 0;
+		model->numPieces  = 0;
 		model->mins = DEF_MIN_SIZE;
 		model->maxs = DEF_MAX_SIZE;
 		model->radius = 0.0f;
 		model->height = 0.0f;
 
-	S3DOPiece* rootPiece = LoadPiece(model, 0, NULL, &model->numobjects);
+	S3DOPiece* rootPiece = LoadPiece(model, 0, NULL, &model->numPieces);
 
 	model->SetRootPiece(rootPiece);
 	model->radius =
@@ -214,7 +217,7 @@ void C3DOParser::GetPrimitives(S3DOPiece* obj, int pos, int num, int excludePrim
 		list<int> orderVert;
 		for(int b=0;b<sp.numVertex;b++){
 			SimStreamRead(&w,2);
-			w = swabword(w);
+			swabWordInPlace(w);
 			sp.vertices.push_back(w);
 			orderVert.push_back(w);
 		}
@@ -238,8 +241,8 @@ void C3DOParser::GetPrimitives(S3DOPiece* obj, int pos, int num, int excludePrim
 		}
 
 		if ((sp.texture = texturehandler3DO->Get3DOTexture(texName)) == NULL) {
-			LogObject() << "[" << __FUNCTION__ << "] ";
-			LogObject() << "unknown 3DO texture \"" << texName << "\" for piece \"" << obj->name << "\"\n";
+			LOG_L(L_WARNING, "[%s] unknown 3DO texture \"%s\" for piece \"%s\"",
+					__FUNCTION__, texName.c_str(), obj->name.c_str());
 
 			// assign a dummy texture (the entire atlas)
 			sp.texture = texturehandler3DO->Get3DOTexture("___dummy___");
@@ -291,7 +294,7 @@ void C3DOParser::GetPrimitives(S3DOPiece* obj, int pos, int num, int excludePrim
 
 		for (int b = 0; b < sp.numVertex; b++) {
 			SimStreamRead(&w, 2);
-			w = swabword(w);
+			swabWordInPlace(w);
 			obj->vertices[w].prims.push_back(obj->prims.size() - 1);
 		}
 	}
@@ -300,7 +303,7 @@ void C3DOParser::GetPrimitives(S3DOPiece* obj, int pos, int num, int excludePrim
 
 void C3DOParser::CalcNormals(S3DOPiece* o) const
 {
-	for (std::vector<S3DOPrimitive>::iterator ps = o->prims.begin(); ps != o->prims.end(); ps++) {
+	for (std::vector<S3DOPrimitive>::iterator ps = o->prims.begin(); ps != o->prims.end(); ++ps) {
 		for (int a = 0; a < ps->numVertex; ++a) {
 			S3DOVertex* vertex = &o->vertices[ps->vertices[a]];
 			float3 vnormal(0.0f, 0.0f, 0.0f);
@@ -383,7 +386,7 @@ S3DOPiece* C3DOParser::LoadPiece(S3DModel* model, int pos, S3DOPiece* parent, in
 
 	piece->radius = math::sqrt(radiusSq);
 	piece->relMidPos = cvOffset * 0.5f;
-	piece->colvol = new CollisionVolume("box", cvScales, cvOffset * 0.5f, CollisionVolume::COLVOL_HITTEST_CONT);
+	piece->SetCollisionVolume(new CollisionVolume("box", cvScales, cvOffset * 0.5f, CollisionVolume::COLVOL_HITTEST_CONT));
 
 
 	if (me.OffsetToChildObject > 0) {
@@ -412,7 +415,7 @@ void C3DOParser::SimStreamRead(void* buf, int length)
 
 
 
-void S3DOPiece::DrawList() const
+void S3DOPiece::DrawForList() const
 {
 	if (isEmpty) {
 		return;
