@@ -96,27 +96,21 @@ S3DModel* CAssParser::Load(const std::string& modelFilePath)
 	//! LOAD METADATA
 	//! Load the lua metafile. This contains properties unique to Spring models and must return a table
 	std::string metaFileName = modelFilePath + ".lua";
-	CFileHandler* metaFile = new CFileHandler(metaFileName);
-	if (!metaFile->FileExists()) {
+	if (!FileSystem::FileExists(metaFileName)) {
 		//! Try again without the model file extension
 		metaFileName = modelPath + '/' + modelName + ".lua";
-		metaFile = new CFileHandler(metaFileName);
 	}
 	LuaParser metaFileParser(metaFileName, SPRING_VFS_MOD_BASE, SPRING_VFS_ZIP);
-	if (!metaFileParser.Execute()) {
-		if (!metaFile->FileExists()) {
-			LOG_S(LOG_SECTION_MODEL, "No meta-file '%s'. Using defaults.",
-					metaFileName.c_str());
-		} else {
-			LOG_SL(LOG_SECTION_MODEL, L_ERROR, "'%s': %s. Using defaults.",
-					metaFileName.c_str(), metaFileParser.GetErrorLog().c_str());
-		}
+	if (!FileSystem::FileExists(metaFileName)) {
+		LOG_S(LOG_SECTION_MODEL, "No meta-file '%s'. Using defaults.", metaFileName.c_str());
+	} else if (!metaFileParser.Execute()) {
+		LOG_SL(LOG_SECTION_MODEL, L_ERROR, "'%s': %s. Using defaults.", metaFileName.c_str(), metaFileParser.GetErrorLog().c_str());
 	}
+
 	//! Get the (root-level) model table
 	const LuaTable& metaTable = metaFileParser.GetRoot();
 	if (metaTable.IsValid()) {
-		LOG_S(LOG_SECTION_MODEL, "Found valid model metadata in '%s'",
-				metaFileName.c_str());
+		LOG_S(LOG_SECTION_MODEL, "Found valid model metadata in '%s'", metaFileName.c_str());
 	}
 
 
