@@ -1,19 +1,30 @@
 /* This file is part of the Spring engine (GPL v2 or later), see LICENSE.html */
 
-#include "StdAfx.h"
-#include <cassert>
-#include <sstream>
 #include <boost/regex.hpp>
 
 #include "OBJParser.h"
+
 #include "Lua/LuaParser.h"
 #include "Rendering/GL/VertexArray.h"
 #include "Rendering/Textures/S3OTextureHandler.h"
 #include "Sim/Misc/CollisionVolume.h"
 #include "System/Exceptions.h"
-#include "System/LogOutput.h"
+#include "System/Log/ILog.h"
 #include "System/FileSystem/FileHandler.h"
 
+#include <cassert>
+#include <sstream>
+
+#define LOG_SECTION_OBJ_PARSER "OBJParser"
+LOG_REGISTER_SECTION_GLOBAL(LOG_SECTION_OBJ_PARSER)
+
+// use the specific section for all LOG*() calls in this source file
+#ifdef LOG_SECTION_CURRENT
+	#undef LOG_SECTION_CURRENT
+#endif
+#define LOG_SECTION_CURRENT LOG_SECTION_OBJ_PARSER
+
+
 static const float3 DEF_MIN_SIZE( 10000.0f,  10000.0f,  10000.0f);
 static const float3 DEF_MAX_SIZE(-10000.0f, -10000.0f, -10000.0f);
 
@@ -46,7 +57,7 @@ S3DModel* COBJParser::Load(const std::string& modelFileName)
 		model->name = modelFileName;
 		model->type = MODELTYPE_OBJ;
 		model->textureType = 0;
-		model->numobjects = 0;
+		model->numPieces = 0;
 		model->radius = modelTable.GetFloat("radius", 0.0f);
 		model->height = modelTable.GetFloat("height", 0.0f);
 		model->relMidPos = modelTable.GetFloat3("midpos", ZeroVector);
@@ -62,7 +73,7 @@ S3DModel* COBJParser::Load(const std::string& modelFileName)
 	modelFile.LoadStringData(modelData);
 
 	if (ParseModelData(model, modelData, modelTable)) {
-		assert(model->numobjects == modelTable.GetInt("numpieces", 0));
+		assert(model->numPieces == modelTable.GetInt("numpieces", 0));
 		return model;
 	} else {
 		delete model;
@@ -143,7 +154,8 @@ bool COBJParser::ParseModelData(S3DModel* model, const std::string& modelData, c
 				// ignore groups ('g'), smoothing groups ('s'),
 				// and materials ("mtllib", "usemtl") for now
 				// (s-groups are obsolete with vertex normals)
-				logOutput.Print("[OBJParser] failed to parse line \"%s\" for model \"%s\"", line.c_str(), model->name.c_str());
+				LOG_L(L_WARNING, "Failed to parse line \"%s\" for model \"%s\"",
+						line.c_str(), model->name.c_str());
 
 				prevReadIdx = currReadIdx + 1;
 				continue;
@@ -168,7 +180,7 @@ bool COBJParser::ParseModelData(S3DModel* model, const std::string& modelData, c
 					piece->name = pieceName;
 					pieceMap[pieceName] = piece;
 
-					model->numobjects += 1;
+					model->numPieces += 1;
 				} break;
 
 				case 'v': {
@@ -273,7 +285,9 @@ bool COBJParser::ParseModelData(S3DModel* model, const std::string& modelData, c
 
 						piece->AddTriangle(triangle);
 					} else {
-						logOutput.Print("[OBJParser] illegal face-element indices on line \"%s\" for model \"%s\"", line.c_str(), model->name.c_str());
+						LOG_L(L_WARNING,
+								"Illegal face-element indices on line \"%s\" for model \"%s\"",
+								line.c_str(), model->name.c_str());
 					}
 				} break;
 
@@ -434,7 +448,7 @@ void COBJParser::BuildModelPieceTreeRec(
 		(piece->maxs - (localPieceOffsets? piece->goffset: piece->offset)) +
 		(piece->mins - (localPieceOffsets? piece->goffset: piece->offset));
 
-	piece->colvol = new CollisionVolume("box", cvScales, cvOffset * 0.5f, CollisionVolume::COLVOL_HITTEST_CONT);
+	piece->SetCollisionVolume(new CollisionVolume("box", cvScales, cvOffset * 0.5f, CollisionVolume::COLVOL_HITTEST_CONT));
 
 
 	std::vector<int> childPieceNumbers;
@@ -498,7 +512,7 @@ void COBJParser::BuildModelPieceTreeRec(
 
 
 
-void SOBJPiece::DrawList() const
+void SOBJPiece::DrawForList() const
 {
 	if (isEmpty) {
 		return;
