@@ -1,7 +1,7 @@
 /* This file is part of the Spring engine (GPL v2 or later), see LICENSE.html */
 
-#ifndef S3OPARSER_H
-#define S3OPARSER_H
+#ifndef S3O_PARSER_H
+#define S3O_PARSER_H
 
 #include <map>
 #include "IModelParser.h"
@@ -15,21 +15,15 @@ struct SS3OVertex {
 };
 
 struct SS3OPiece: public S3DModelPiece {
-	SS3OPiece() { parent = NULL; }
-	~SS3OPiece() {
-		vertices.clear();
-		vertexDrawOrder.clear();
+	SS3OPiece() { parent = NULL; primitiveType=0; }
 
-		sTangents.clear();
-		tTangents.clear();
-	}
-
-	void DrawList() const;
+	void DrawForList() const;
 	void SetMinMaxExtends();
 	void SetVertexTangents();
 	int GetVertexCount() const { return vertices.size(); }
 	const float3& GetVertexPos(int idx) const { return vertices[idx].pos; }
-	void Shatter(float, int, int, const float3&, const float3&) const;
+	void Shatter(float pieceChance, int texType, int team, const float3& pos,
+			const float3& speed) const;
 
 	std::vector<SS3OVertex> vertices;
 	std::vector<unsigned int> vertexDrawOrder;
@@ -49,7 +43,7 @@ struct SS3OTriangle {
 };
 
 
-enum {S3O_PRIMTYPE_TRIANGLES, S3O_PRIMTYPE_TRIANGLE_STRIP, S3O_PRIMTYPE_QUADS};
+enum {S3O_PRIMTYPE_TRIANGLES = 0, S3O_PRIMTYPE_TRIANGLE_STRIP = 1, S3O_PRIMTYPE_QUADS = 2};
 
 class CS3OParser: public IModelParser
 {
@@ -60,4 +54,4 @@ private:
 	SS3OPiece* LoadPiece(S3DModel*, SS3OPiece*, unsigned char* buf, int offset);
 };
 
-#endif /* S3OPARSER_H */
+#endif /* S3O_PARSER_H */
