@@ -1,7 +1,7 @@
 /* This file is part of the Spring engine (GPL v2 or later), see LICENSE.html */
 
-#ifndef _3DOTEXTUREHANDLER_H
-#define _3DOTEXTUREHANDLER_H
+#ifndef _3DO_TEXTURE_HANDLER_H
+#define _3DO_TEXTURE_HANDLER_H
 
 #include <map>
 #include <string>
@@ -28,8 +28,8 @@ public:
 
 	UnitTexture* Get3DOTexture(const std::string& name);
 
-	unsigned int GetAtlasTex1ID() const  { return atlas3do1; }
-	unsigned int GetAtlasTex2ID() const  { return atlas3do2; }
+	unsigned int GetAtlasTex1ID() const { return atlas3do1; }
+	unsigned int GetAtlasTex2ID() const { return atlas3do2; }
 	unsigned int GetAtlasTexSizeX() const { return bigTexX; }
 	unsigned int GetAtlasTexSizeY() const { return bigTexY; }
 	const std::map<std::string, UnitTexture*>& GetAtlasTextures() const { return textures; }
@@ -41,9 +41,9 @@ private:
 	int bigTexX;
 	int bigTexY;
 
-	TexFile* CreateTex(const std::string& name, const std::string& name2, bool teamcolor = false);
+	static TexFile* CreateTex(const std::string& name, const std::string& name2, bool teamcolor = false);
 };
 
 extern C3DOTextureHandler* texturehandler3DO;
 
-#endif /* _3DOTEXTUREHANDLER_H */
+#endif /* _3DO_TEXTURE_HANDLER_H */
