@@ -1,7 +1,7 @@
 /* This file is part of the Spring engine (GPL v2 or later), see LICENSE.html */
 
-#ifndef __BITMAP_H__
-#define __BITMAP_H__
+#ifndef _BITMAP_H
+#define _BITMAP_H
 
 #include <string>
 #ifndef BITMAP_NO_OPENGL
@@ -14,7 +14,7 @@
 struct SDL_Surface;
 
 
-class CBitmap  
+class CBitmap
 {
 public:
 	CBitmap(const unsigned char* data,int xsize,int ysize);
@@ -32,13 +32,8 @@ public:
 	bool LoadGrayscale(std::string const& filename);
 	bool Save(std::string const& filename, bool opaque = true) const;
 
-#ifndef BITMAP_NO_OPENGL
 	const unsigned int CreateTexture(bool mipmaps = false) const;
 	const unsigned int CreateDDSTexture(unsigned int texID = 0) const;
-#else  // !BITMAP_NO_OPENGL
-	const unsigned int CreateTexture(bool mipmaps = false) const;
-	const unsigned int CreateDDSTexture(unsigned int texID = 0) const;
-#endif // !BITMAP_NO_OPENGL
 
 	void CreateAlpha(unsigned char red, unsigned char green, unsigned char blue);
 	void SetTransparent(const SColor& c, const SColor& trans = SColor(0,0,0,0));
@@ -47,7 +42,7 @@ public:
 	void Blur(int iterations = 1, float weight = 1.0f);
 
 	CBitmap GetRegion(int startx, int starty, int width, int height) const;
-	void CopySubImage(const CBitmap& src, unsigned int x, unsigned int y);
+	void CopySubImage(const CBitmap& src, int x, int y);
 
 	/**
 	 * Allocates a new SDL_Surface, and feeds it with the data of this bitmap.
@@ -89,6 +84,11 @@ public:
 	void InvertAlpha();
 	void GrayScale();
 	void Tint(const float tint[3]);
+private:
+	/**
+	 * Allocates a red 1x1, 4-channel bitmap
+	 */
+	void AllocDummy();
 };
 
-#endif // __BITMAP_H__
+#endif // _BITMAP_H
