@@ -14,11 +14,20 @@
 #include "System/bitops.h"
 #include "System/TimeProfiler.h"
 #include "System/Vec2.h"
+#include "System/Log/ILog.h"
 
+#ifdef _MSC_VER
+	#include <map>
+	// only way to compile unordered_map with MSVC appears to require inclusion of math.h instead of streflop, 
+	// and that cannot be done here because it gives rise to other conflicts
+	typedef std::map<std::string, CNamedTextures::TexInfo> TEXMAP;
+#else
+	typedef boost::unordered_map<std::string, CNamedTextures::TexInfo> TEXMAP;
+#endif
 
 namespace CNamedTextures {
 
-	static boost::unordered_map<std::string, TexInfo> texMap;
+	static TEXMAP texMap;
 	static std::vector<std::string> texWaiting;
 
 	/******************************************************************************/
@@ -32,7 +41,7 @@ namespace CNamedTextures {
 	{
 		GML_STDMUTEX_LOCK(ntex); // Kill
 
-		boost::unordered_map<std::string, TexInfo>::iterator it;
+		TEXMAP::iterator it;
 		for (it = texMap.begin(); it != texMap.end(); ++it) {
 			const GLuint texID = it->second.id;
 			glDeleteTextures(1, &texID);
@@ -118,6 +127,7 @@ namespace CNamedTextures {
 		TexInfo texInfo;
 
 		if (!bitmap.Load(filename)) {
+			LOG_L(L_WARNING, "Couldn't find texture \"%s\"!", filename.c_str());
 			texMap[texName] = texInfo;
 			glBindTexture(GL_TEXTURE_2D, 0);
 			return false;
@@ -217,18 +227,15 @@ namespace CNamedTextures {
 
 		GML_STDMUTEX_LOCK(ntex); // Bind
 
-		boost::unordered_map<std::string, TexInfo>::iterator it = texMap.find(texName);
+		// cached
+		TEXMAP::iterator it = texMap.find(texName);
 		if (it != texMap.end()) {
-			const GLuint texID = it->second.id;
-			if (texID == 0) {
-				glBindTexture(GL_TEXTURE_2D, 0);
-				return false;
-			} else {
-				glBindTexture(GL_TEXTURE_2D, texID);
-				return true;
-			}
+			const GLuint& texID = it->second.id;
+			glBindTexture(GL_TEXTURE_2D, texID);
+			return (texID != 0);
 		}
 
+		// load texture
 		GLboolean inListCompile;
 		glGetBooleanv(GL_LIST_INDEX, &inListCompile);
 		if (inListCompile) {
@@ -261,7 +268,7 @@ namespace CNamedTextures {
 		
 		glPushAttrib(GL_TEXTURE_BIT);
 		for (std::vector<std::string>::iterator it = texWaiting.begin(); it != texWaiting.end(); ++it) {
-			boost::unordered_map<std::string, TexInfo>::iterator mit = texMap.find(*it);
+			TEXMAP::iterator mit = texMap.find(*it);
 			if (mit != texMap.end()) {
 				Load(*it,mit->second.id);
 			}
@@ -279,7 +286,7 @@ namespace CNamedTextures {
 
 		GML_STDMUTEX_LOCK(ntex); // Free
 
-		boost::unordered_map<std::string, TexInfo>::iterator it = texMap.find(texName);
+		TEXMAP::iterator it = texMap.find(texName);
 		if (it != texMap.end()) {
 			const GLuint texID = it->second.id;
 			glDeleteTextures(1, &texID);
@@ -298,7 +305,7 @@ namespace CNamedTextures {
 
 		GML_STDMUTEX_LOCK(ntex); // GetInfo
 
-		boost::unordered_map<std::string, TexInfo>::const_iterator it = texMap.find(texName);
+		TEXMAP::const_iterator it = texMap.find(texName);
 		if (it != texMap.end()) {
 			return &it->second;
 		}
