@@ -1,7 +1,7 @@
 /* This file is part of the Spring engine (GPL v2 or later), see LICENSE.html */
 
-#ifndef __CATEGORY_HANDLER_H__
-#define __CATEGORY_HANDLER_H__
+#ifndef _CATEGORY_HANDLER_H
+#define _CATEGORY_HANDLER_H
 
 #include <string>
 #include <vector>
@@ -59,4 +59,4 @@ private:
 	unsigned int firstUnused;
 };
 
-#endif // __CATEGORY_HANDLER_H__
+#endif // _CATEGORY_HANDLER_H
