@@ -3,9 +3,9 @@
 #ifndef COLLISION_VOLUME_H
 #define COLLISION_VOLUME_H
 
-#include "float3.h"
-#include "creg/creg_cond.h"
-#include "Util.h"
+#include "System/float3.h"
+#include "System/creg/creg_cond.h"
+#include "System/Util.h"
 
 const float EPS = 0.0000000001f;
 
@@ -13,8 +13,8 @@ struct CollisionVolume
 {
 	CR_DECLARE_STRUCT(CollisionVolume);
 
+public:
 	enum COLVOL_SHAPE_TYPES {
-		COLVOL_TYPE_DISABLED  = -1,
 		COLVOL_TYPE_ELLIPSOID =  0,
 		COLVOL_TYPE_CYLINDER  =  1,
 		COLVOL_TYPE_BOX       =  2,
@@ -35,12 +35,20 @@ struct CollisionVolume
 		COLVOL_NUM_HITTESTS = 2     // number of hit-test types
 	};
 
+public:
 	CollisionVolume();
 	CollisionVolume(const CollisionVolume* v, float defaultRadius = 0.0f);
-	CollisionVolume(const std::string&, const float3&, const float3&, int);
+	CollisionVolume(const std::string& volTypeStr, const float3& scales, const float3& offsets, int hitTestType);
 
-	void Init(float);
-	void Init(const float3&, const float3&, int, int, int);
+	/**
+	 * Called if a unit or feature does not define a custom volume.
+	 * @param r the object's default radius
+	 */
+	void Init(float r);
+	void Init(const float3& scales, const float3& offsets, int vType, int tType, int pAxis);
+
+	void RescaleAxes(const float& xs, const float& ys, const float& zs);
+	void SetAxisScales(const float& xs, const float& ys, const float& zs);
 
 	int GetVolumeType() const { return volumeType; }
 	int GetTestType() const { return testType; }
@@ -66,25 +74,22 @@ struct CollisionVolume
 	const float3& GetHScalesSq() const { return axisHScalesSq; }
 	const float3& GetHIScales() const { return axisHIScales; }
 
-	void RescaleAxes(float, float, float);
-
 	bool IsDisabled() const { return disabled; }
 	bool DefaultScale() const { return defaultScale; }
 	bool IsSphere() const { return volumeType == COLVOL_TYPE_SPHERE; }
 	bool UseFootprint() const { return volumeType == COLVOL_TYPE_FOOTPRINT; }
 
 private:
-	void SetAxisScales(float, float, float);
 	void SetBoundingRadius();
 
-	float3 axisScales;                  // full-length axis scales
-	float3 axisHScales;                 // half-length axis scales
-	float3 axisHScalesSq;               // half-length axis scales (squared)
-	float3 axisHIScales;                // half-length axis scales (inverted)
-	float3 axisOffsets;                 // offsets wrt. the model's mid-position (world-space)
+	float3 axisScales;                  ///< full-length axis scales
+	float3 axisHScales;                 ///< half-length axis scales
+	float3 axisHScalesSq;               ///< half-length axis scales (squared)
+	float3 axisHIScales;                ///< half-length axis scales (inverted)
+	float3 axisOffsets;                 ///< offsets wrt. the model's mid-position (world-space)
 
-	float volumeBoundingRadius;         // radius of minimally-bounding sphere around volume
-	float volumeBoundingRadiusSq;       // squared radius of minimally-bounding sphere
+	float volumeBoundingRadius;         ///< radius of minimally-bounding sphere around volume
+	float volumeBoundingRadiusSq;       ///< squared radius of minimally-bounding sphere
 	int volumeType;
 	int testType;
 	int primaryAxis;
