@@ -1,11 +1,9 @@
 /* This file is part of the Spring engine (GPL v2 or later), see LICENSE.html */
 
-#include "StdAfx.h"
-#include "mmgr.h"
+#include "System/mmgr.h"
 
-#include "creg/STL_Map.h"
+#include "System/creg/STL_Map.h"
 #include "GeometricObjects.h"
-#include "LogOutput.h"
 #include "Map/ReadMap.h"
 #include "Sim/Projectiles/ProjectileHandler.h"
 #include "Sim/Projectiles/Unsynced/GeoSquareProjectile.h"
@@ -95,10 +93,7 @@ void CGeometricObjects::SetColor(int group, float r, float g, float b, float a)
 	std::vector<CGeoSquareProjectile*>::iterator gi;
 
 	for (gi = gg->squares.begin(); gi != gg->squares.end(); ++gi) {
-		(*gi)->r = r;
-		(*gi)->g = g;
-		(*gi)->b = b;
-		(*gi)->a = a;
+		(*gi)->SetColor(r, g, b, a);
 	}
 }
 
@@ -108,7 +103,6 @@ float3 CGeometricObjects::CalcSpline(float i, const float3& p1, const float3& p2
 	float ni = 1 - i;
 
 	float3 res = p1*ni*ni*ni + p2*3*i*ni*ni + p3*3*i*i*ni + p4*i*i*i;
-//	logOutput.Print("%f %f %f",res.x,res.y,res.z);
 	return res;
 }
 
@@ -154,7 +148,7 @@ void CGeometricObjects::MarkSquare(int mapSquare) {
 	float3 startPos;
 	startPos.x = (int) (mapSquare * SQUARE_SIZE) % gs->mapx;
 	startPos.z = (int) (mapSquare * SQUARE_SIZE) / gs->mapx;
-	startPos.y = readmap->centerheightmap[mapSquare];
+	startPos.y = readmap->GetCenterHeightMapSynced()[mapSquare];
 
 	float3 endPos = startPos;
 	endPos.x += SQUARE_SIZE;
