@@ -6,8 +6,8 @@
 #include <map>
 #include <vector>
 #include <boost/noncopyable.hpp>
-#include "creg/creg_cond.h"
-#include "float3.h"
+#include "System/creg/creg_cond.h"
+#include "System/float3.h"
 
 
 class CGeoSquareProjectile;
