@@ -7,9 +7,6 @@
 
 #include "ExternalAI/SkirmishAIHandler.h"
 #include "Game/GameSetup.h"
-#include "Lua/LuaGaia.h"
-#include "Lua/LuaRules.h"
-#include "Sim/Misc/Team.h"
 #include "Sim/Misc/TeamHandler.h"
 #include "Sim/Misc/GlobalConstants.h"
 #include "System/Util.h"
@@ -75,13 +72,13 @@ CGlobalSynced::CGlobalSynced()
 	userSpeedFactor = 1;
 	paused = false;
 	godMode = false;
-	globalLOS = false;
 	cheatEnabled = false;
 	noHelperAIs = false;
 	editDefsEnabled = false;
 	tempNum = 2;
 	useLuaGaia = true;
 
+	memset(globalLOS, 0, sizeof(globalLOS));
 	log_framePrefixer_setFrameNumReference(&frameNum);
 
 	teamHandler = new CTeamHandler();
