@@ -5,8 +5,8 @@
 
 #include <map>
 
-#include "creg/creg_cond.h"
-#include "float3.h"
+#include "System/creg/creg_cond.h"
+#include "System/float3.h"
 
 class CSolidObject;
 typedef std::map<int, CSolidObject*> BlockingMapCell;
@@ -23,7 +23,6 @@ public:
 	void AddGroundBlockingObject(CSolidObject* object);
 	void AddGroundBlockingObject(CSolidObject* object, const unsigned char* yardMap, unsigned char mask);
 	void RemoveGroundBlockingObject(CSolidObject* object);
-	// void MoveGroundBlockingObject(CSolidObject* object, float3 oldPos);
 
 	void OpenBlockingYard(CSolidObject* yard, const unsigned char* yardMap);
 	void CloseBlockingYard(CSolidObject* yard, const unsigned char* yardMap);
@@ -36,6 +35,7 @@ public:
 	// same as GroundBlocked(), but does not bounds-check mapSquare
 	CSolidObject* GroundBlockedUnsafe(int mapSquare, bool topMost = true);
 
+	// for full thread safety, access via GetCell would need to be mutexed, but it appears only sim thread uses it
 	const BlockingMapCell& GetCell(int mapSquare) const { return groundBlockingMap[mapSquare]; }
 
 private:
