@@ -79,7 +79,7 @@ CQuadField::~CQuadField()
 
 std::vector<int> CQuadField::GetQuads(float3 pos, float radius) const
 {
-	pos.CheckInBounds();
+	pos.ClampInBounds();
 	assert(!math::isnan(pos.x));
 	assert(!math::isnan(pos.y));
 	assert(!math::isnan(pos.z));
@@ -112,7 +112,7 @@ std::vector<int> CQuadField::GetQuads(float3 pos, float radius) const
 
 unsigned int CQuadField::GetQuads(float3 pos, float radius, int*& begQuad, int*& endQuad) const
 {
-	pos.CheckInBounds();
+	pos.ClampInBounds();
 	assert(!math::isnan(pos.x));
 	assert(!math::isnan(pos.y));
 	assert(!math::isnan(pos.z));
