@@ -6,7 +6,7 @@
 #include <vector>
 #include <map>
 #include <boost/noncopyable.hpp>
-#include "creg/creg_cond.h"
+#include "System/creg/creg_cond.h"
 #include "Resource.h"
 
 class CResourceMapAnalyzer;
