@@ -85,6 +85,22 @@ CHoverAirMoveType::CHoverAirMoveType(CUnit* owner) :
 	forceHeadingTo(wantedHeading),
 	maxDrift(1)
 {
+	assert(owner != NULL);
+	assert(owner->unitDef != NULL);
+
+	turnRate = owner->unitDef->turnRate;
+	accRate = std::max(0.01f, owner->unitDef->maxAcc);
+	decRate = std::max(0.01f, owner->unitDef->maxDec);
+
+	wantedHeight = owner->unitDef->wantedHeight + gs->randFloat() * 5.0f;
+	orgWantedHeight = wantedHeight;
+	dontLand = owner->unitDef->DontLand();
+	collide = owner->unitDef->collide;
+	altitudeRate = owner->unitDef->verticalSpeed;
+	bankingAllowed = owner->unitDef->bankingAllowed;
+	useSmoothMesh = owner->unitDef->useSmoothMesh;
+
+	// prevent weapons from being updated and firing while on the ground
 	owner->dontUseWeapons = true;
 }
 
@@ -127,18 +143,19 @@ void CHoverAirMoveType::SetState(AircraftState newState)
 	// Do animations
 	switch (aircraftState) {
 		case AIRCRAFT_LANDED:
-			if (padStatus == 0) {
+			if (padStatus == PAD_STATUS_FLYING) {
 				// set us on ground if we are not on a pad
 				owner->physicalState = CSolidObject::OnGround;
 				owner->Block();
 			}
+			break;
 		case AIRCRAFT_LANDING:
 			owner->Deactivate();
 			break;
 		case AIRCRAFT_HOVERING:
 			wantedHeight = orgWantedHeight;
 			wantedSpeed = ZeroVector;
-			// fall through...
+			// fall through
 		default:
 			owner->physicalState = CSolidObject::Flying;
 			owner->UnBlock();
@@ -233,7 +250,7 @@ void CHoverAirMoveType::ExecuteStop()
 			if (!dontLand && autoLand) {
 				SetState(AIRCRAFT_LANDING);
 				// trick to land directly
-				waitCounter = 30;
+				waitCounter = GAME_SPEED;
 				break;
 			} // let it fall through
 		case AIRCRAFT_FLYING:
@@ -257,7 +274,7 @@ void CHoverAirMoveType::ExecuteStop()
 			if (!dontLand && autoLand) {
 				// land immediately
 				SetState(AIRCRAFT_LANDING);
-				waitCounter = 30;
+				waitCounter = GAME_SPEED;
 			}
 			break;
 	}
@@ -277,21 +294,7 @@ void CHoverAirMoveType::StopMoving()
 
 void CHoverAirMoveType::UpdateLanded()
 {
-	if (owner->beingBuilt)
-		return;
-
-	float3& pos = owner->pos;
-	float3& spd = owner->speed;
-
-	if (padStatus == 0) {
-		if (owner->unitDef->canSubmerge) {
-			pos.y = std::max(pos.y, ground->GetHeightReal(pos.x, pos.z));
-		} else {
-			pos.y = std::max(pos.y, ground->GetHeightAboveWater(pos.x, pos.z));
-		}
-	}
-
-	spd = ZeroVector;
+	AAirMoveType::UpdateLanded();
 
 	if (progressState != AMoveType::Failed)
 		progressState = AMoveType::Done;
@@ -299,18 +302,16 @@ void CHoverAirMoveType::UpdateLanded()
 
 void CHoverAirMoveType::UpdateTakeoff()
 {
-	float3& pos = owner->pos;
+	const float3& pos = owner->pos;
+
 	wantedSpeed = ZeroVector;
 	wantedHeight = orgWantedHeight;
 
 	UpdateAirPhysics();
 
-	float altitude = 0.0f;
-	if (owner->unitDef->canSubmerge) {
-		altitude = pos.y - ground->GetHeightReal(pos.x, pos.z);
-	} else {
-		altitude = pos.y - ground->GetHeightAboveWater(pos.x, pos.z);
-	}
+	const float altitude = owner->unitDef->canSubmerge?
+		(pos.y - ground->GetHeightReal(pos.x, pos.z)):
+		(pos.y - ground->GetHeightAboveWater(pos.x, pos.z));
 
 	if (altitude > orgWantedHeight * 0.8f) {
 		SetState(AIRCRAFT_FLYING);
@@ -356,52 +357,50 @@ void CHoverAirMoveType::UpdateHovering()
 
 void CHoverAirMoveType::UpdateFlying()
 {
-	float3 &pos = owner->pos;
-	float3 &speed = owner->speed;
+	const float3& pos = owner->pos;
+	const float3& speed = owner->speed;
 
 	// Direction to where we would like to be
-	float3 dir = goalPos - pos;
+	float3 goalVec = goalPos - pos;
+
 	owner->restTime = 0;
 
 	// don't change direction for waypoints we just flew over and missed slightly
-	if (flyState != FLY_LANDING && owner->commandAI->HasMoreMoveCommands()
-			&& dir != ZeroVector && dir.SqLength2D() < 10000.0f) {
-		float3 ndir = dir; ndir = ndir.UnsafeANormalize();
+	if (flyState != FLY_LANDING && owner->commandAI->HasMoreMoveCommands()) {
+		float3 goalDir = goalVec;
 
-		if (ndir.SqDistance(dir) < 1.0f) {
-			dir = owner->frontdir;
+		if ((goalDir != ZeroVector) && (goalDir.UnsafeANormalize()).SqDistance(goalVec) < 1.0f) {
+			goalVec = owner->frontdir;
 		}
 	}
 
+	const float goalDistSq2D = goalVec.SqLength2D();
 	const float gHeight = UseSmoothMesh()?
 		std::max(smoothGround->GetHeight(pos.x, pos.z), ground->GetApproximateHeight(pos.x, pos.z)):
 		ground->GetHeightAboveWater(pos.x, pos.z);
 
-	// are we there yet?
-	bool closeToGoal =
-		(dir.SqLength2D() < maxDrift * maxDrift) &&
-		(fabs(gHeight - pos.y + wantedHeight) < maxDrift);
-
-	if (flyState == FLY_ATTACKING) {
-		closeToGoal = (dir.SqLength2D() < 400);
-	}
+	const bool closeToGoal = (flyState == FLY_ATTACKING)?
+		(goalDistSq2D < (             400.0f)):
+		(goalDistSq2D < (maxDrift * maxDrift)) && (math::fabs(gHeight - pos.y + wantedHeight) < maxDrift);
 
 	if (closeToGoal) {
-		// pretty close
 		switch (flyState) {
 			case FLY_CRUISING: {
-				bool trans = dynamic_cast<CTransportUnit*>(owner);
-				bool noland = dontLand || !autoLand;
-				// should CMD_LOAD_ONTO be here?
-				bool hasLoadCmds = trans && !owner->commandAI->commandQue.empty()
-						&& (owner->commandAI->commandQue.front().GetID() == CMD_LOAD_ONTO
-							|| owner->commandAI->commandQue.front().GetID() == CMD_LOAD_UNITS);
-				if (noland || (trans && ++waitCounter < 55 && hasLoadCmds)) {
-					// transport aircraft need some time to detect that they can pickup
+				const bool trans = (dynamic_cast<CTransportUnit*>(owner) != NULL);
+				const bool noland = dontLand || !autoLand;
+				// NOTE: should CMD_LOAD_ONTO be here?
+				const bool hasLoadCmds = trans &&
+					!owner->commandAI->commandQue.empty() &&
+					(owner->commandAI->commandQue.front().GetID() == CMD_LOAD_ONTO ||
+					 owner->commandAI->commandQue.front().GetID() == CMD_LOAD_UNITS);
+				// [?] transport aircraft need some time to detect that they can pickup
+				const bool canLoad = trans && (++waitCounter < ((GAME_SPEED << 1) - 5));
+
+				if (noland || (canLoad && hasLoadCmds)) {
 					if (trans) {
 						wantedSpeed = ZeroVector;
 						SetState(AIRCRAFT_HOVERING);
-						if (waitCounter > 60) {
+						if (waitCounter > (GAME_SPEED << 1)) {
 							wantedHeight = orgWantedHeight;
 						}
 					} else {
@@ -418,8 +417,7 @@ void CHoverAirMoveType::UpdateFlying()
 			}
 			case FLY_CIRCLING:
 				// break;
-				waitCounter++;
-				if (waitCounter > 100) {
+				if ((++waitCounter) > ((GAME_SPEED * 3) + 10)) {
 					if (airStrafe) {
 						float3 relPos = pos - circlingPos;
 						if (relPos.x < 0.0001f && relPos.x > -0.0001f) {
@@ -461,40 +459,43 @@ void CHoverAirMoveType::UpdateFlying()
 				}
 				break;
 			}
-			case FLY_LANDING:{
+			case FLY_LANDING: {
 				break;
 			}
 		}
 	}
 
 	// not there yet, so keep going
-	dir.y = 0;
-	float realMax = maxSpeed;
-	float dist = dir.Length() + 0.1f;
+	goalVec.y = 0.0f;
 
-	// If we are close to our goal, we should go slow enough to be able to break in time
-	// new additional rule: if in attack mode or if we have more move orders then this is
-	// an intermediate waypoint, don't slow down (FIXME)
-	if (flyState != FLY_ATTACKING && dist < brakeDistance) {
-		realMax = dist / (speed.Length2D() + 0.01f) * decRate;
-	}
+	// if we are close to our goal and not in attack mode,
+	// we should go slow enough to be able to break in time
+	const float goalDist = goalVec.Length() + 0.1f;
+	const float approachSpeed =
+		(flyState != FLY_ATTACKING && goalDist < brakeDistance)?
+		(goalDist / (speed.Length2D() + 0.01f) * decRate):
+		maxSpeed;
+
+	wantedSpeed = (goalVec / goalDist) * approachSpeed;
 
-	wantedSpeed = (dir / dist) * realMax;
 	UpdateAirPhysics();
 
 	// Point toward goal or forward - unless we just passed it to get to another goal
 	if ((flyState == FLY_ATTACKING) || (flyState == FLY_CIRCLING)) {
-		dir = circlingPos - pos;
-	} else if (flyState != FLY_LANDING && (owner->commandAI->HasMoreMoveCommands() &&
-		dist < 120) && (goalPos - pos).Normalize().SqDistance(dir) > 1) {
-		dir = owner->frontdir;
+		goalVec = circlingPos - pos;
 	} else {
-		dir = goalPos - pos;
+		const bool b0 = (flyState != FLY_LANDING && (owner->commandAI->HasMoreMoveCommands()));
+		const bool b1 = (goalDist < 120.0f) && ((goalVec.SafeNormalize()).SqDistance(goalVec) > 1.0f);
+
+		if (b0 && b1) {
+			goalVec = owner->frontdir;
+		} else {
+			goalVec = goalPos - pos;
+		}
 	}
 
-	if (dir.SqLength2D() > 1) {
-		const int h = GetHeadingFromVector(dir.x, dir.z);
-		wantedHeading = (h == 0)? wantedHeading : h;
+	if (goalVec.SqLength2D() > 1.0f) {
+		wantedHeading = GetHeadingFromVector(goalVec.x, goalVec.z);
 	}
 }
 
@@ -502,16 +503,14 @@ void CHoverAirMoveType::UpdateFlying()
 
 void CHoverAirMoveType::UpdateLanding()
 {
-	float3& pos = owner->pos;
-	float3& speed = owner->speed;
+	const float3& pos = owner->pos;
+	const float3& speed = owner->speed;
 
 	// We want to land, and therefore cancel our speed first
 	wantedSpeed = ZeroVector;
 
-	waitCounter++;
-
 	// Hang around for a while so queued commands have a chance to take effect
-	if (waitCounter < 30) {
+	if ((++waitCounter) < GAME_SPEED) {
 		UpdateAirPhysics();
 		return;
 	}
@@ -529,7 +528,7 @@ void CHoverAirMoveType::UpdateLanding()
 		} else {
 			if (goalPos.SqDistance2D(pos) < 900) {
 				goalPos = goalPos + gs->randVector() * 300;
-				goalPos.CheckInBounds();
+				goalPos.ClampInBounds();
 				progressState = AMoveType::Failed; // exact landing pos failed, make sure finishcommand is called anyway
 			}
 			flyState = FLY_LANDING;
@@ -544,24 +543,22 @@ void CHoverAirMoveType::UpdateLanding()
 	}
 
 	// We have stopped, time to land
-	const float gh = ground->GetHeightReal(pos.x, pos.z);
-	float altitude = 0.0f;
+	// NOTE: wantedHeight is interpreted as RELATIVE altitude
+	const float gh = ground->GetHeightAboveWater(pos.x, pos.z);
+	const float gah = ground->GetHeightReal(pos.x, pos.z);
+	float altitude = (wantedHeight = 0.0f);
 
-	// if aircraft submergible and above water we want height of ocean floor
-	if ((owner->unitDef->canSubmerge) && (gh < 0.0f)) {
-		altitude = pos.y - gh;
-		wantedHeight = gh;
+	// can we submerge and are we still above water?
+	if ((owner->unitDef->canSubmerge) && (gah < 0.0f)) {
+		altitude = pos.y - gah;
 	} else {
-		altitude = pos.y - ground->GetHeightAboveWater(pos.x, pos.z);
-		wantedHeight = -2.0;
+		altitude = pos.y - gh;
 	}
 
 	UpdateAirPhysics();
 
-	if (altitude <= 0.0f) {
+	if (altitude <= 1.0f) {
 		SetState(AIRCRAFT_LANDED);
-
-		pos.y = gh;
 	}
 }
 
@@ -569,9 +566,8 @@ void CHoverAirMoveType::UpdateLanding()
 
 void CHoverAirMoveType::UpdateHeading()
 {
-	if (aircraftState == AIRCRAFT_TAKEOFF && !owner->unitDef->factoryHeadingTakeoff) {
+	if (aircraftState == AIRCRAFT_TAKEOFF && !owner->unitDef->factoryHeadingTakeoff)
 		return;
-	}
 
 	SyncedSshort& heading = owner->heading;
 	const short deltaHeading = forceHeading?
@@ -584,11 +580,15 @@ void CHoverAirMoveType::UpdateHeading()
 		heading += std::max(deltaHeading, short(-turnRate));
 	}
 
-	owner->UpdateDirVectors(false);
+	owner->UpdateDirVectors(aircraftState == AIRCRAFT_LANDED);
+	owner->UpdateMidPos();
 }
 
 void CHoverAirMoveType::UpdateBanking(bool noBanking)
 {
+	if (aircraftState != AIRCRAFT_FLYING && aircraftState != AIRCRAFT_HOVERING)
+		return;
+
 	if (!owner->upright) {
 		float wantedPitch = 0.0f;
 
@@ -610,6 +610,7 @@ void CHoverAirMoveType::UpdateBanking(bool noBanking)
 	// pitching does not affect rightdir, but...
 	frontDir.y = currentPitch;
 	frontDir.Normalize();
+
 	// we want a flat right-vector to calculate wantedBank
 	rightDir2D = frontDir.cross(UpVector);
 
@@ -634,69 +635,87 @@ void CHoverAirMoveType::UpdateBanking(bool noBanking)
 	upDir = upDir * math::cos(currentBank) + rightDir2D * math::sin(currentBank);
 	rightDir3D = frontDir.cross(upDir);
 
-	owner->SetHeadingFromDirection();
+	// NOTE:
+	//     heading might not be fully in sync with frontDir due to the
+	//     vector<-->heading mapping not being 1:1 (such that heading
+	//     != GetHeadingFromVector(frontDir)), therefore this call can
+	//     cause owner->heading to change --> unwanted if forceHeading
+	//
+	//     it is "safe" to skip because only frontDir.y is manipulated
+	//     above so its xz-direction does not change, but the problem
+	//     should really be fixed elsewhere
+	if (!forceHeading) {
+		owner->SetHeadingFromDirection();
+	}
+
+	owner->UpdateMidPos();
 }
 
 
 void CHoverAirMoveType::UpdateAirPhysics()
 {
-	float3& pos = owner->pos;
-	float3& speed = owner->speed;
+	const float3& pos = owner->pos;
+	      float3& speed = owner->speed;
 
 	if (!((gs->frameNum + owner->id) & 3)) {
 		CheckForCollision();
 	}
 
-	const float yspeed = speed.y;
-	speed.y = 0.0f;
+	const float yspeed = speed.y; speed.y = 0.0f;
 
-	const float3 delta = wantedSpeed - speed;
-	const float deltaDotSpeed = (speed != ZeroVector)? delta.dot(speed): 1.0f;
+	const float3 deltaSpeed = wantedSpeed - speed;
+	const float deltaDotSpeed = (speed != ZeroVector)? deltaSpeed.dot(speed): 1.0f;
 
 	if (deltaDotSpeed == 0.0f) {
 		// we have the wanted speed
 	} else if (deltaDotSpeed > 0.0f) {
 		// accelerate
-		const float sqdl = delta.SqLength();
+		const float sqdl = deltaSpeed.SqLength();
+
 		if (sqdl < Square(accRate)) {
 			speed = wantedSpeed;
 		} else {
-			speed += delta / math::sqrt(sqdl) * accRate;
+			speed += (deltaSpeed / math::sqrt(sqdl) * accRate);
 		}
 	} else {
 		// break
-		const float sqdl = delta.SqLength();
+		const float sqdl = deltaSpeed.SqLength();
+
 		if (sqdl < Square(decRate)) {
 			speed = wantedSpeed;
 		} else {
-			speed += delta / math::sqrt(sqdl) * decRate;
+			speed += (deltaSpeed / math::sqrt(sqdl) * decRate);
 		}
 	}
 
-	float minH = 0.0f; // minimum altitude at (pos.x, pos.z)
-	float curH = 0.0f; // current altitude at (pos.x, pos.z)
+	float minHeight = 0.0f;  // absolute ground height at (pos.x, pos.z)
+	float curHeight = 0.0f;  // relative ground height at (pos.x, pos.z) == pos.y - minHeight (altitude)
+
+	float wh = wantedHeight; // wanted RELATIVE height (altitude)
+	float ws = 0.0f;         // wanted vertical speed
 
 	if (UseSmoothMesh()) {
-		minH = owner->unitDef->canSubmerge?
+		minHeight = owner->unitDef->canSubmerge?
 			smoothGround->GetHeight(pos.x, pos.z):
 			smoothGround->GetHeightAboveWater(pos.x, pos.z);
 	} else {
-		minH = owner->unitDef->canSubmerge?
+		minHeight = owner->unitDef->canSubmerge?
 			ground->GetHeightReal(pos.x, pos.z):
 			ground->GetHeightAboveWater(pos.x, pos.z);
 	}
 
-	speed.y = yspeed;
-	pos.y = std::max(pos.y, minH);
-	curH = pos.y - minH;
+	// [?] aircraft should never be able to end up below terrain
+	// if (pos.y < minHeight)
+	//     owner->Move1D(std::min(minHeight - pos.y, altitudeRate), 1, true);
 
-	if (curH < 4.0f) {
+	speed.y = yspeed;
+	curHeight = pos.y - minHeight;
+
+	if (curHeight < 4.0f) {
 		speed.x *= 0.95f;
 		speed.z *= 0.95f;
 	}
 
-	float wh = wantedHeight;
-
 	if (lastColWarningType == 2) {
 		const float3 dir = lastColWarning->midPos - owner->midPos;
 		const float3 sdir = lastColWarning->speed - speed;
@@ -711,33 +730,37 @@ void CHoverAirMoveType::UpdateAirPhysics()
 	}
 
 
-	float ws = 0.0f;
 
-	if (curH < wh) {
+	if (curHeight < wh) {
 		ws = altitudeRate;
-		if (speed.y > 0.0001f && (wh - curH) / speed.y * accRate * 1.5f < speed.y) {
+
+		if ((speed.y > 0.0001f) && (((wh - curHeight) / speed.y) * accRate * 1.5f) < speed.y) {
 			ws = 0.0f;
 		}
 	} else {
 		ws = -altitudeRate;
-		if (speed.y < -0.0001f && (wh - curH) / speed.y * accRate * 0.7f < -speed.y) {
+
+		if ((speed.y < -0.0001f) && (((wh - curHeight) / speed.y) * accRate * 0.7f) < -speed.y) {
 			ws = 0.0f;
 		}
 	}
 
-	if (fabs(wh - curH) > 2.0f) {
-		if (speed.y > ws) {
-			speed.y = std::max(ws, speed.y - accRate * 1.5f);
-		} else if (!owner->beingBuilt) {
-			// let them accelerate upward faster if close to ground
-			speed.y = std::min(ws, speed.y + accRate * (curH < 20.0f? 2.0f: 0.7f));
+	if (!owner->beingBuilt) {
+		if (math::fabs(wh - curHeight) > 2.0f) {
+			if (speed.y > ws) {
+				speed.y = std::max(ws, speed.y - accRate * 1.5f);
+			} else {
+				// accelerate upward faster if close to ground
+				speed.y = std::min(ws, speed.y + accRate * ((curHeight < 20.0f)? 2.0f: 0.7f));
+			}
+		} else {
+			speed.y *= 0.95;
 		}
-	} else {
-		speed.y = speed.y * 0.95;
 	}
 
-	if (modInfo.allowAirPlanesToLeaveMap || (pos + speed).CheckInBounds()) {
-		pos += speed;
+
+	if (modInfo.allowAircraftToLeaveMap || (pos + speed).IsInBounds()) {
+		owner->Move3D(speed, true);
 	}
 }
 
@@ -765,8 +788,8 @@ void CHoverAirMoveType::UpdateMoveRate()
 
 bool CHoverAirMoveType::Update()
 {
-	float3& pos = owner->pos;
-	float3& speed = owner->speed;
+	const float3& pos = owner->pos;
+	      float3& speed = owner->speed;
 
 	AAirMoveType::Update();
 
@@ -815,7 +838,7 @@ bool CHoverAirMoveType::Update()
 		if (reservedPad != NULL) {
 			MoveToRepairPad();
 
-			if (padStatus >= 1) {
+			if (padStatus >= PAD_STATUS_LANDING) {
 				flyState = FLY_LANDING;
 			}
 		}
@@ -862,7 +885,7 @@ void CHoverAirMoveType::SlowUpdate()
 	// but only MobileCAI's reserve pads so we need to do
 	// this for ourselves
 	if (reservedPad == NULL && aircraftState == AIRCRAFT_FLYING && WantsRepair()) {
-		CAirBaseHandler::LandingPad* lp = airBaseHandler->FindAirBase(owner, owner->unitDef->minAirBasePower);
+		CAirBaseHandler::LandingPad* lp = airBaseHandler->FindAirBase(owner, owner->unitDef->minAirBasePower, true);
 
 		if (lp != NULL) {
 			AAirMoveType::ReservePad(lp);
@@ -881,7 +904,10 @@ bool CHoverAirMoveType::CanLandAt(const float3& pos) const
 	if (!autoLand) { return false; }
 	if (!pos.IsInBounds()) { return false; }
 
-	if ((ground->GetApproximateHeight(pos.x, pos.z) < 0.0f) && !(owner->unitDef->floater || owner->unitDef->canSubmerge)) {
+	const UnitDef* ud = owner->unitDef;
+	const float gah = ground->GetApproximateHeight(pos.x, pos.z);
+
+	if ((gah < 0.0f) && !(ud->floatOnWater || ud->canSubmerge)) {
 		return false;
 	}
 
@@ -934,18 +960,16 @@ void CHoverAirMoveType::Takeoff()
 
 bool CHoverAirMoveType::HandleCollisions()
 {
-	float3& pos = owner->pos;
+	const float3& pos = owner->pos;
 
 	if (pos != oldPos) {
 		oldPos = pos;
 
-		const bool checkCollisions =
-			collide &&
-			(!loadingUnits) &&
-			(padStatus == 0) &&
-			(aircraftState != AIRCRAFT_TAKEOFF);
+		// check for collisions if not on a pad, not being built, or not taking off
+		// includes an extra condition for transports, which are exempt while loading
+		const bool checkCollisions = collide && !owner->beingBuilt && (padStatus == PAD_STATUS_FLYING) && (aircraftState != AIRCRAFT_TAKEOFF);
 
-		if (checkCollisions) {
+		if (!loadingUnits && checkCollisions) {
 			const vector<CUnit*>& nearUnits = qf->GetUnitsExact(pos, owner->radius + 6);
 
 			for (vector<CUnit*>::const_iterator ui = nearUnits.begin(); ui != nearUnits.end(); ++ui) {
@@ -964,17 +988,13 @@ bool CHoverAirMoveType::HandleCollisions()
 				const float3 dif = (pos - unit->pos).Normalize();
 
 				if (unit->mass >= CSolidObject::DEFAULT_MASS || unit->immobile) {
-					pos -= dif * (dist - totRad);
-					owner->UpdateMidPos();
+					owner->Move3D(-dif * (dist - totRad), true);
 					owner->speed *= 0.99f;
 				} else {
 					const float part = owner->mass / (owner->mass + unit->mass);
 
-					pos -= dif * (dist - totRad) * (1.0f - part);
-					owner->UpdateMidPos();
-
-					unit->pos += dif * (dist - totRad) * (part);
-					unit->UpdateMidPos();
+					owner->Move3D(-dif * (dist - totRad) * (1.0f - part), true);
+					unit->Move3D(dif * (dist - totRad) * (part), true);
 
 					const float colSpeed = -owner->speed.dot(dif) + unit->speed.dot(dif);
 
@@ -985,19 +1005,15 @@ bool CHoverAirMoveType::HandleCollisions()
 		}
 
 		if (pos.x < 0.0f) {
-			pos.x += 0.6f;
-			owner->midPos.x += 0.6f;
+			owner->Move1D(0.6f, 0, true);
 		} else if (pos.x > float3::maxxpos) {
-			pos.x -= 0.6f;
-			owner->midPos.x -= 0.6f;
+			owner->Move1D(-0.6f, 0, true);
 		}
 
 		if (pos.z < 0.0f) {
-			pos.z += 0.6f;
-			owner->midPos.z += 0.6f;
+			owner->Move1D(0.6f, 2, true);
 		} else if (pos.z > float3::maxzpos) {
-			pos.z -= 0.6f;
-			owner->midPos.z -= 0.6f;
+			owner->Move1D(-0.6f, 2, true);
 		}
 
 		return true;
