@@ -11,15 +11,13 @@
 class CGroundMoveMath :	public CMoveMath {
 	CR_DECLARE(CGroundMoveMath);
 public:
-	//SpeedMod returns a speed-multiplier for given position or data.
 	float SpeedMod(const MoveData& moveData, float height, float slope) const;
-	float SpeedMod(const MoveData& moveData, float height, float slope,float moveSlope) const;
+	float SpeedMod(const MoveData& moveData, float height, float slope, float moveSlope) const;
 
-	//Gives the y-coordinate the unit will "stand on".
 	float yLevel(int xSquare, int zSquare) const;
 	float yLevel(const float3& pos) const;
 
-	static float waterCost;
+	static float waterDamageCost;
 };
 
 #endif
