@@ -11,13 +11,12 @@
 class CShipMoveMath : public CMoveMath {
 	CR_DECLARE(CShipMoveMath);
 public:
-	//SpeedMod returns a speed-multiplier for given position or data.
 	float SpeedMod(const MoveData& moveData, float height, float slope) const;
-	float SpeedMod(const MoveData& moveData, float height, float slope,float moveSlope) const;
+	float SpeedMod(const MoveData& moveData, float height, float slope, float moveSlope) const;
 
-	//Gives the y-coordinate the unit will "stand on".
-	float yLevel(int xSquare, int zSquare) const;
-	float yLevel(const float3& pos) const;
+	// ships are always at water-level
+	float yLevel(int xSquare, int zSquare) const { return 0.0f; }
+	float yLevel(const float3& pos) const { return 0.0f; }
 };
 
 #endif
