@@ -46,6 +46,11 @@ public:
 
 	void SetRepairBelowHealth(float rbHealth) { repairBelowHealth = rbHealth; }
 
+	float GetMaxSpeed() const { return maxSpeed; }
+	float GetMaxSpeedDef() const { return maxSpeedDef; }
+	float GetMaxWantedSpeed() const { return maxWantedSpeed; }
+	float GetRepairBelowHealth() const { return repairBelowHealth; }
+
 public:
 	CUnit* owner;
 
@@ -53,10 +58,6 @@ public:
 	float3 oldPos;             // owner position at last Update()
 	float3 oldSlowUpdatePos;   // owner position at last SlowUpdate()
 
-	float maxSpeed;
-	float maxWantedSpeed;
-	float repairBelowHealth;
-
 	/// TODO: probably should move the code in CUnit that reads this into the movement classes
 	bool useHeading;
 
@@ -66,6 +67,13 @@ public:
 		Failed = 2
 	};
 	ProgressState progressState;
+
+protected:
+	float maxSpeed;            // current maximum speed owner is allowed to reach (changes with eg. guard orders)
+	float maxSpeedDef;         // default maximum speed owner can reach (as defined by its UnitDef, never changes)
+	float maxWantedSpeed;      // FIXME: largely redundant / unused except by StrafeAirMoveType
+
+	float repairBelowHealth;
 };
 
 #endif // MOVETYPE_H
