@@ -11,11 +11,10 @@ class CScriptMoveType : public AMoveType
 
 	public:
 		CScriptMoveType(CUnit* owner);
-		virtual ~CScriptMoveType(void);
+		virtual ~CScriptMoveType();
 
 	public:
-		void Update();
-		void SlowUpdate();
+		bool Update();
 		void ForceUpdates();
 
 		void SetPhysics(const float3& pos, const float3& vel, const float3& rot);
@@ -24,28 +23,23 @@ class CScriptMoveType : public AMoveType
 		void SetRelativeVelocity(const float3& rvel);
 		void SetRotation(const float3& rot);
 		void SetRotationVelocity(const float3& rvel);
-		void SetRotationOffset(const float3& rotOff);
 		void SetHeading(short heading);
 		void SetNoBlocking(bool state);
 		
 	public: // null'ed virtuals
-		void StartMoving(float3, float goalRadius) {};
-		void StartMoving(float3, float goalRadius, float speed) {};
-		void KeepPointingTo(float3, float distance, bool aggressive) {};
-		void KeepPointingTo(CUnit* unit, float distance, bool aggressive) {};
-		void StopMoving() {};
-		void Idle(unsigned int frames) {};
-		void Idle() {};
-		void DeIdle() {};
-		void ImpulseAdded() {};
-		void SetGoal(float3 pos) {};
-		void SetMaxSpeed(float speed) {};
-		void SetWantedMaxSpeed(float speed) {};
-		void LeaveTransport(void) {};
+		void StartMoving(float3, float goalRadius) {}
+		void StartMoving(float3, float goalRadius, float speed) {}
+		void KeepPointingTo(float3, float distance, bool aggressive) {}
+		void KeepPointingTo(CUnit* unit, float distance, bool aggressive) {}
+		void StopMoving() {}
+
+		void SetGoal(float3 pos) {}
+		void SetMaxSpeed(float speed) {}
+		void SetWantedMaxSpeed(float speed) {}
+		void LeaveTransport() {}
 
 	protected:
 		void CalcDirections();
-		void TrackSlope();
 		void CheckLimits();
 		void CheckNotify();
 
@@ -53,6 +47,8 @@ class CScriptMoveType : public AMoveType
 		int tag;
 		
 		bool extrapolate;
+		bool useRelVel;
+		bool useRotVel;
 
 		float drag;
 
@@ -60,13 +56,11 @@ class CScriptMoveType : public AMoveType
 		float3 vel;
 		/// relative velocity (to current direction)
 		float3 relVel;
-		bool useRelVel;
 
 		/// angular position
 		float3 rot;
 		/// angular velocity
 		float3 rotVel;
-		bool useRotVel;
 
 		bool trackSlope;
 		bool trackGround;
@@ -85,18 +79,7 @@ class CScriptMoveType : public AMoveType
 		bool slopeStop;
 		bool collideStop;
 
-		bool leaveTracks;
-
 	protected:
-		bool hasDecal;
-		bool isBuilding;
-
-		float3 rotOffset;
-
-		int lastTrackUpdate;
-		float3 oldPos;
-		float3 oldSlowUpdatePos;
-
 		int scriptNotify;
 };
 
