@@ -170,8 +170,8 @@ bool CStrafeAirMoveType::Update()
 
 			if (con.forward) { elevator -= 1; }
 			if (con.back   ) { elevator += 1; }
-			if (con.right  ) { aileron += 1; }
-			if (con.left   ) { aileron -= 1; }
+			if (con.right  ) { aileron  += 1; }
+			if (con.left   ) { aileron  -= 1; }
 
 			UpdateAirPhysics(0, aileron, elevator, 1, owner->frontdir);
 			maneuver = 0;
@@ -180,16 +180,27 @@ bool CStrafeAirMoveType::Update()
 		}
 	}
 
+	// somewhat hackish, but planes that have attack orders
+	// while no pad is available would otherwise continue
+	// attacking even if out of fuel
+	const bool outOfFuel = (owner->currentFuel <= 0.0f && owner->unitDef->maxFuel > 0.0f);
+	const bool continueAttack = (reservedPad == NULL && !outOfFuel);
+
 	if (aircraftState != AIRCRAFT_CRASHING) {
 		if (reservedPad != NULL) {
 			MoveToRepairPad();
 		} else {
-			if (owner->unitDef->maxFuel > 0.0f && owner->currentFuel <= 0.0f) {
-				if (padStatus == 0 && maxWantedSpeed > 0.0f) {
-					// out of fuel, keep us in the air to reach our landing
-					// goalPos (which is hopefully in the vicinity of a pad)
-					SetState(AIRCRAFT_FLYING);
-				}
+			if (outOfFuel && airBaseHandler->HaveAirBase(owner->allyteam)) {
+				// out of fuel, keep us in the air to reach our landing
+				// goalPos (which is/will be set to a pad's position by
+				// MobileCAI) so long as there is at least one friendly
+				// base
+				//
+				// NOTE:
+				//     technically need to pass minAirBasePower as well,
+				//     otherwise aircraft might keep flying and never be
+				//     serviced
+				SetState(AIRCRAFT_FLYING);
 			}
 		}
 	}
@@ -198,12 +209,6 @@ bool CStrafeAirMoveType::Update()
 		case AIRCRAFT_FLYING: {
 			owner->restTime = 0;
 
-			// somewhat hackish, but planes that have attack orders
-			// while no pad is available would otherwise continue
-			// attacking even if out of fuel
-			const bool continueAttack =
-				(reservedPad == NULL && ((owner->currentFuel > 0.0f) || owner->unitDef->maxFuel <= 0.0f));
-
 			if (continueAttack && ((owner->userTarget && !owner->userTarget->isDead) || owner->userAttackGround)) {
 				inefficientAttackTime = std::min(inefficientAttackTime, float(gs->frameNum) - owner->lastFireWeapon);
 
@@ -279,10 +284,8 @@ bool CStrafeAirMoveType::HandleCollisions() {
 	if (pos != oldPos) {
 		oldPos = pos;
 
-		const bool checkCollisions =
-			collide &&
-			(!owner->beingBuilt) &&
-			(aircraftState == AIRCRAFT_FLYING || aircraftState == AIRCRAFT_CRASHING);
+		// check for collisions if not on a pad, not being built, or not taking off
+		const bool checkCollisions = collide && !owner->beingBuilt && (padStatus == PAD_STATUS_FLYING) && (aircraftState != AIRCRAFT_TAKEOFF);
 
 		if (checkCollisions) {
 			bool hitBuilding = false;
@@ -306,8 +309,8 @@ bool CStrafeAirMoveType::HandleCollisions() {
 
 					const float damage = ((unit->speed - owner->speed) * 0.1f).SqLength();
 
-					owner->DoDamage(DamageArray(damage), 0, ZeroVector);
-					unit->DoDamage(DamageArray(damage), 0, ZeroVector);
+					owner->DoDamage(DamageArray(damage), ZeroVector, NULL, -CSolidObject::DAMAGE_COLLISION_OBJECT);
+					unit->DoDamage(DamageArray(damage), ZeroVector, NULL, -CSolidObject::DAMAGE_COLLISION_OBJECT);
 					hitBuilding = true;
 				} else {
 					const float part = owner->mass / (owner->mass + unit->mass);
@@ -317,8 +320,8 @@ bool CStrafeAirMoveType::HandleCollisions() {
 
 					const float damage = ((unit->speed - owner->speed) * 0.1f).SqLength();
 
-					owner->DoDamage(DamageArray(damage), 0, ZeroVector);
-					unit->DoDamage(DamageArray(damage), 0, ZeroVector);
+					owner->DoDamage(DamageArray(damage), ZeroVector, NULL, -CSolidObject::DAMAGE_COLLISION_OBJECT);
+					unit->DoDamage(DamageArray(damage), ZeroVector, NULL, -CSolidObject::DAMAGE_COLLISION_OBJECT);
 
 					owner->speed *= 0.99f;
 				}
@@ -409,7 +412,7 @@ void CStrafeAirMoveType::UpdateManeuver()
 			if ((owner->updir.y < 0.0f && owner->frontdir.y < 0.0f) || speedf < 0.8f) {
 				maneuver = 0;
 			}
-			// some seem to report that the "unlimited altitude" thing is because of these maneuvers
+			// [?] some seem to report that the "unlimited altitude" thing is because of these maneuvers
 			if (owner->pos.y - ground->GetApproximateHeight(owner->pos.x, owner->pos.z) > wantedHeight * 4.0f) {
 				maneuver = 0;
 			}
@@ -769,10 +772,7 @@ void CStrafeAirMoveType::UpdateFlying(float wantedHeight, float engine)
 
 void CStrafeAirMoveType::UpdateLanded()
 {
-	owner->Move3D(owner->speed = ZeroVector, true);
-	// match the terrain normal
-	owner->UpdateDirVectors(true);
-	owner->UpdateMidPos();
+	AAirMoveType::UpdateLanded();
 }
 
 
@@ -844,7 +844,7 @@ void CStrafeAirMoveType::UpdateLanding()
 			owner->Deactivate();
 			owner->script->StopMoving();
 		} else {
-			goalPos.CheckInBounds();
+			goalPos.ClampInBounds();
 			UpdateFlying(wantedHeight, 1);
 			return;
 		}
@@ -890,23 +890,21 @@ void CStrafeAirMoveType::UpdateLanding()
 	owner->UpdateMidPos();
 
 	// see if we are at the reserved (not user-clicked) landing spot
-	if (reservedLandingPosDist < 1.0f) {
-		const float gh = ground->GetHeightAboveWater(pos.x, pos.z);
-		const float gah = ground->GetHeightReal(pos.x, pos.z);
-		float alt = 0.0f;
+	const float gh = ground->GetHeightAboveWater(pos.x, pos.z);
+	const float gah = ground->GetHeightReal(pos.x, pos.z);
+	float altitude = 0.0f;
 
-		// can we submerge and are we still above water?
-		if ((owner->unitDef->canSubmerge) && (gah < 0)) {
-			alt = pos.y - gah;
-			reservedLandingPos.y = gah;
-		} else {
-			alt = pos.y - gh;
-			reservedLandingPos.y = gh;
-		}
+	// can we submerge and are we still above water?
+	if ((owner->unitDef->canSubmerge) && (gah < 0.0f)) {
+		altitude = pos.y - gah;
+		reservedLandingPos.y = gah;
+	} else {
+		altitude = pos.y - gh;
+		reservedLandingPos.y = gh;
+	}
 
-		if (alt <= 1.0f) {
-			SetState(AIRCRAFT_LANDED);
-		}
+	if (altitude <= 1.0f) {
+		SetState(AIRCRAFT_LANDED);
 	}
 }
 
@@ -940,7 +938,7 @@ void CStrafeAirMoveType::UpdateAirPhysics(float rudder, float aileron, float ele
 			engine = std::max(0.0f, std::min(engine, 1 - (pos.y - gHeight - wantedHeight * 1.2f) / wantedHeight));
 		}
 		// check next position given current (unadjusted) pos and speed
-		nextPosInBounds = (pos + speed).CheckInBounds();
+		nextPosInBounds = (pos + speed).IsInBounds();
 	}
 
 
@@ -1065,7 +1063,7 @@ float3 CStrafeAirMoveType::FindLandingPos() const
 		return ret;
 	}
 
-	tryPos.CheckInBounds();
+	tryPos.ClampInBounds();
 
 	const int2 mp = owner->GetMapPos(tryPos);
 
