@@ -12,7 +12,6 @@
 #include "Map/Ground.h"
 #include "Map/ReadMap.h"
 #include "Sim/MoveTypes/MoveInfo.h"
-#include "Sim/MoveTypes/MoveMath/MoveMath.h"
 #include "Sim/Misc/GeometricObjects.h"
 
 #define PATHDEBUG 0
@@ -22,7 +21,7 @@ void* CPathFinder::operator new(size_t size) { return PathAllocator::Alloc(size)
 void CPathFinder::operator delete(void* p, size_t size) { PathAllocator::Free(p, size); }
 #endif
 
-
+const CMoveMath::BlockType squareMobileBlockBits = (CMoveMath::BLOCK_MOBILE | CMoveMath::BLOCK_MOVING | CMoveMath::BLOCK_MOBILE_BUSY);
 
 CPathFinder::CPathFinder()
 	: heatMapOffset(0)
@@ -44,23 +43,48 @@ CPathFinder::CPathFinder()
 	InitHeatMap();
 
 	// Precalculated vectors.
-	directionVector[PATHOPT_RIGHT].x = -2;
-	directionVector[PATHOPT_LEFT ].x =  2;
-	directionVector[PATHOPT_UP   ].x =  0;
-	directionVector[PATHOPT_DOWN ].x =  0;
-	directionVector[(PATHOPT_RIGHT | PATHOPT_UP  )].x = directionVector[PATHOPT_RIGHT].x + directionVector[PATHOPT_UP  ].x;
-	directionVector[(PATHOPT_LEFT  | PATHOPT_UP  )].x = directionVector[PATHOPT_LEFT ].x + directionVector[PATHOPT_UP  ].x;
-	directionVector[(PATHOPT_RIGHT | PATHOPT_DOWN)].x = directionVector[PATHOPT_RIGHT].x + directionVector[PATHOPT_DOWN].x;
-	directionVector[(PATHOPT_LEFT  | PATHOPT_DOWN)].x = directionVector[PATHOPT_LEFT ].x + directionVector[PATHOPT_DOWN].x;
+	dirVectors2D[PATHOPT_RIGHT               ].x = -2;
+	dirVectors2D[PATHOPT_RIGHT               ].y =  0;
+	dirVectors2D[PATHOPT_LEFT                ].x =  2;
+	dirVectors2D[PATHOPT_LEFT                ].y =  0;
+	dirVectors2D[PATHOPT_UP                  ].x =  0;
+	dirVectors2D[PATHOPT_UP                  ].y =  2;
+	dirVectors2D[PATHOPT_DOWN                ].x =  0;
+	dirVectors2D[PATHOPT_DOWN                ].y = -2;
+	dirVectors2D[PATHOPT_RIGHT | PATHOPT_UP  ].x = dirVectors2D[PATHOPT_RIGHT].x + dirVectors2D[PATHOPT_UP  ].x;
+	dirVectors2D[PATHOPT_RIGHT | PATHOPT_UP  ].y = dirVectors2D[PATHOPT_RIGHT].y + dirVectors2D[PATHOPT_UP  ].y;
+	dirVectors2D[PATHOPT_LEFT  | PATHOPT_UP  ].x = dirVectors2D[PATHOPT_LEFT ].x + dirVectors2D[PATHOPT_UP  ].x;
+	dirVectors2D[PATHOPT_LEFT  | PATHOPT_UP  ].y = dirVectors2D[PATHOPT_LEFT ].y + dirVectors2D[PATHOPT_UP  ].y;
+	dirVectors2D[PATHOPT_RIGHT | PATHOPT_DOWN].x = dirVectors2D[PATHOPT_RIGHT].x + dirVectors2D[PATHOPT_DOWN].x;
+	dirVectors2D[PATHOPT_RIGHT | PATHOPT_DOWN].y = dirVectors2D[PATHOPT_RIGHT].y + dirVectors2D[PATHOPT_DOWN].y;
+	dirVectors2D[PATHOPT_LEFT  | PATHOPT_DOWN].x = dirVectors2D[PATHOPT_LEFT ].x + dirVectors2D[PATHOPT_DOWN].x;
+	dirVectors2D[PATHOPT_LEFT  | PATHOPT_DOWN].y = dirVectors2D[PATHOPT_LEFT ].y + dirVectors2D[PATHOPT_DOWN].y;
 
-	directionVector[PATHOPT_RIGHT].y =  0;
-	directionVector[PATHOPT_LEFT ].y =  0;
-	directionVector[PATHOPT_UP   ].y =  2;
-	directionVector[PATHOPT_DOWN ].y = -2;
-	directionVector[(PATHOPT_RIGHT | PATHOPT_UP  )].y = directionVector[PATHOPT_RIGHT].y + directionVector[PATHOPT_UP  ].y;
-	directionVector[(PATHOPT_LEFT  | PATHOPT_UP  )].y = directionVector[PATHOPT_LEFT ].y + directionVector[PATHOPT_UP  ].y;
-	directionVector[(PATHOPT_RIGHT | PATHOPT_DOWN)].y = directionVector[PATHOPT_RIGHT].y + directionVector[PATHOPT_DOWN].y;
-	directionVector[(PATHOPT_LEFT  | PATHOPT_DOWN)].y = directionVector[PATHOPT_LEFT ].y + directionVector[PATHOPT_DOWN].y;
+	dirVectors3D[PATHOPT_RIGHT               ].x = dirVectors2D[PATHOPT_RIGHT].x;
+	dirVectors3D[PATHOPT_RIGHT               ].z = dirVectors2D[PATHOPT_RIGHT].y;
+	dirVectors3D[PATHOPT_LEFT                ].x = dirVectors2D[PATHOPT_LEFT ].x;
+	dirVectors3D[PATHOPT_LEFT                ].z = dirVectors2D[PATHOPT_LEFT ].y;
+	dirVectors3D[PATHOPT_UP                  ].x = dirVectors2D[PATHOPT_UP   ].x;
+	dirVectors3D[PATHOPT_UP                  ].z = dirVectors2D[PATHOPT_UP   ].y;
+	dirVectors3D[PATHOPT_DOWN                ].x = dirVectors2D[PATHOPT_DOWN ].x;
+	dirVectors3D[PATHOPT_DOWN                ].z = dirVectors2D[PATHOPT_DOWN ].y;
+	dirVectors3D[PATHOPT_RIGHT | PATHOPT_UP  ].x = dirVectors2D[PATHOPT_RIGHT | PATHOPT_UP  ].x;
+	dirVectors3D[PATHOPT_RIGHT | PATHOPT_UP  ].z = dirVectors2D[PATHOPT_RIGHT | PATHOPT_UP  ].y;
+	dirVectors3D[PATHOPT_LEFT  | PATHOPT_UP  ].x = dirVectors2D[PATHOPT_LEFT  | PATHOPT_UP  ].x;
+	dirVectors3D[PATHOPT_LEFT  | PATHOPT_UP  ].z = dirVectors2D[PATHOPT_LEFT  | PATHOPT_UP  ].y;
+	dirVectors3D[PATHOPT_RIGHT | PATHOPT_DOWN].x = dirVectors2D[PATHOPT_RIGHT | PATHOPT_DOWN].x;
+	dirVectors3D[PATHOPT_RIGHT | PATHOPT_DOWN].z = dirVectors2D[PATHOPT_RIGHT | PATHOPT_DOWN].y;
+	dirVectors3D[PATHOPT_LEFT  | PATHOPT_DOWN].x = dirVectors2D[PATHOPT_LEFT  | PATHOPT_DOWN].x;
+	dirVectors3D[PATHOPT_LEFT  | PATHOPT_DOWN].z = dirVectors2D[PATHOPT_LEFT  | PATHOPT_DOWN].y;
+
+	dirVectors3D[PATHOPT_RIGHT               ].ANormalize();
+	dirVectors3D[PATHOPT_LEFT                ].ANormalize();
+	dirVectors3D[PATHOPT_UP                  ].ANormalize();
+	dirVectors3D[PATHOPT_DOWN                ].ANormalize();
+	dirVectors3D[PATHOPT_RIGHT | PATHOPT_UP  ].ANormalize();
+	dirVectors3D[PATHOPT_LEFT  | PATHOPT_UP  ].ANormalize();
+	dirVectors3D[PATHOPT_RIGHT | PATHOPT_DOWN].ANormalize();
+	dirVectors3D[PATHOPT_LEFT  | PATHOPT_DOWN].ANormalize();
 
 	moveCost[PATHOPT_RIGHT] = 1;
 	moveCost[PATHOPT_LEFT ] = 1;
@@ -75,7 +99,6 @@ CPathFinder::CPathFinder()
 CPathFinder::~CPathFinder()
 {
 	ResetSearch();
-	squareStates.Clear();
 }
 
 
@@ -151,17 +174,19 @@ IPath::SearchResult CPathFinder::InitSearch(const MoveData& moveData, const CPat
 	if (startzSqr <         0) { startzSqr =            0; }
 	if (startzSqr >= gs->mapy) { startzSqr = gs->mapym1; }
 
-	// If the starting position is a goal position, then no search need to be performed.
-	if (pfDef.IsGoal(startxSqr, startzSqr))
+	const bool isStartGoal = pfDef.IsGoal(startxSqr, startzSqr);
+	// although our starting square may be inside the goal radius, the starting coordinate may be outside.
+	// in this case we do not want to return CantGetCloser, but instead a path to our starting square.
+	if (isStartGoal && pfDef.startInGoalRadius)
 		return IPath::CantGetCloser;
 
 	// Clear the system from last search.
 	ResetSearch();
 
 	// Marks and store the start-square.
-	squareStates[startSquare].nodeMask = (PATHOPT_START | PATHOPT_OPEN);
-	squareStates[startSquare].fCost = 0.0f;
-	squareStates[startSquare].gCost = 0.0f;
+	squareStates.nodeMask[startSquare] = (PATHOPT_START | PATHOPT_OPEN);
+	squareStates.fCost[startSquare] = 0.0f;
+	squareStates.gCost[startSquare] = 0.0f;
 	squareStates.SetMaxFCost(0.0f);
 	squareStates.SetMaxGCost(0.0f);
 
@@ -185,7 +210,7 @@ IPath::SearchResult CPathFinder::InitSearch(const MoveData& moveData, const CPat
 	IPath::SearchResult result = DoSearch(moveData, pfDef, ownerId, synced);
 
 	// if no improvements are found, then return CantGetCloser instead
-	if (goalSquare == startSquare || goalSquare == 0) {
+	if ((goalSquare == startSquare && (!isStartGoal || pfDef.startInGoalRadius)) || goalSquare == 0) {
 		return IPath::CantGetCloser;
 	}
 
@@ -202,7 +227,7 @@ IPath::SearchResult CPathFinder::DoSearch(const MoveData& moveData, const CPathF
 		openSquares.pop();
 
 		// check if this PathNode has become obsolete
-		if (squareStates[os->nodeNum].fCost != os->fCost)
+		if (squareStates.fCost[os->nodeNum] != os->fCost)
 			continue;
 
 		// Check if the goal is reached.
@@ -231,7 +256,7 @@ IPath::SearchResult CPathFinder::DoSearch(const MoveData& moveData, const CPathF
 		}
 
 		// Mark this square as closed.
-		squareStates[os->nodeNum].nodeMask |= PATHOPT_CLOSED;
+		squareStates.nodeMask[os->nodeNum] |= PATHOPT_CLOSED;
 	}
 
 	if (foundGoal)
@@ -261,10 +286,13 @@ bool CPathFinder::TestSquare(
 ) {
 	testedNodes++;
 
+	const int2& dirVec2D = dirVectors2D[enterDirection];
+	const float3& dirVec3D = dirVectors3D[enterDirection];
+
 	// Calculate the new square.
 	int2 square;
-		square.x = parentOpenSquare->nodePos.x + directionVector[enterDirection].x;
-		square.y = parentOpenSquare->nodePos.y + directionVector[enterDirection].y;
+		square.x = parentOpenSquare->nodePos.x + dirVec2D.x;
+		square.y = parentOpenSquare->nodePos.y + dirVec2D.y;
 
 	// Inside map?
 	if (square.x < 0 || square.y < 0 || square.x >= gs->mapx || square.y >= gs->mapy) {
@@ -272,7 +300,7 @@ bool CPathFinder::TestSquare(
 	}
 
 	const int sqrIdx = square.x + square.y * gs->mapx;
-	const int sqrStatus = squareStates[sqrIdx].nodeMask;
+	const int sqrStatus = squareStates.nodeMask[sqrIdx];
 
 	// Check if the square is unaccessable or used.
 	if (sqrStatus & (PATHOPT_CLOSED | PATHOPT_FORBIDDEN | PATHOPT_BLOCKED)) {
@@ -286,35 +314,34 @@ bool CPathFinder::TestSquare(
 	if (!(sqrStatus & PATHOPT_OPEN) &&
 		((blockStatus & CMoveMath::BLOCK_STRUCTURE) || !pfDef.WithinConstraints(square.x, square.y))
 	) {
-		squareStates[sqrIdx].nodeMask |= PATHOPT_BLOCKED;
+		squareStates.nodeMask[sqrIdx] |= PATHOPT_BLOCKED;
 		dirtySquares.push_back(sqrIdx);
 		return false;
 	}
 
 	// Evaluate this square.
-	float squareSpeedMod = moveData.moveMath->GetPosSpeedMod(moveData, square.x, square.y);
+	float squareSpeedMod = moveData.moveMath->GetPosSpeedMod(moveData, square.x, square.y, dirVec3D);
+	float heatCostMod = 1.0f;
 
-	if (squareSpeedMod == 0) {
-		squareStates[sqrIdx].nodeMask |= PATHOPT_FORBIDDEN;
+	if (squareSpeedMod == 0.0f) {
+		squareStates.nodeMask[sqrIdx] |= PATHOPT_FORBIDDEN;
 		dirtySquares.push_back(sqrIdx);
 		return false;
 	}
 
-	static CMoveMath::BlockType blockBits = (CMoveMath::BLOCK_MOBILE | CMoveMath::BLOCK_MOVING | CMoveMath::BLOCK_MOBILE_BUSY);
-
-	if (testMobile && (blockStatus & blockBits)) {
-		if (blockStatus & CMoveMath::BLOCK_MOBILE_BUSY)
-			squareSpeedMod *= 0.10f;
-		else if (blockStatus & CMoveMath::BLOCK_MOBILE)
-			squareSpeedMod *= 0.35f;
-		else //CMoveMath::BLOCK_MOVING
-			squareSpeedMod *= 0.65f;
+	if (testMobile && moveData.avoidMobilesOnPath && (blockStatus & squareMobileBlockBits)) {
+		if (blockStatus & CMoveMath::BLOCK_MOBILE_BUSY) {
+			squareSpeedMod *= moveData.speedModMults[MoveData::SPEEDMOD_MOBILE_BUSY_MULT];
+		} else if (blockStatus & CMoveMath::BLOCK_MOBILE) {
+			squareSpeedMod *= moveData.speedModMults[MoveData::SPEEDMOD_MOBILE_IDLE_MULT];
+		} else { // (blockStatus & CMoveMath::BLOCK_MOVING)
+			squareSpeedMod *= moveData.speedModMults[MoveData::SPEEDMOD_MOBILE_MOVE_MULT];
+		}
 	}
 
 	// Include heatmap cost adjustment.
-	float heatCostMod = 1.0f;
 	if (heatMapping && moveData.heatMapping && GetHeatOwner(square.x, square.y) != ownerId) {
-		heatCostMod += (moveData.heatMod * GetHeatValue(square.x,square.y));
+		heatCostMod += (moveData.heatMod * GetHeatValue(square.x, square.y));
 	}
 
 
@@ -328,12 +355,12 @@ bool CPathFinder::TestSquare(
 	const float fCost = gCost + hCost;                       // f
 
 
-	if (squareStates[sqrIdx].nodeMask & PATHOPT_OPEN) {
+	if (squareStates.nodeMask[sqrIdx] & PATHOPT_OPEN) {
 		// already in the open set
-		if (squareStates[sqrIdx].fCost <= fCost)
+		if (squareStates.fCost[sqrIdx] <= fCost)
 			return true;
 
-		squareStates[sqrIdx].nodeMask &= ~PATHOPT_DIRECTION;
+		squareStates.nodeMask[sqrIdx] &= ~PATHOPT_DIRECTION;
 	}
 
 	// Look for improvements.
@@ -357,9 +384,9 @@ bool CPathFinder::TestSquare(
 	squareStates.SetMaxGCost(std::max(squareStates.GetMaxGCost(), gCost));
 
 	// mark this square as open
-	squareStates[sqrIdx].fCost = os->fCost;
-	squareStates[sqrIdx].gCost = os->gCost;
-	squareStates[sqrIdx].nodeMask |= (PATHOPT_OPEN | enterDirection);
+	squareStates.fCost[sqrIdx] = os->fCost;
+	squareStates.gCost[sqrIdx] = os->gCost;
+	squareStates.nodeMask[sqrIdx] |= (PATHOPT_OPEN | enterDirection);
 	dirtySquares.push_back(sqrIdx);
 	return true;
 }
@@ -383,7 +410,7 @@ void CPathFinder::FinishSearch(const MoveData& moveData, IPath::Path& foundPath)
 		while (true) {
 			const int sqrIdx = square.y * gs->mapx + square.x;
 
-			if (squareStates[sqrIdx].nodeMask & PATHOPT_START)
+			if (squareStates.nodeMask[sqrIdx] & PATHOPT_START)
 				break;
 
 			float3 cs;
@@ -404,8 +431,8 @@ void CPathFinder::FinishSearch(const MoveData& moveData, IPath::Path& foundPath)
 				oldSquare.x = square.x;
 				oldSquare.y = square.y;
 
-			square.x -= directionVector[squareStates[sqrIdx].nodeMask & PATHOPT_DIRECTION].x;
-			square.y -= directionVector[squareStates[sqrIdx].nodeMask & PATHOPT_DIRECTION].y;
+			square.x -= dirVectors2D[squareStates.nodeMask[sqrIdx] & PATHOPT_DIRECTION].x;
+			square.y -= dirVectors2D[squareStates.nodeMask[sqrIdx] & PATHOPT_DIRECTION].y;
 		}
 
 		if (!foundPath.path.empty()) {
@@ -414,7 +441,7 @@ void CPathFinder::FinishSearch(const MoveData& moveData, IPath::Path& foundPath)
 	}
 
 	// Adds the cost of the path.
-	foundPath.pathCost = squareStates[goalSquare].fCost;
+	foundPath.pathCost = squareStates.fCost[goalSquare];
 }
 
 /** Helper function for AdjustFoundPath */
@@ -441,8 +468,8 @@ void CPathFinder::AdjustFoundPath(const MoveData& moveData, IPath::Path& foundPa
 	do {                                                                                         \
 		int testsqr = square.x + (dxtest) + (square.y + (dytest)) * gs->mapx;                    \
 		int p2sqr = previous[2].x + previous[2].y * gs->mapx;                                    \
-		if (!(squareStates[testsqr].nodeMask & (PATHOPT_BLOCKED | PATHOPT_FORBIDDEN)) &&         \
-			 squareStates[testsqr].fCost <= (COSTMOD) * squareStates[p2sqr].fCost) {             \
+		if (!(squareStates.nodeMask[testsqr] & (PATHOPT_BLOCKED | PATHOPT_FORBIDDEN)) &&         \
+			 squareStates.fCost[testsqr] <= (COSTMOD) * squareStates.fCost[p2sqr]) {             \
 			float3& p2 = foundPath.path[foundPath.path.size() - 2];                              \
 			float3& p1 = foundPath.path.back();                                                  \
 			float3& p0 = nextPoint;                                                              \
@@ -550,9 +577,9 @@ void CPathFinder::ResetSearch()
 		const int lsquare = dirtySquares.back();
 		dirtySquares.pop_back();
 
-		squareStates[lsquare].nodeMask = 0;
-		squareStates[lsquare].fCost = PATHCOST_INFINITY;
-		squareStates[lsquare].gCost = PATHCOST_INFINITY;
+		squareStates.nodeMask[lsquare] = 0;
+		squareStates.fCost[lsquare] = PATHCOST_INFINITY;
+		squareStates.gCost[lsquare] = PATHCOST_INFINITY;
 	}
 	testedNodes = 0;
 }
