@@ -59,8 +59,8 @@ unsigned int CPathManager::RequestPath(
 	CSolidObject* caller,
 	bool synced
 ) {
-	float3 sp(startPos); sp.CheckInBounds();
-	float3 gp(goalPos); gp.CheckInBounds();
+	float3 sp(startPos); sp.ClampInBounds();
+	float3 gp(goalPos); gp.ClampInBounds();
 
 	// Create an estimator definition.
 	CRangedGoalWithCircularConstraint* pfDef = new CRangedGoalWithCircularConstraint(sp, gp, goalRadius, 3.0f, 2000);
@@ -282,28 +282,30 @@ void CPathManager::LowRes2MedRes(MultiPath& multiPath, const float3& startPos, i
 /*
 Removes and return the next waypoint in the multipath corresponding to given id.
 */
-float3 CPathManager::NextWaypoint(
+float3 CPathManager::NextWayPoint(
 	unsigned int pathId,
 	float3 callerPos,
 	float minDistance,
 	int numRetries,
 	int ownerId,
 	bool synced
-) const {
-	SCOPED_TIMER("PathManager::NextWaypoint");
+) {
+	SCOPED_TIMER("PathManager::NextWayPoint");
+
+	const float3 noPathPoint = float3(-1.0f, 0.0f, -1.0f);
 
 	// 0 indicates a no-path id
 	if (pathId == 0)
-		return float3(-1.0f, -1.0f, -1.0f);
+		return noPathPoint;
 
 	if (numRetries > 4)
-		return float3(-1.0f, -1.0f, -1.0f);
+		return noPathPoint;
 
 	// Find corresponding multipath.
 	const std::map<unsigned int, MultiPath*>::const_iterator pi = pathMap.find(pathId);
 
 	if (pi == pathMap.end())
-		return float3(-1.0f, -1.0f, -1.0f);
+		return noPathPoint;
 
 	MultiPath* multiPath = pi->second;
 
@@ -336,21 +338,25 @@ float3 CPathManager::NextWaypoint(
 	}
 
 	float3 waypoint;
+
 	do {
 		// get the next waypoint from the high-res path
 		//
 		// if this is not possible, then either we are
 		// at the goal OR the path could not reach all
 		// the way to it (ie. a GoalOutOfRange result)
+		// OR we are stuck on an impassable square
 		if (multiPath->maxResPath.path.empty()) {
 			if (multiPath->lowResPath.path.empty() && multiPath->medResPath.path.empty()) {
 				if (multiPath->searchResult == IPath::Ok) {
-					return multiPath->finalGoal;
+					waypoint = multiPath->finalGoal; break;
 				} else {
-					return float3(-1.0f, -1.0f, -1.0f);
+					// note: unreachable?
+					waypoint = noPathPoint; break;
 				}
 			} else {
-				return NextWaypoint(pathId, callerPos, minDistance, numRetries + 1, ownerId, synced);
+				waypoint = NextWayPoint(pathId, callerPos, minDistance, numRetries + 1, ownerId, synced);
+				break;
 			}
 		} else {
 			waypoint = multiPath->maxResPath.path.back();
@@ -358,6 +364,10 @@ float3 CPathManager::NextWaypoint(
 		}
 	} while (callerPos.SqDistance2D(waypoint) < Square(minDistance) && waypoint != multiPath->maxResPath.pathGoal);
 
+	// indicate this is not a temporary waypoint
+	// (the default PFS does not queue requests)
+	waypoint.y = 0.0f;
+
 	return waypoint;
 }
 
@@ -472,7 +482,7 @@ void CPathManager::GetDetailedPathSquares(unsigned pathId, std::vector<int2>& po
 
 
 
-void CPathManager::GetEstimatedPath(
+void CPathManager::GetPathWayPoints(
 	unsigned int pathId,
 	std::vector<float3>& points,
 	std::vector<int>& starts
