@@ -11,15 +11,16 @@ class CGeoThermSmokeProjectile : public CSmokeProjectile
 {
 	CR_DECLARE(CGeoThermSmokeProjectile)
 public:
-	CGeoThermSmokeProjectile(const float3& pos, const float3& speed, int ttl, CFeature* geo);
+	CGeoThermSmokeProjectile(const float3& pos, const float3& speed, int ttl,
+			CFeature* geo);
 
 	void Update();
-	virtual void DrawOnMinimap(CVertexArray& lines, CVertexArray& points) {};
+	virtual void DrawOnMinimap(CVertexArray& lines, CVertexArray& points) {}
 
-	CFeature* geo;
-
-public:
 	static void GeoThermDestroyed(const CFeature* geo);
+
+private:
+	CFeature* geo;
 };
 
 #endif // GEO_THERM_SMOKE_H
