@@ -1,14 +1,13 @@
 /* This file is part of the Spring engine (GPL v2 or later), see LICENSE.html */
 
-#include "StdAfx.h"
-#include "mmgr.h"
+#include "System/mmgr.h"
 
 #include "Game/Camera.h"
+#include "Game/GlobalUnsynced.h"
 #include "MuzzleFlame.h"
-#include "Rendering/ProjectileDrawer.hpp"
+#include "Rendering/ProjectileDrawer.h"
 #include "Rendering/GL/VertexArray.h"
 #include "Rendering/Textures/TextureAtlas.h"
-#include "System/GlobalUnsynced.h"
 
 
 CR_BIND_DERIVED(CMuzzleFlame, CProjectile, (ZeroVector, ZeroVector, ZeroVector, 0));
@@ -30,7 +29,7 @@ void CMuzzleFlame::creg_Serialize(creg::ISerializer& s)
 }
 
 CMuzzleFlame::CMuzzleFlame(const float3& pos, const float3& speed, const float3& dir, float size):
-	CProjectile(pos, speed, 0, false, false, false),
+	CProjectile(pos, speed, NULL, false, false, false),
 	dir(dir),
 	size(size),
 	age(0)
