@@ -14,17 +14,20 @@ class CSmokeProjectile : public CProjectile
 
 public:
 	CSmokeProjectile();
-	CSmokeProjectile(const float3& pos, const float3& speed, float ttl, float startSize, float sizeExpansion, CUnit* owner, float color);
-	virtual ~CSmokeProjectile();
+	CSmokeProjectile(const float3& pos, const float3& speed, float ttl,
+			float startSize, float sizeExpansion, CUnit* owner, float color);
 
 	void Update();
 	void Draw();
 	void Init(const float3& pos, CUnit* owner);
 
+private:
 	float color;
 	float age;
 	float ageSpeed;
+public:
 	float size;
+private:
 	float startSize;
 	float sizeExpansion;
 	int textureNum;
