@@ -11,16 +11,19 @@ class CSmokeTrailProjectile : public CProjectile
 {
 	CR_DECLARE(CSmokeTrailProjectile);
 public:
-	CSmokeTrailProjectile(const float3& pos1, const float3& pos2, const float3& dir1, const float3& dir2, CUnit* owner, bool firstSegment, bool lastSegment, float size = 1, float time = 80, float color = 0.7f, bool drawTrail = true, CProjectile* drawCallback = 0, AtlasedTexture* texture = 0);
+	CSmokeTrailProjectile(const float3& pos1, const float3& pos2, const float3& dir1, const float3& dir2, CUnit* owner, bool firstSegment, bool lastSegment, float size = 1, int time = 80, float color = 0.7f, bool drawTrail = true, CProjectile* drawCallback = 0, AtlasedTexture* texture = 0);
 	virtual ~CSmokeTrailProjectile();
 
 	void Update();
 	void Draw();
 
+private:
 	float3 pos1;
 	float3 pos2;
 	float orgSize;
+public:
 	int creationTime;
+private:
 	int lifeTime;
 	float color;
 	float3 dir1;
@@ -32,8 +35,11 @@ public:
 	float3 midpos;
 	float3 middir;
 	bool drawSegmented;
-	bool firstSegment, lastSegment;
+	bool firstSegment;
+	bool lastSegment;
+public:
 	CProjectile* drawCallbacker;
+private:
 	AtlasedTexture* texture;
 };
 
