@@ -11,13 +11,15 @@ public:
 	CR_DECLARE(CTracerProjectile);
 
 	CTracerProjectile();
-	CTracerProjectile(const float3 pos, const float3 speed, const float range, CUnit* owner);
+	CTracerProjectile(const float3& pos, const float3& speed, const float range,
+			CUnit* owner);
 	virtual ~CTracerProjectile();
 
 	void Draw();
 	void Update();
 	void Init(const float3& pos, CUnit *owner);
 
+private:
 	float speedf;
 	float length;
 	float drawLength;
