@@ -9,12 +9,15 @@ class CWakeProjectile : public CProjectile
 {
 	CR_DECLARE(CWakeProjectile);
 public:
-	CWakeProjectile(const float3 pos, const float3 speed, float startSize, float sizeExpansion, CUnit* owner, float alpha, float alphaFalloff, float fadeupTime);
-	virtual ~CWakeProjectile();
+	CWakeProjectile(const float3& pos, const float3& speed, float startSize,
+			float sizeExpansion, CUnit* owner, float alpha, float alphaFalloff,
+			float fadeupTime);
+	~CWakeProjectile() {}
 
 	void Update();
 	void Draw();
 
+private:
 	float alpha;
 	float alphaFalloff;
 	float alphaAdd;
