@@ -1,7 +1,7 @@
 /* This file is part of the Spring engine (GPL v2 or later), see LICENSE.html */
 
-#ifndef BEAMLASERPROJECTILE_H
-#define BEAMLASERPROJECTILE_H
+#ifndef BEAM_LASER_PROJECTILE_H
+#define BEAM_LASER_PROJECTILE_H
 
 #include "WeaponProjectile.h"
 
@@ -12,8 +12,13 @@ public:
 	CBeamLaserProjectile(const float3& startPos, const float3& endPos,
 		float startAlpha, float endAlpha, const float3& color,
 		CUnit* owner, const WeaponDef* weaponDef);
-	~CBeamLaserProjectile(void) {}
+	~CBeamLaserProjectile() {}
 
+	void Update();
+	void Draw();
+	virtual void DrawOnMinimap(CVertexArray& lines, CVertexArray& points);
+
+private:
 	float3 startPos;
 	float3 endPos;
 	unsigned char corecolstart[4];
@@ -27,10 +32,6 @@ public:
 	float midtexx;
 	
 	float decay;
-
-	void Update(void);
-	void Draw(void);
-	virtual void DrawOnMinimap(CVertexArray& lines, CVertexArray& points);
 };
 
-#endif
+#endif // BEAM_LASER_PROJECTILE_H
