@@ -43,7 +43,7 @@ CExplosiveProjectile::CExplosiveProjectile(
 	useAirLos = true;
 
 	if (weaponDef) {
-		SetRadius(weaponDef->collisionSize);
+		SetRadiusAndHeight(weaponDef->collisionSize, 0.0f);
 		drawRadius = weaponDef->size;
 	}
 
