@@ -1,16 +1,17 @@
 /* This file is part of the Spring engine (GPL v2 or later), see LICENSE.html */
 
-#ifndef WEAPONPROJECTILE_H
-#define WEAPONPROJECTILE_H
+#ifndef WEAPON_PROJECTILE_H
+#define WEAPON_PROJECTILE_H
 
 #include "Sim/Projectiles/Projectile.h"
-#include "Sim/Misc/DamageArray.h"
 
 struct WeaponDef;
 class CPlasmaRepulser;
-/*
-* Base class for all projectiles originating from a weapon or having weapon-properties. Uses data from a weapon definition.
-*/
+
+/**
+ * Base class for all projectiles originating from a weapon or having
+ * weapon-properties. Uses data from a weapon definition.
+ */
 class CWeaponProjectile : public CProjectile
 {
 	CR_DECLARE(CWeaponProjectile);
@@ -32,27 +33,28 @@ public:
 
 	CWeaponProjectile();
 	CWeaponProjectile(const float3& pos, const float3& speed, CUnit* owner,
-			CUnit* target, const float3 &targetPos, const WeaponDef *weaponDef,
+			CUnit* target, const float3& targetPos, const WeaponDef* weaponDef,
 			CWeaponProjectile* interceptTarget, int ttl);
-	virtual ~CWeaponProjectile();
+	virtual ~CWeaponProjectile() {}
 
 	virtual void Collision();
 	virtual void Collision(CFeature* feature);
 	virtual void Collision(CUnit* unit);
 	virtual void Update();
-	virtual int ShieldRepulse(CPlasmaRepulser* shield, float3 shieldPos, float shieldForce, float shieldMaxSpeed) { return 0; };	//return 0=unaffected,1=instant repulse,2=gradual repulse
+	/// @return 0=unaffected, 1=instant repulse, 2=gradual repulse
+	virtual int ShieldRepulse(CPlasmaRepulser* shield, float3 shieldPos, float shieldForce, float shieldMaxSpeed) { return 0; }
 
 	virtual void DrawOnMinimap(CVertexArray& lines, CVertexArray& points);
 
-	// true if we are a nuke and an anti is on the way
+	/// true if we are a nuke and an anti is on the way
 	bool targeted;
 	const WeaponDef* weaponDef;
 	std::string weaponDefName;
 	CUnit* target;
 	float3 targetPos;
 
-	CCustomExplosionGenerator ceg;
 	std::string cegTag;
+	unsigned int cegID;
 
 	int colorTeam;
 
@@ -73,5 +75,4 @@ public:
 	void PostLoad();
 };
 
-
-#endif /* WEAPONPROJECTILE_H */
+#endif /* WEAPON_PROJECTILE_H */
