@@ -1,35 +1,45 @@
 /* This file is part of the Spring engine (GPL v2 or later), see LICENSE.html */
 
-#ifndef __AIR_CAI_H__
-#define __AIR_CAI_H__
+#ifndef AIR_CAI_H
+#define AIR_CAI_H
 
 #include "MobileCAI.h"
 
-class CAirCAI :
-	public CMobileCAI
+class CUnit;
+class CFeature;
+struct Command;
+
+class CAirCAI : public CMobileCAI
 {
 public:
 	CR_DECLARE(CAirCAI);
 	CAirCAI(CUnit* owner);
 	CAirCAI();
-	~CAirCAI(void);
+	~CAirCAI();
 
 	int GetDefaultCmd(const CUnit* pointed, const CFeature* feature);
 	void SlowUpdate();
-	void GiveCommandReal(const Command &c);
-	void DrawCommands(void);
+	void GiveCommandReal(const Command& c);
 	void AddUnit(CUnit* unit);
-	void FinishCommand(void);
-	void BuggerOff(float3 pos, float radius);
+	void FinishCommand();
+	void BuggerOff(const float3& pos, float radius);
 //	void StopMove();
 	
 	void SetGoal(const float3& pos, const float3& curPos, float goalRadius = SQUARE_SIZE);
 	
-	void ExecuteGuard(Command &c);
-	void ExecuteAreaAttack(Command &c);
-	void ExecuteAttack(Command &c);
-	void ExecuteFight(Command &c);
-//	void ExecuteMove(Command &c);
+	void ExecuteGuard(Command& c);
+	void ExecuteAreaAttack(Command& c);
+	void ExecuteAttack(Command& c);
+	void ExecuteFight(Command& c);
+//	void ExecuteMove(Command& c);
+
+	bool IsValidTarget(const CUnit* enemy) const;
+
+private:
+	void PushOrUpdateReturnFight() {
+		CCommandAI::PushOrUpdateReturnFight(commandPos1, commandPos2);
+	}
+
 
 	float3 basePos;
 	float3 baseDir;
@@ -40,13 +50,6 @@ public:
 
 	int lastPC1;
 	int lastPC2;
-
-	bool IsValidTarget(const CUnit* enemy) const;
-
-protected:
-	void PushOrUpdateReturnFight() {
-		CCommandAI::PushOrUpdateReturnFight(commandPos1, commandPos2);
-	}
 };
 
-#endif // __AIR_CAI_H__
+#endif // AIR_CAI_H
