@@ -4,11 +4,12 @@
 #define COMMAND_H
 
 #include <string>
-#include <vector>
-#include <limits.h> // for INT_MAX
-#include "creg/creg_cond.h"
+#include <climits> // for INT_MAX
 
-// cmds lower than 0 is reserved for build options (cmd -x = unitdefs[x])
+#include "System/creg/creg_cond.h"
+#include "System/SafeVector.h"
+
+// ID's lower than 0 are reserved for build options (cmd -x = unitdefs[x])
 #define CMD_STOP                   0
 #define CMD_INSERT                 1
 #define CMD_REMOVE                 2
@@ -23,7 +24,7 @@
 #define CMD_ATTACK                20
 #define CMD_AREA_ATTACK           21
 #define CMD_GUARD                 25
-#define CMD_AISELECT              30
+#define CMD_AISELECT              30 //FIXME REMOVE
 #define CMD_GROUPSELECT           35
 #define CMD_GROUPADD              36
 #define CMD_GROUPCLEAR            37
@@ -42,7 +43,7 @@
 #define CMD_RECLAIM               90
 #define CMD_CLOAK                 95
 #define CMD_STOCKPILE            100
-#define CMD_DGUN                 105
+#define CMD_MANUALFIRE           105
 #define CMD_RESTORE              110
 #define CMD_REPEAT               115
 #define CMD_TRAJECTORY           120
@@ -91,47 +92,159 @@
 
 #define INTERNAL_ORDER  (DONT_REPEAT)
 
+enum {
+	MOVESTATE_NONE     = -1,
+	MOVESTATE_HOLDPOS  =  0,
+	MOVESTATE_MANEUVER =  1,
+	MOVESTATE_ROAM     =  2,
+};
+enum {
+	FIRESTATE_NONE       = -1,
+	FIRESTATE_HOLDFIRE   =  0,
+	FIRESTATE_RETURNFIRE =  1,
+	FIRESTATE_FIREATWILL =  2,
+};
 
 struct Command
 {
 private:
 	CR_DECLARE_STRUCT(Command);
+/*
+	TODO check if usage of System/MemPool.h for this struct improves performance
+	#if !defined(USE_MMGR) && !(defined(USE_GML) && GML_ENABLE_SIM)
+	inline void* operator new(size_t size) { return mempool.Alloc(size); }
+	inline void operator delete(void* p, size_t size) { mempool.Free(p, size); }
+	#endif
+*/
 
 public:
-	Command():
-		id(0),
-		options(0),
-		tag(0),
-		timeOut(INT_MAX) {}
+	Command(const int cmdID)
+		: aiCommandId(-1)
+		, options(0)
+		, tag(0)
+		, timeOut(INT_MAX)
+		, id(cmdID)
+	{}
 
-	bool IsAreaCommand() const {
-		if (id == CMD_REPAIR ||
-			id == CMD_RECLAIM ||
-			id == CMD_CAPTURE ||
-			id == CMD_RESURRECT ||
-			id == CMD_LOAD_UNITS ||
-			id == CMD_UNLOAD_UNITS) {
-			// params[0..2] always holds the position, params[3] the radius
-			return (params.size() == 4);
-		}
-		if (id == CMD_AREA_ATTACK) {
-			return true;
-		}
+	Command(const int cmdID, const unsigned char cmdOptions)
+		: aiCommandId(-1)
+		, options(cmdOptions)
+		, tag(0)
+		, timeOut(INT_MAX)
+		, id(cmdID)
+	{}
 
+	Command()
+		: aiCommandId(-1)
+		, options(0)
+		, tag(0)
+		, timeOut(INT_MAX)
+		, id(0)
+	{}
+
+	Command(const Command& c)
+		: aiCommandId(c.aiCommandId)
+		, options(c.options)
+		, params(c.params)
+		, tag(c.tag)
+		, timeOut(c.timeOut)
+		, id(c.id)
+	{}
+
+	Command& operator = (const Command& c) {
+		id = c.id;
+		aiCommandId = c.aiCommandId;
+		options = c.options;
+		tag = c.tag;
+		timeOut = c.timeOut;
+		params = c.params;
+		return *this;
+	}
+
+	~Command() { params.clear(); }
+
+	// returns true if the command references another object and
+	// in this case also returns the param index of the object in cpos
+	bool IsObjectCommand(int &cpos) const {
+		int psize = params.size();
+		switch(id) {
+			case CMD_ATTACK:
+			case CMD_FIGHT:
+			case CMD_MANUALFIRE:
+				cpos = 0;
+				return 1 <= psize && psize < 3;
+			case CMD_GUARD:
+			case CMD_LOAD_ONTO:
+				cpos = 0;
+				return psize >= 1;
+			case CMD_CAPTURE:
+			case CMD_LOAD_UNITS:
+			case CMD_RECLAIM:
+			case CMD_REPAIR:
+			case CMD_RESURRECT:
+				cpos = 0;
+				return 1 <= psize && psize < 4;
+			case CMD_UNLOAD_UNIT:
+				cpos = 3;
+				return psize >= 4;
+			case CMD_INSERT: {
+				if (psize < 3)
+					return false;
+				Command icmd((int)params[1], (unsigned char)params[2]);
+				for (int p = 3; p < (int)psize; p++)
+					icmd.params.push_back(params[p]);
+				if (!icmd.IsObjectCommand(cpos))
+					return false;
+				cpos += 3;
+				return true;
+			}
+		}
 		return false;
 	}
 
-	/// CMD_xxx code  (custom codes can also be used)
-	int id;
-	/// option bits
-	unsigned char options;
-	/// command parameters
-	std::vector<float> params;
-	/// adds a value to this commands parameter list
-	void AddParam(float par) {
-		params.push_back(par);
+	bool IsAreaCommand() const {
+		switch(id) {
+			case CMD_CAPTURE:
+			case CMD_LOAD_UNITS:
+			case CMD_RECLAIM:
+			case CMD_REPAIR:
+			case CMD_RESURRECT:
+				// params[0..2] always holds the position, params[3] the radius
+				return (params.size() == 4);
+			case CMD_UNLOAD_UNITS:
+				return (params.size() == 5);
+			case CMD_AREA_ATTACK:
+				return true;
+		}
+		return false;
 	}
 
+	void AddParam(float par) { params.push_back(par); }
+	const float& GetParam(size_t idx) const { return params[idx]; }
+
+	/// const safe_vector<float>& GetParams() const { return params; }
+	const size_t GetParamsCount() const { return params.size(); }
+
+	void SetID(int id) 
+#ifndef _MSC_VER
+		__attribute__ ((deprecated)) 
+#endif
+		{ this->id = id; params.clear(); }
+	const int& GetID() const { return id; }
+
+public:
+	/**
+	 * AI Command callback id (passed in on handleCommand, returned
+	 * in CommandFinished event)
+	 */
+	int aiCommandId;
+
+	/// option bits (RIGHT_MOUSE_KEY, ...)
+	unsigned char options;
+
+	/// command parameters
+	safe_vector<float> params;
+
 	/// unique id within a CCommandQueue
 	unsigned int tag;
 
@@ -145,6 +258,10 @@ public:
 	 * - currenFrame + 60
 	 */
 	int timeOut;
+
+private:
+	/// CMD_xxx code  (custom codes can also be used)
+	int id;
 };
 
 
@@ -161,7 +278,7 @@ public:
 		showUnique(false),
 		onlyTexture(false) {}
 
-	/// CMD_xxx     code (custom codes can also be used)
+	/// CMD_xxx code (custom codes can also be used)
 	int id;
 	/// CMDTYPE_xxx code
 	int type;
