@@ -836,9 +836,10 @@ void CCommandAI::GiveWaitCommand(const Command& c)
 			return;
 		}
 	}
-	else if (commandQue.front().GetID()== CMD_WAIT) {
+	else if (commandQue.front().GetID() == CMD_WAIT) {
 		waitCommandsAI.RemoveWaitCommand(owner, commandQue.front());
 		commandQue.pop_front();
+		return;
 	}
 	else {
 		// shutdown the current order
@@ -856,12 +857,9 @@ void CCommandAI::GiveWaitCommand(const Command& c)
 			eoh->UnitIdle(*owner);
 		}
 		eventHandler.UnitIdle(owner);
-	}
-	else {
+	} else {
 		SlowUpdate();
 	}
-
-	return;
 }
 
 
@@ -1414,7 +1412,8 @@ void CCommandAI::FinishCommand()
 		eventHandler.UnitIdle(owner);
 	}
 
-	if (lastFinishCommand != gs->frameNum) {	//avoid infinite loops
+	// avoid infinite loops
+	if (lastFinishCommand != gs->frameNum) {
 		lastFinishCommand = gs->frameNum;
 		if (!owner->stunned) {
 			SlowUpdate();
@@ -1635,7 +1634,7 @@ void CCommandAI::SlowUpdateMaxSpeed() {
 		return;
 
 	// grab the second command
-	CCommandQueue::const_iterator it = commandQue.begin(); ++it;
+	const CCommandQueue::const_iterator it = ++(commandQue.begin());
 	const Command& c = *it;
 
 	// treat any following CMD_SET_WANTED_MAX_SPEED commands as options
@@ -1645,7 +1644,8 @@ void CCommandAI::SlowUpdateMaxSpeed() {
 	if (c.params.empty())
 		return;
 
-	const float defMaxSpeed = owner->moveType->GetMaxSpeed();
+	// always clamp the command parameter
+	const float defMaxSpeed = owner->moveType->GetMaxSpeedDef();
 	const float newMaxSpeed = std::min(c.params[0], defMaxSpeed);
 
 	if (newMaxSpeed > 0.0f) {
