@@ -1268,12 +1268,13 @@ int CUnitScript::GetUnitVal(int val, int p1, int p2, int p3, int p4)
 		return 1;
 	}
 	case WEAPON_RELOADSTATE: {
+		const int np1 = -p1;
 		if (p1 > 0 && static_cast<size_t>(p1) <= unit->weapons.size()) {
 			return unit->weapons[p1-1]->reloadStatus;
 		}
-		else if (p1 < 0 && p1 >= (0 - unit->weapons.size())) {
-			int old = unit->weapons[-p1-1]->reloadStatus;
-			unit->weapons[-p1-1]->reloadStatus = p2;
+		else if (np1 > 0 && static_cast<size_t>(np1) <= unit->weapons.size()) {
+			const int old = unit->weapons[np1 - 1]->reloadStatus;
+			unit->weapons[np1 - 1]->reloadStatus = p2;
 			return old;
 		}
 		else {
@@ -1281,12 +1282,13 @@ int CUnitScript::GetUnitVal(int val, int p1, int p2, int p3, int p4)
 		}
 	}
 	case WEAPON_RELOADTIME: {
+		const int np1 = -p1;
 		if (p1 > 0 && static_cast<size_t>(p1) <= unit->weapons.size()) {
 			return unit->weapons[p1-1]->reloadTime;
 		}
-		else if (p1 < 0 && p1 >= 0 - unit->weapons.size()) {
-			int old = unit->weapons[-p1-1]->reloadTime;
-			unit->weapons[-p1-1]->reloadTime = p2;
+		else if (np1 > 0 && static_cast<size_t>(np1) <= unit->weapons.size()) {
+			const int old = unit->weapons[np1 - 1]->reloadTime;
+			unit->weapons[np1 - 1]->reloadTime = p2;
 			return old;
 		}
 		else {
@@ -1294,12 +1296,13 @@ int CUnitScript::GetUnitVal(int val, int p1, int p2, int p3, int p4)
 		}
 	}
 	case WEAPON_ACCURACY: {
+		const int np1 = -p1;
 		if (p1 > 0 && static_cast<size_t>(p1) <= unit->weapons.size()) {
 			return int(unit->weapons[p1-1]->accuracy * COBSCALE);
 		}
-		else if (p1 < 0 && p1 >= (0 - unit->weapons.size())) {
-			int old = int(unit->weapons[-p1-1]->accuracy * COBSCALE);
-			unit->weapons[-p1-1]->accuracy = float(p2) / COBSCALE;
+		else if (np1 > 0 && static_cast<size_t>(np1) <= unit->weapons.size()) {
+			const int old = unit->weapons[np1 - 1]->accuracy * COBSCALE;
+			unit->weapons[np1 - 1]->accuracy = float(p2) / COBSCALE;
 			return old;
 		}
 		else {
@@ -1307,12 +1310,13 @@ int CUnitScript::GetUnitVal(int val, int p1, int p2, int p3, int p4)
 		}
 	}
 	case WEAPON_SPRAY: {
+		const int np1 = -p1;
 		if (p1 > 0 && static_cast<size_t>(p1) <= unit->weapons.size()) {
 			return int(unit->weapons[p1-1]->sprayAngle * COBSCALE);
 		}
-		else if (p1 < 0 && p1 >= (0 - unit->weapons.size())) {
-			int old = int(unit->weapons[-p1-1]->sprayAngle * COBSCALE);
-			unit->weapons[-p1-1]->sprayAngle = float(p2) / COBSCALE;
+		else if (np1 > 0 && static_cast<size_t>(np1) <= unit->weapons.size()) {
+			const int old = unit->weapons[np1 - 1]->sprayAngle * COBSCALE;
+			unit->weapons[np1 - 1]->sprayAngle = float(p2) / COBSCALE;
 			return old;
 		}
 		else {
@@ -1320,12 +1324,13 @@ int CUnitScript::GetUnitVal(int val, int p1, int p2, int p3, int p4)
 		}
 	}
 	case WEAPON_RANGE: {
+		const int np1 = -p1;
 		if (p1 > 0 && static_cast<size_t>(p1) <= unit->weapons.size()) {
-			return int(unit->weapons[p1-1]->range * COBSCALE);
+			return int(unit->weapons[p1 - 1]->range * COBSCALE);
 		}
-		else if (p1 < 0 && p1 >= (0 - unit->weapons.size())) {
-			int old = int(unit->weapons[-p1-1]->range * COBSCALE);
-			unit->weapons[-p1-1]->range = float(p2) / COBSCALE;
+		else if (np1 > 0 && static_cast<size_t>(np1) <= unit->weapons.size()) {
+			const int old = unit->weapons[np1 - 1]->range * COBSCALE;
+			unit->weapons[np1 - 1]->range = float(p2) / COBSCALE;
 			return old;
 		}
 		else {
@@ -1333,12 +1338,13 @@ int CUnitScript::GetUnitVal(int val, int p1, int p2, int p3, int p4)
 		}
 	}
 	case WEAPON_PROJECTILE_SPEED: {
+		const int np1 = -p1;
 		if (p1 > 0 && static_cast<size_t>(p1) <= unit->weapons.size()) {
 			return int(unit->weapons[p1-1]->projectileSpeed * COBSCALE);
 		}
-		else if (p1 < 0 && p1 >= (0 - unit->weapons.size())) {
-			int old = int(unit->weapons[-p1-1]->projectileSpeed * COBSCALE);
-			unit->weapons[-p1-1]->projectileSpeed = float(p2) / COBSCALE;
+		else if (np1 > 0 && static_cast<size_t>(np1) <= unit->weapons.size()) {
+			const int old = unit->weapons[np1 - 1]->projectileSpeed * COBSCALE;
+			unit->weapons[np1 - 1]->projectileSpeed = float(p2) / COBSCALE;
 			return old;
 		}
 		else {
