@@ -563,40 +563,47 @@ bool CBuilder::StartBuild(BuildInfo& buildInfo, CFeature*& feature, bool& waitst
 
 	// Pass -1 as allyteam to behave like we have maphack.
 	// This is needed to prevent building on top of cloaked stuff.
-	const int canBuild = uh->TestUnitBuildSquare(buildInfo, feature, -1, true);
+	const BuildSquareStatus tbs = uh->TestUnitBuildSquare(buildInfo, feature, -1, true);
 
-	if (canBuild < 2) {
-		// the ground is blocked at the position we want
-		// to build at; check if the blocking object is
-		// of the same type as our buildee (which means
-		// another builder has already started it)
-		// note: even if construction has already started,
-		// the buildee is *not* guaranteed to be the unit
-		// closest to us
-		CSolidObject* o = groundBlockingObjectMap->GroundBlocked(buildInfo.pos);
-		CUnit* u = NULL;
+	switch (tbs) {
+		case BUILDSQUARE_OPEN:
+			break;
 
-		if (o != NULL) {
-			u = dynamic_cast<CUnit*>(o);
-		} else {
-			// <pos> might map to a non-blocking portion
-			// of the buildee's yardmap, fallback check
-			u = helper->GetClosestFriendlyUnit(buildInfo.pos, buildDistance, allyteam);
+		case BUILDSQUARE_BLOCKED:
+		case BUILDSQUARE_OCCUPIED: {
+			// the ground is blocked at the position we want
+			// to build at; check if the blocking object is
+			// of the same type as our buildee (which means
+			// another builder has already started it)
+			// note: even if construction has already started,
+			// the buildee is *not* guaranteed to be the unit
+			// closest to us
+			CSolidObject* o = groundBlockingObjectMap->GroundBlocked(buildInfo.pos);
+			CUnit* u = NULL;
+
+			if (o != NULL) {
+				u = dynamic_cast<CUnit*>(o);
+			} else {
+				// <pos> might map to a non-blocking portion
+				// of the buildee's yardmap, fallback check
+				u = helper->GetClosestFriendlyUnit(buildInfo.pos, buildDistance, allyteam);
+			}
+
+			if (u != NULL && u->unitDef == buildInfo.def && unitDef->canAssist) {
+				curBuild = u;
+				AddDeathDependence(u, DEPENDENCE_BUILD);
+				SetBuildStanceToward(buildInfo.pos);
+				return true;
+			}
+
+			return false;
 		}
 
-		if (u != NULL && u->unitDef == buildInfo.def && unitDef->canAssist) {
-			curBuild = u;
-			AddDeathDependence(u, DEPENDENCE_BUILD);
-			SetBuildStanceToward(buildInfo.pos);
-			return true;
-		}
-
-		return false;
+		case BUILDSQUARE_RECLAIMABLE:
+			// caller should handle this
+			return false;
 	}
 
-	if (feature)
-		return false;
-
 	const UnitDef* unitDef = buildInfo.def;
 	SetBuildStanceToward(buildInfo.pos);
 
