@@ -1,7 +1,7 @@
 /* This file is part of the Spring engine (GPL v2 or later), see LICENSE.html */
 
-#ifndef __CANNON_H__
-#define __CANNON_H__
+#ifndef _CANNON_H
+#define _CANNON_H
 
 #include "Weapon.h"
 
@@ -18,13 +18,19 @@ protected:
 
 public:
 	CCannon(CUnit* owner);
-	virtual ~CCannon();
-	void Init(void);
-	bool TryTarget(const float3& pos,bool userTarget,CUnit* unit);
+	~CCannon();
+
+	void Init();
+	void UpdateRange(float val);
+	bool TryTarget(const float3& pos, bool userTarget, CUnit* unit);
 	void Update();
-	virtual bool AttackGround(float3 pos,bool userTarget);
+	bool AttackGround(float3 pos, bool userTarget);
 	float GetRange2D(float yDiff) const;
 
+	void SlowUpdate();
+	/// tells where to point the gun to hit the point at pos+diff
+	float3 GetWantedDir(const float3& diff);
+
 	/// unused?
 	float maxPredict;
 	/// unused?
@@ -36,12 +42,8 @@ public:
 	/// projectile gravity
 	float gravity;
 
-	void SlowUpdate(void);
-	/// tells where to point the gun to hit the point at pos+diff
-	float3 GetWantedDir(const float3& diff);
-
 private:
-	virtual void FireImpl();
+	void FireImpl();
 };
 
-#endif // __CANNON_H__
+#endif // _CANNON_H
