@@ -287,14 +287,6 @@ void CWeaponDefHandler::ParseWeapon(const LuaTable& wdTable, WeaponDef& wd)
 	wd.trajectoryHeight = wdTable.GetFloat("trajectoryHeight", 0.0f);
 
 	wd.noAutoTarget = (wd.manualfire || wd.interceptor || wd.isShield);
-
-	wd.onlyTargetCategory = 0xffffffff;
-	if (wdTable.GetBool("toAirWeapon", false)) {
-		// fix if we sometime call aircrafts otherwise
-		wd.onlyTargetCategory = CCategoryHandler::Instance()->GetCategories("VTOL");
-		//LOG("air only weapon %s %i", weaponname.c_str(), wd.onlyTargetCategory);
-	}
-
 	wd.largeBeamLaser = wdTable.GetBool("largeBeamLaser", false);
 
 	if (wd.type == "Cannon") {
