@@ -177,7 +177,7 @@ public:
 	PacketType SendMapErase(uchar myPlayerNum, short x, short z);
 	PacketType SendMapDrawLine(uchar myPlayerNum, short x1, short z1, short x2, short z2, bool);
 	PacketType SendMapDrawPoint(uchar myPlayerNum, short x, short z, const std::string& label, bool);
-	PacketType SendSyncResponse(int frameNum, uint checksum);
+	PacketType SendSyncResponse(uchar myPlayerNum, int frameNum, uint checksum);
 	PacketType SendSystemMessage(uchar myPlayerNum, std::string message);
 	PacketType SendStartPos(uchar myPlayerNum, uchar teamNum, uchar ready, float x, float y, float z);
 	PacketType SendPlayerInfo(uchar myPlayerNum, float cpuUsage, int ping);
@@ -187,7 +187,7 @@ public:
 
 	PacketType SendGiveAwayEverything(uchar myPlayerNum, uchar giveToTeam);
 	/**
-	 * Gives everything from one team to an other.
+	 * Gives everything from one team to another.
 	 * The player issuing this command has to be leader of the takeFromTeam.
 	 */
 	PacketType SendGiveAwayEverything(uchar myPlayerNum, uchar giveToTeam, uchar takeFromTeam);
