@@ -24,7 +24,7 @@ public:
 	 *
 	 * Re-instantiates if the configHandler already existed.
 	 */
-	static void Instantiate(std::string configSource = "");
+	static void Instantiate(const std::string configSource = "", const bool safemode = false);
 
 	/**
 	 * @brief Deallocate global configHandler
