@@ -14,6 +14,17 @@
 	typedef int _compile_time_assertion_failed__ ## message [(condition) ? 1 : -1]
 
 
+/**
+ * user_error
+ *   thrown when a enduser config is broken/invalid.
+ */
+class user_error : public std::runtime_error
+{
+public:
+	user_error(const std::string& msg) : std::runtime_error(msg) {};
+};
+
+
 /**
  * content_error
  *   thrown when content couldn't be found/loaded.
