@@ -1,8 +1,9 @@
 /* This file is part of the Spring engine (GPL v2 or later), see LICENSE.html */
 
-#include "StdAfx.h"
 #include "Demo.h"
 
+#include <cstring>
+
 CDemo::CDemo()
 {
 	demoName = "demos/unnamed.sdf";
