@@ -18,6 +18,11 @@ namespace {
 		static std::vector<log_sink_ptr> sinks;
 		return sinks;
 	}
+
+	std::vector<log_cleanup_ptr>& log_formatter_getCleanupFuncs() {
+		static std::vector<log_cleanup_ptr> cleanupFuncs;
+		return cleanupFuncs;
+	}
 }
 
 
@@ -37,6 +42,23 @@ void log_backend_unregisterSink(log_sink_ptr sink) {
 	}
 }
 
+
+void log_backend_registerCleanup(log_cleanup_ptr cleanupFunc) {
+	log_formatter_getCleanupFuncs().push_back(cleanupFunc);
+}
+
+void log_backend_unregisterCleanup(log_cleanup_ptr cleanupFunc) {
+
+	std::vector<log_cleanup_ptr>& cleanupFuncs = log_formatter_getCleanupFuncs();
+	std::vector<log_cleanup_ptr>::iterator si;
+	for (si = cleanupFuncs.begin(); si != cleanupFuncs.end(); ++si) {
+		if (*si == cleanupFunc) {
+			cleanupFuncs.erase(si);
+			break;
+		}
+	}
+}
+
 /**
  * @name logging_backend
  * ILog.h backend implementation.
@@ -71,6 +93,16 @@ void log_backend_record(const char* section, int level, const char* fmt,
 	}
 }
 
+/// Passes on a cleanup request to all sinks
+void log_backend_cleanup() {
+
+	const std::vector<log_cleanup_ptr>& cleanupFuncs = log_formatter_getCleanupFuncs();
+	std::vector<log_cleanup_ptr>::const_iterator si;
+	for (si = cleanupFuncs.begin(); si != cleanupFuncs.end(); ++si) {
+		(*si)();
+	}
+}
+
 ///@}
 
 #ifdef __cplusplus
