@@ -5,31 +5,40 @@
 #include <boost/format.hpp>
 
 #include "Exception.h"
+#include "ProtocolDef.h"
+#include "System/Log/ILog.h"
 
 namespace netcode {
 
 // static stuff
-unsigned CLocalConnection::Instances = 0;
+unsigned CLocalConnection::instances = 0;
 std::deque< boost::shared_ptr<const RawPacket> > CLocalConnection::Data[2];
 boost::mutex CLocalConnection::Mutex[2];
 
 CLocalConnection::CLocalConnection()
 {
-	if (Instances > 1)
-	{
+	if (instances > 1) {
 		throw network_error("Opening a third local connection is not allowed");
 	}
-	instance = Instances;
-	Instances++;
+	instance = instances;
+	instances++;
 }
 
 CLocalConnection::~CLocalConnection()
 {
-	Instances--;
+	instances--;
 }
 
 void CLocalConnection::SendData(boost::shared_ptr<const RawPacket> data)
 {
+	if (!ProtocolDef::GetInstance()->IsValidPacket(data->data, data->length)) {
+		// having this check here makes it easier to find networking bugs
+		// also when testing locally
+		LOG_L(L_ERROR, "Discarding invalid packet: ID %d, LEN %d",
+				(data->length > 0) ? (int)data->data[0] : -1, data->length);
+		return;
+	}
+
 	dataSent += data->length;
 	boost::mutex::scoped_lock scoped_lock(Mutex[OtherInstance()]);
 	Data[OtherInstance()].push_back(data);
@@ -48,19 +57,24 @@ boost::shared_ptr<const RawPacket> CLocalConnection::Peek(unsigned ahead) const
 	}
 }
 
+void CLocalConnection::DeleteBufferPacketAt(unsigned index)
+{
+	boost::mutex::scoped_lock scoped_lock(Mutex[instance]);
+
+	if (index < Data[instance].size())
+		Data[instance].erase(Data[instance].begin() + index);
+}
+
 boost::shared_ptr<const RawPacket> CLocalConnection::GetData()
 {
 	boost::mutex::scoped_lock scoped_lock(Mutex[instance]);
-	
-	if (!Data[instance].empty())
-	{
+
+	if (!Data[instance].empty()) {
 		boost::shared_ptr<const RawPacket> next = Data[instance].front();
 		Data[instance].pop_front();
 		dataRecv += next->length;
 		return next;
-	}
-	else
-	{
+	} else {
 		boost::shared_ptr<const RawPacket> empty;
 		return empty;
 	}
@@ -70,7 +84,7 @@ void CLocalConnection::Flush(const bool forced)
 {
 }
 
-bool CLocalConnection::CheckTimeout(int nsecs, bool initial) const
+bool CLocalConnection::CheckTimeout(int seconds, bool initial) const
 {
 	return false;
 }
@@ -93,6 +107,11 @@ std::string CLocalConnection::Statistics() const
 	return msg;
 }
 
+std::string CLocalConnection::GetFullAddress() const
+{
+	return "shared memory";
+}
+
 bool CLocalConnection::HasIncomingData() const
 {
 	boost::mutex::scoped_lock scoped_lock(Mutex[instance]);
@@ -101,10 +120,11 @@ bool CLocalConnection::HasIncomingData() const
 
 unsigned CLocalConnection::OtherInstance() const
 {
-	if (instance == 0)
+	if (instance == 0) {
 		return 1;
-	else
+	} else {
 		return 0;
+	}
 }
 
 } // namespace netcode
