@@ -1,37 +1,41 @@
 /* This file is part of the Spring engine (GPL v2 or later), see LICENSE.html */
 
-#include "StdAfx.h"
 #include <string.h>
 #include <stdexcept>
-#include "mmgr.h"
+#include "System/mmgr.h"
 
 #include "RawPacket.h"
 
+#include "System/Log/ILog.h"
+
 namespace netcode
 {
 
-RawPacket::RawPacket(const unsigned char* const tdata, const unsigned newLength) : length(newLength)
+RawPacket::RawPacket(const unsigned char* const tdata, const unsigned newLength)
+	: length(newLength)
 {
-	if (length > 0)
-	{
+	if (length > 0) {
 		data = new unsigned char[length];
 		memcpy(data, tdata, length);
-	}
-	else
-	{
+	} else {
+		LOG_L(L_ERROR, "Tried to pack a zero lengh packet");
+		// TODO handle error
 	}
 }
 
-RawPacket::RawPacket(const unsigned newLength) : length(newLength)
+RawPacket::RawPacket(const unsigned newLength)
+	: length(newLength)
 {
-	if (length > 0)
+	if (length > 0) {
 		data = new unsigned char[length];
+	}
 }
 
 RawPacket::~RawPacket()
 {
-	if (length > 0)
+	if (length > 0) {
 		delete[] data;
+	}
 }
 
 } // namespace netcode
