@@ -3,57 +3,68 @@
 #ifndef UNPACK_PACKET_H
 #define UNPACK_PACKET_H
 
+#include "RawPacket.h"
+
 #include <string>
 #include <vector>
 #include <cstring>
+#include <stdexcept>
 #include <boost/shared_ptr.hpp>
 
-#include "RawPacket.h"
-
 namespace netcode
 {
 
-class UnpackPacketException {
+class UnpackPacketException : public std::runtime_error {
 public:
-	UnpackPacketException(const char *msg) : err(msg) {}
-	std::string err;
+	UnpackPacketException(const std::string& what) : std::runtime_error(what) {}
 };
 
 class UnpackPacket
 {
 public:
 	UnpackPacket(boost::shared_ptr<const RawPacket>, size_t skipBytes = 0);
-	
+
 	template <typename T>
-	void operator>>(T& t) {
-		if(pos + sizeof(T) > pckt->length)
+	void operator>>(T& t)
+	{
+		if ((pos + sizeof(T)) > pckt->length) {
 			throw UnpackPacketException("Unpack failure (type)");
-		t = *(T*)(pckt->data+pos); pos += sizeof(T);
-	};
+		}
+		t = *(T*)(pckt->data + pos);
+		pos += sizeof(T);
+	}
+
 	template <typename element>
 	void operator>>(std::vector<element>& vec)
 	{
-		if(pckt->length - pos < vec.size() * sizeof(element))
+		if ((pckt->length - pos) < (vec.size() * sizeof(element))) {
 			throw UnpackPacketException("Unpack failure (vector)");
+		}
 		const size_t toCopy = vec.size() * sizeof(element);
-		std::memcpy((void*)(&vec[0]), (pckt->data+pos), toCopy);
+		std::memcpy((void*)(&vec[0]), pckt->data + pos, toCopy);
 		pos += toCopy;
-	};
-	void operator>>(std::string& text) {
+	}
+
+	void operator>>(std::string& text)
+	{
 		int i = pos;
-		for(; i < pckt->length; ++i)
-			if(pckt->data[i] == '\0')
+		for (; i < pckt->length; ++i) {
+			if (pckt->data[i] == '\0') {
 				break;
-		if(i >= pckt->length)
+			}
+		}
+		if (i >= pckt->length) {
 			throw UnpackPacketException("Unpack failure (string)");
-		text = std::string((char*)(pckt->data + pos)); pos += text.size()+1;
-	};
-	
+		}
+		text = std::string((char*)(pckt->data + pos));
+		pos += text.size() + 1;
+	}
+
 private:
 	boost::shared_ptr<const RawPacket> pckt;
 	size_t pos;
 };
 
-};
+} // namespace netcode
 
-#endif
+#endif // UNPACK_PACKET_H
