@@ -12,6 +12,7 @@
 # define m_resetGlobals()
 #endif
 
+
 CR_BIND(CObject, )
 
 CR_REG_METADATA(CObject, (
@@ -21,12 +22,22 @@ CR_REG_METADATA(CObject, (
 	CR_POSTLOAD(PostLoad)
 	));
 
+Threading::AtomicCounterInt64 CObject::cur_sync_id(0);
+
 //////////////////////////////////////////////////////////////////////
 // Construction/Destruction
 //////////////////////////////////////////////////////////////////////
 
 CObject::CObject() : detached(false)
 {
+	// Note1: this static var is shared between all different types of classes synced & unsynced (CUnit, CFeature, CProjectile, ...)
+	//  Still it doesn't break syncness even when synced objects have different sync_ids between clients as long as the sync_id is
+	//  creation time dependent and monotonously increasing, so the _order_ remains between clients.
+
+	// Use atomic fetch-and-add, so threads don't read half written data nor write old (= smaller) numbers
+	sync_id = ++cur_sync_id;
+
+	assert(sync_id + 1 > sync_id); // check for overflow
 }
 
 void CObject::Detach()
@@ -34,22 +45,31 @@ void CObject::Detach()
 	// SYNCED
 	assert(!detached);
 	detached = true;
-	for (std::map<DependenceType, std::list<CObject*> >::iterator i = listeners.begin(); i != listeners.end(); ++i) {
-		for (std::list<CObject*>::iterator di = i->second.begin(); di != i->second.end(); ++di) {
+	for (TDependenceMap::iterator i = listeners.begin(); i != listeners.end(); ++i) {
+		const DependenceType& depType = i->first;
+		TSyncSafeSet& objs = i->second;
+
+		for (TSyncSafeSet::iterator di = objs.begin(); di != objs.end(); ++di) {
+			CObject* const& obj = (*di);
+			
 			m_setOwner(__FILE__, __LINE__, __FUNCTION__);
-			(*di)->DependentDied(this);
+			obj->DependentDied(this);
+
 			m_setOwner(__FILE__, __LINE__, __FUNCTION__);
-			std::map<DependenceType, std::list<CObject*> >::iterator dio = (*di)->listening.find(i->first);
-			if (dio != (*di)->listening.end())
-				ListErase<CObject*>(dio->second, this);
+			assert(obj->listening.find(depType) != obj->listening.end());
+			obj->listening[depType].erase(this);
 		}
 	}
-	for (std::map<DependenceType, std::list<CObject*> >::iterator i = listening.begin(); i != listening.end(); ++i) {
-		for (std::list<CObject*>::iterator di = i->second.begin(); di != i->second.end(); ++di) {
+	for (TDependenceMap::iterator i = listening.begin(); i != listening.end(); ++i) {
+		const DependenceType& depType = i->first;
+		TSyncSafeSet& objs = i->second;
+
+		for (TSyncSafeSet::iterator di = objs.begin(); di != objs.end(); ++di) {
+			CObject* const& obj = (*di);
+
 			m_setOwner(__FILE__, __LINE__, __FUNCTION__);
-			std::map<DependenceType, std::list<CObject*> >::iterator dio = (*di)->listeners.find(i->first);
-			if (dio != (*di)->listeners.end())
-				ListErase<CObject*>(dio->second, this);
+			assert(obj->listeners.find(depType) != obj->listeners.end());
+			obj->listeners[depType].erase(this);
 		}
 	}
 	m_resetGlobals();
@@ -65,15 +85,17 @@ CObject::~CObject()
 
 void CObject::Serialize(creg::ISerializer* ser)
 {
-	if (ser->IsWriting()) {
+	//FIXME this was written when listeners & listening were std::list's, with switching to std::set it would need a rewrite
+	assert(false);
+	/*if (ser->IsWriting()) {
 		int num = listening.size();
 		ser->Serialize(&num, sizeof(int));
-		for (std::map<DependenceType, std::list<CObject*> >::iterator i = listening.begin(); i != listening.end(); ++i) {
+		for (std::map<DependenceType, TSyncSafeSet >::iterator i = listening.begin(); i != listening.end(); ++i) {
 			int dt = i->first;
 			ser->Serialize(&dt, sizeof(int));
-			std::list<CObject*>& dl = i->second;
+			TSyncSafeSet& dl = i->second;
 			int size = 0;
-			std::list<CObject*>::const_iterator oi;
+			TSyncSafeSet::const_iterator oi;
 			for (oi = dl.begin(); oi != dl.end(); ++oi) {
 				if ((*oi)->GetClass() != CObject::StaticClass()) {
 					size++;
@@ -84,8 +106,7 @@ void CObject::Serialize(creg::ISerializer* ser)
 				if ((*oi)->GetClass() != CObject::StaticClass()) {
 					ser->SerializeObjectPtr((void**)&*oi, (*oi)->GetClass());
 				} else {
-					LOG("Death dependance not serialized in %s",
-						GetClass()->name.c_str());
+					LOG("Death dependance not serialized in %s", GetClass()->name.c_str());
 				}
 			}
 		}
@@ -97,25 +118,26 @@ void CObject::Serialize(creg::ISerializer* ser)
 			ser->Serialize(&dt, sizeof(int));
 			int size;
 			ser->Serialize(&size, sizeof(int));
-			std::list<CObject*>& dl = listening[(DependenceType)dt];
+			TSyncSafeSet& dl = listening[(DependenceType)dt];
 			for (int o = 0; o < size; o++) {
-				std::list<CObject*>::iterator oi =
-					dl.insert(dl.end(), NULL);
+				TSyncSafeSet::iterator oi = dl.insert(NULL);
 				ser->SerializeObjectPtr((void**)&*oi, NULL);
 			}
 		}
-	}
+	}*/
 }
 
 void CObject::PostLoad()
 {
-	for (std::map<DependenceType, std::list<CObject*> >::iterator i = listening.begin(); i != listening.end(); ++i) {
-		for (std::list<CObject*>::iterator oi = i->second.begin(); oi != i->second.end(); ++oi) {
+	//FIXME this was written when listeners & listening were std::list's, with switching to std::set it would need a rewrite
+	assert(false);
+	/*for (std::map<DependenceType, TSyncSafeSet >::iterator i = listening.begin(); i != listening.end(); ++i) {
+		for (TSyncSafeSet::iterator oi = i->second.begin(); oi != i->second.end(); ++oi) {
 			m_setOwner(__FILE__, __LINE__, __FUNCTION__);
-			std::list<CObject*>& dl = (*oi)->listeners[i->first];
-			dl.insert(dl.end(), this);
+			TSyncSafeSet& dl = (*oi)->listeners[i->first];
+			dl.insert(this);
 		}
-	}
+	}*/
 	m_resetGlobals();
 }
 
@@ -130,40 +152,21 @@ void CObject::AddDeathDependence(CObject* obj, DependenceType dep)
 {
 	assert(!detached);
 	m_setOwner(__FILE__, __LINE__, __FUNCTION__);
-	if (!ListInsert<CObject *>(obj->listeners[dep], this)) {
-#ifndef NDEBUG
-		LOG_L(L_ERROR, "AddDeathDependence: Duplicated listener object for dependence type %d", (int)dep);
-		CrashHandler::OutputStacktrace();
-#endif
-	}
+	listening[dep].insert(obj);
 
 	m_setOwner(__FILE__, __LINE__, __FUNCTION__);
-	if (!ListInsert<CObject *>(listening[dep], obj)) {
-#ifndef NDEBUG
-		LOG_L(L_ERROR, "AddDeathDependence: Duplicated listening object for dependence type %d", (int)dep);
-		CrashHandler::OutputStacktrace();
-#endif
-	}
+	obj->listeners[dep].insert(this);
 	m_resetGlobals();
 }
 
+
 void CObject::DeleteDeathDependence(CObject* obj, DependenceType dep)
 {
 	assert(!detached);
 	m_setOwner(__FILE__, __LINE__, __FUNCTION__);
-	if (!ListErase<CObject *>(listening[dep], obj)) {
-#ifndef NDEBUG
-		LOG_L(L_ERROR, "DeleteDeathDependence: Non existent listening object for dependence type %d", (int)dep);
-		CrashHandler::OutputStacktrace();
-#endif
-	}
+	obj->listeners[dep].erase(this);
 
 	m_setOwner(__FILE__, __LINE__, __FUNCTION__);
-	if (!ListErase<CObject *>(obj->listeners[dep], this)) {
-#ifndef NDEBUG
-		LOG_L(L_ERROR, "DeleteDeathDependence: Non existent listener object for dependence type %d", (int)dep);
-		CrashHandler::OutputStacktrace();
-#endif
-	}
+	listening[dep].erase(obj);
 	m_resetGlobals();
 }
