@@ -3,14 +3,18 @@
 #ifndef _CRASH_HANDLER_H_
 #define _CRASH_HANDLER_H_
 
+#include <string.h>
+#include "Threading.h"
+
 namespace CrashHandler {
 	void Install();
 	void Remove();
-	void InstallHangHandler();
-	void UninstallHangHandler();
-	void ClearDrawWDT(bool disable = false);
-	void ClearSimWDT(bool disable = false);
-	void GameLoading(bool);
+
+	void Stacktrace(Threading::NativeThreadHandle thread, const std::string& threadName);
+	void PrepareStacktrace();
+	void CleanupStacktrace();
+
+	void OutputStacktrace();
 };
 
 #endif // _CRASH_HANDLER_H_
