@@ -34,11 +34,6 @@ static void SigAbrtHandler(int signal)
 	*((int*)(0)) = 0;
 }
 
-// Set this to the desired printf style output function.
-// Currently we write through the ILog.h frontend to infolog.txt
-#define PRINT(fmt, ...) \
-		LOG_L(L_ERROR, fmt, ##__VA_ARGS__)
-
 /** Convert exception code to human readable string. */
 static const char* ExceptionName(DWORD exceptionCode)
 {
@@ -91,13 +86,13 @@ static bool InitImageHlpDll()
 #if _MSC_VER >= 1500
 	static BOOL CALLBACK EnumModules(PCSTR moduleName, ULONG baseOfDll, PVOID userContext)
 	{
-		PRINT("0x%08lx\t%s", baseOfDll, moduleName);
+		LOG_L(L_ERROR, "0x%08lx\t%s", baseOfDll, moduleName);
 		return TRUE;
 	}
 #else // _MSC_VER >= 1500
 	static BOOL CALLBACK EnumModules(LPSTR moduleName, DWORD baseOfDll, PVOID userContext)
 	{
-		PRINT("0x%08lx\t%s", baseOfDll, moduleName);
+		LOG_L(L_ERROR, "0x%08lx\t%s", baseOfDll, moduleName);
 		return TRUE;
 	}
 #endif // _MSC_VER >= 1500
@@ -121,9 +116,9 @@ static void Stacktrace(const char *threadName, LPEXCEPTION_POINTERS e, HANDLE hT
 	process = GetCurrentProcess();
 
 	if(threadName)
-		PRINT("Stacktrace (%s):", threadName);
+		LOG_L(L_ERROR, "Stacktrace (%s):", threadName);
 	else
-		PRINT("Stacktrace:");
+		LOG_L(L_ERROR, "Stacktrace:");
 
 	bool suspended = false;
 	CONTEXT c;
@@ -145,7 +140,7 @@ static void Stacktrace(const char *threadName, LPEXCEPTION_POINTERS e, HANDLE hT
 			CloseHandle(allocThread);
 			if (allocIter < 10)
 				continue;
-			PRINT("Error: Stacktrace failed, allocator deadlock");
+			LOG_L(L_ERROR, "Stacktrace failed, allocator deadlock");
 			return;
 		}
 
@@ -155,7 +150,7 @@ static void Stacktrace(const char *threadName, LPEXCEPTION_POINTERS e, HANDLE hT
 
 		if (!GetThreadContext(hThread, &c)) {
 			ResumeThread(hThread);
-			PRINT("Error: Stacktrace failed, failed to get context");
+			LOG_L(L_ERROR, "Stacktrace failed, failed to get context");
 			return;
 		}
 		thread = hThread;
@@ -274,14 +269,14 @@ static void Stacktrace(const char *threadName, LPEXCEPTION_POINTERS e, HANDLE hT
 	}
 
 	if (containsOglDll) {
-		PRINT("This stack trace indicates a problem with your graphic card driver. "
+		LOG_L(L_ERROR, "This stack trace indicates a problem with your graphic card driver. "
 		      "Please try upgrading or downgrading it. "
 		      "Specifically recommended is the latest driver, and one that is as old as your graphic card. "
 		      "Make sure to use a driver removal utility, before installing other drivers.");
 	}
 
 	for (int i = 0; i < count; ++i) {
-		PRINT("%s", printstrings + i * BUFFER_SIZE);
+		LOG_L(L_ERROR, "%s", printstrings + i * BUFFER_SIZE);
 	}
 
 	GlobalFree(printstrings);
@@ -300,28 +295,28 @@ void PrepareStacktrace() {
 	InitImageHlpDll();
 
 	// Record list of loaded DLLs.
-	PRINT("DLL information:");
+	LOG_L(L_ERROR, "DLL information:");
 	SymEnumerateModules(GetCurrentProcess(), EnumModules, NULL);
 }
 
 void CleanupStacktrace() {
+	LOG_CLEANUP();
 	// Unintialize IMAGEHLP.DLL
 	SymCleanup(GetCurrentProcess());
 
 	LeaveCriticalSection( &stackLock );
-
 }
 
 void OutputStacktrace() {
-	PRINT("Error handler invoked for Spring %s.", SpringVersion::GetFull().c_str());
+	LOG_L(L_ERROR, "Error handler invoked for Spring %s.", SpringVersion::GetFull().c_str());
 #ifdef USE_GML
-	PRINT("MT with %d threads.", gmlThreadCount);
+	LOG_L(L_ERROR, "MT with %d threads.", GML::ThreadCount());
 #endif
 
 	PrepareStacktrace();
 
-	PRINT("Stacktrace:");
-	Stacktrace(NULL,NULL);
+	LOG_L(L_ERROR, "Stacktrace:");
+	Stacktrace(NULL, NULL);
 
 	CleanupStacktrace();
 }
@@ -331,9 +326,9 @@ LONG CALLBACK ExceptionHandler(LPEXCEPTION_POINTERS e)
 {
 	// Prologue.
 	logSinkHandler.SetSinking(false);
-	PRINT("Spring %s has crashed.", SpringVersion::GetFull().c_str());
+	LOG_L(L_ERROR, "Spring %s has crashed.", SpringVersion::GetFull().c_str());
 #ifdef USE_GML
-	PRINT("MT with %d threads.", gmlThreadCount);
+	LOG_L(L_ERROR, "MT with %d threads.", GML::ThreadCount());
 #endif
 
 	PrepareStacktrace();
@@ -341,8 +336,8 @@ LONG CALLBACK ExceptionHandler(LPEXCEPTION_POINTERS e)
 	const std::string error(ExceptionName(e->ExceptionRecord->ExceptionCode));
 
 	// Print exception info.
-	PRINT("Exception: %s (0x%08lx)", error.c_str(), e->ExceptionRecord->ExceptionCode);
-	PRINT("Exception Address: 0x%08lx", (unsigned long int) (PVOID) e->ExceptionRecord->ExceptionAddress);
+	LOG_L(L_ERROR, "Exception: %s (0x%08lx)", error.c_str(), e->ExceptionRecord->ExceptionCode);
+	LOG_L(L_ERROR, "Exception Address: 0x%08lx", (unsigned long int) (PVOID) e->ExceptionRecord->ExceptionAddress);
 
 	// Print stacktrace.
 	Stacktrace(NULL, e);
