@@ -22,16 +22,10 @@
 	#include "System/SpringApp.h"
 	#include "System/Platform/Threading.h"
 	#include "System/Platform/Watchdog.h"
-
-	#ifndef HEADLESS
-		#ifdef WIN32
-			#include <windows.h>
-		#else
-			// from X_MessageBox.cpp:
-			void X_MessageBox(const char* msg, const char* caption, unsigned int flags);
-		#endif
-	#endif // ifndef HEADLESS
-#endif // ifndef DEDICATED
+#endif
+#if !defined(DEDICATED) && !defined(HEADLESS)
+	#include "System/Platform/MessageBox.h"
+#endif
 
 
 static void ExitMessage(const std::string& msg, const std::string& caption, unsigned int flags, bool forced)
@@ -43,24 +37,10 @@ static void ExitMessage(const std::string& msg, const std::string& caption, unsi
 	LOG_L(L_ERROR, "%s %s", caption.c_str(), msg.c_str());
 	
 	if (!forced) {
-	#if defined(DEDICATED) || defined(HEADLESS)
+	#if !defined(DEDICATED) && !defined(HEADLESS)
+		Platform::MsgBox(msg, caption, flags);
+	#else
 		// no op
-
-	#elif defined(WIN32)
-		//! Windows implementation, using MessageBox.
-		// Translate spring flags to corresponding win32 dialog flags
-		unsigned int winFlags = MB_TOPMOST;
-		// MB_OK is default (0)
-		if (flags & MBF_EXCL)  winFlags |= MB_ICONEXCLAMATION;
-		if (flags & MBF_INFO)  winFlags |= MB_ICONINFORMATION;
-		if (flags & MBF_CRASH) winFlags |= MB_ICONERROR;
-		MessageBox(GetActiveWindow(), msg.c_str(), caption.c_str(), winFlags);
-
-	#else  // ifdef WIN32
-		//! X implementation
-		// TODO: write Mac OS X specific message box
-		X_MessageBox(msg.c_str(), caption.c_str(), flags);
-
 	#endif
 	}
 
@@ -91,11 +71,9 @@ void ErrorMessageBox(const std::string& msg, const std::string& caption, unsigne
 	ExitMessage(msg, caption, flags, false);
 
 #else
-//#ifdef USE_GML
 	//! SpringApp::Shutdown is extremely likely to deadlock or end up waiting indefinitely if any 
 	//! MT thread has crashed or deviated from its normal execution path by throwing an exception
 	boost::thread* forcedExitThread = new boost::thread(boost::bind(&ForcedExit, msg, caption, flags));
-//#endif
 
 	//! Non-MainThread. Inform main one and then interrupt it.
 	if (!Threading::IsMainThread()) {
@@ -113,11 +91,9 @@ void ErrorMessageBox(const std::string& msg, const std::string& caption, unsigne
 	//! (else they would still run while the error messagebox is shown)
 	SpringApp::Shutdown();
 
-//#ifdef USE_GML
 	shutdownSucceeded = true;
 	forcedExitThread->join();
 	delete forcedExitThread;
-//#endif
 
 	ExitMessage(msg, caption, flags, false);
 #endif // defined(DEDICATED)
