@@ -3,7 +3,8 @@
 #include "NullSound.h"
 
 #include "SoundLog.h"
-#include "System/LogOutput.h"
+#include "System/float3.h"
+
 
 NullSound::NullSound() {
 }
@@ -11,7 +12,7 @@ NullSound::NullSound() {
 NullSound::~NullSound() {
 }
 
-bool NullSound::HasSoundItem(const std::string& name) {
+bool NullSound::HasSoundItem(const std::string& name) const {
 	return false;
 }
 
@@ -19,7 +20,7 @@ size_t NullSound::GetSoundId(const std::string& name, bool hardFail) {
 	return 0;
 }
 
-SoundSource* NullSound::GetNextBestSource(bool lock) {
+CSoundSource* NullSound::GetNextBestSource(bool lock) {
 	return NULL;
 }
 
@@ -40,14 +41,11 @@ bool NullSound::IsMuted() const {
 void NullSound::Iconified(bool state) {
 }
 
-void NullSound::PlaySample(size_t id, const float3& p, const float3& velocity, float volume, bool relative) {
-}
-
 void NullSound::UpdateListener(const float3& campos, const float3& camdir, const float3& camup, float lastFrameTime) {
 }
 
 void NullSound::PrintDebugInfo() {
-	LogObject(LOG_SOUND) << "Null Sound System";
+	LOG("Null Sound System");
 }
 
 bool NullSound::LoadSoundDefs(const std::string& fileName) {
@@ -56,3 +54,7 @@ bool NullSound::LoadSoundDefs(const std::string& fileName) {
 
 void NullSound::NewFrame() {
 }
+
+const float3& NullSound::GetListenerPos() const {
+	return ZeroVector;
+}
