@@ -2,16 +2,17 @@
 
 #include "SoundBuffer.h"
 
-#include <ogg/ogg.h>
-#include <vorbis/vorbisfile.h>
 
 #include "SoundLog.h"
 #include "ALShared.h"
 #include "VorbisShared.h"
-#include "System/LogOutput.h"
 #include "System/Platform/errorhandler.h"
 #include "System/Platform/byteorder.h"
 
+#include <vorbis/vorbisfile.h>
+#include <ogg/ogg.h>
+#include <cstring>
+
 namespace
 {
 struct VorbisInputBuffer
@@ -39,7 +40,7 @@ int	VorbisClose(void* datasource)
 SoundBuffer::bufferMapT SoundBuffer::bufferMap; // filename, index into Buffers
 SoundBuffer::bufferVecT SoundBuffer::buffers;
 
-SoundBuffer::SoundBuffer() : id(0)
+SoundBuffer::SoundBuffer() : id(0), channels(0)
 {
 }
 
@@ -70,15 +71,15 @@ bool SoundBuffer::LoadWAV(const std::string& file, std::vector<boost::uint8_t> b
 {
 	WAVHeader* header = (WAVHeader*)(&buffer[0]);
 
-	if (memcmp(header->riff, "RIFF", 4) || memcmp(header->wavefmt, "WAVEfmt", 7)) {
+	if ((buffer.empty()) || memcmp(header->riff, "RIFF", 4) || memcmp(header->wavefmt, "WAVEfmt", 7)) {
 		if (strict) {
 			ErrorMessageBox("ReadWAV: invalid header.", file, 0);
 		}
 		return false;
 	}
 
-#define hswabword(c) header->c = swabword(header->c)
-#define hswabdword(c) header->c = swabdword(header->c)
+#define hswabword(c) swabWordInPlace(header->c)
+#define hswabdword(c) swabDWordInPlace(header->c)
 	hswabword(format_tag);
 	hswabword(channels);
 	hswabword(BlockAlign);
@@ -128,24 +129,32 @@ bool SoundBuffer::LoadWAV(const std::string& file, std::vector<boost::uint8_t> b
 	}
 
 	if (static_cast<unsigned>(header->datalen) > buffer.size() - sizeof(WAVHeader)) {
-		LogObject(LOG_SOUND) << "WAV file " << file << " has data length " << header->datalen << " greater than actual data length " << buffer.size() - sizeof(WAVHeader);
+		LOG_L(L_WARNING,
+				"WAV file %s has data length %i greater than actual data length %i",
+				file.c_str(), header->datalen,
+				(int)(buffer.size() - sizeof(WAVHeader)));
 
-//		logOutput.Print("OpenAL: size %d\n", size);
-//		logOutput.Print("OpenAL: sizeof(WAVHeader) %d\n", sizeof(WAVHeader));
-//		logOutput.Print("OpenAL: format_tag %d\n", header->format_tag);
-//		logOutput.Print("OpenAL: channels %d\n", header->channels);
-//		logOutput.Print("OpenAL: BlockAlign %d\n", header->BlockAlign);
-//		logOutput.Print("OpenAL: BitsPerSample %d\n", header->BitsPerSample);
-//		logOutput.Print("OpenAL: totalLength %d\n", header->totalLength);
-//		logOutput.Print("OpenAL: length %d\n", header->length);
-//		logOutput.Print("OpenAL: SamplesPerSec %d\n", header->SamplesPerSec);
-//		logOutput.Print("OpenAL: AvgBytesPerSec %d\n", header->AvgBytesPerSec);
+//		LOG_L(L_WARNING, "OpenAL: size %d\n", size);
+//		LOG_L(L_WARNING, "OpenAL: sizeof(WAVHeader) %d\n", sizeof(WAVHeader));
+//		LOG_L(L_WARNING, "OpenAL: format_tag %d\n", header->format_tag);
+//		LOG_L(L_WARNING, "OpenAL: channels %d\n", header->channels);
+//		LOG_L(L_WARNING, "OpenAL: BlockAlign %d\n", header->BlockAlign);
+//		LOG_L(L_WARNING, "OpenAL: BitsPerSample %d\n", header->BitsPerSample);
+//		LOG_L(L_WARNING, "OpenAL: totalLength %d\n", header->totalLength);
+//		LOG_L(L_WARNING, "OpenAL: length %d\n", header->length);
+//		LOG_L(L_WARNING, "OpenAL: SamplesPerSec %d\n", header->SamplesPerSec);
+//		LOG_L(L_WARNING, "OpenAL: AvgBytesPerSec %d\n", header->AvgBytesPerSec);
 
 		header->datalen = boost::uint32_t(buffer.size() - sizeof(WAVHeader))&(~boost::uint32_t((header->BitsPerSample*header->channels)/8 -1));
 	}
 
-	if (!AlGenBuffer(file, format, &buffer[sizeof(WAVHeader)], header->datalen, header->SamplesPerSec))
-		LogObject(LOG_SOUND) << "Loading audio failed for " << file;
+	if (!AlGenBuffer(file, format, &buffer[sizeof(WAVHeader)], header->datalen, header->SamplesPerSec)) {
+		LOG_L(L_WARNING, "Loading audio failed for %s", file.c_str());
+	}
+
+	filename = file;
+	channels = header->channels;
+
 	return true;
 }
 
@@ -163,10 +172,10 @@ bool SoundBuffer::LoadVorbis(const std::string& file, std::vector<boost::uint8_t
 	vorbisCallbacks.tell_func  = NULL;
 
 	OggVorbis_File oggStream;
-	int result = 0;
-	if ((result = ov_open_callbacks(&buf, &oggStream, NULL, 0, vorbisCallbacks)) < 0)
-	{
-		logOutput.Print("Could not open Ogg stream (reason: %s).", ErrorString(result).c_str());
+	const int result = ov_open_callbacks(&buf, &oggStream, NULL, 0, vorbisCallbacks);
+	if (result < 0) {
+		LOG_L(L_WARNING, "Could not open Ogg stream (reason: %s).",
+				ErrorString(result).c_str());
 		return false;
 	}
 	
@@ -184,10 +193,12 @@ bool SoundBuffer::LoadVorbis(const std::string& file, std::vector<boost::uint8_t
 	}
 	else
 	{
-		if (strict)
+		if (strict) {
 			ErrorMessageBox("SoundBuffer::LoadVorbis (%s): invalid number of channels.", file, 0);
-		else
-			LogObject(LOG_SOUND) << "File  " << file << ": invalid number of channels: " << vorbisInfo->channels;
+		} else {
+			LOG_L(L_WARNING, "File %s: invalid number of channels: %i",
+					file.c_str(), vorbisInfo->channels);
+		}
 		return false;
 	}
 
@@ -203,13 +214,15 @@ bool SoundBuffer::LoadVorbis(const std::string& file, std::vector<boost::uint8_t
 		switch(read)
 		{
 			case OV_HOLE:
-				LogObject(LOG_SOUND) << file << ": garbage or corrupt page in stream (non-fatal)";
+				LOG_L(L_WARNING,
+						"%s: garbage or corrupt page in stream (non-fatal)",
+						file.c_str());
 				continue; // read next
 			case OV_EBADLINK:
-				LogObject(LOG_SOUND) << file << ": corrupted stream";
+				LOG_L(L_WARNING, "%s: corrupted stream", file.c_str());
 				return false; // abort
 			case OV_EINVAL:
-				LogObject(LOG_SOUND) << file << ": corrupted headers";
+				LOG_L(L_WARNING, "%s: corrupted headers", file.c_str());
 				return false; // abort
 			default:
 				break; // all good
@@ -218,6 +231,8 @@ bool SoundBuffer::LoadVorbis(const std::string& file, std::vector<boost::uint8_t
 	} while (read > 0); // read == 0 indicated EOF, read < 0 is error
 
 	AlGenBuffer(file, format, &decodeBuffer[0], pos, vorbisInfo->rate);
+	filename = file;
+	channels = vorbisInfo->channels;
 	return true;
 }
 
@@ -277,7 +292,6 @@ size_t SoundBuffer::Insert(boost::shared_ptr<SoundBuffer> buffer)
 bool SoundBuffer::AlGenBuffer(const std::string& file, ALenum format, const boost::uint8_t* data, size_t datalength, int rate)
 {
 	alGenBuffers(1, &id);
-	filename = file;
 	alBufferData(id, format, (ALvoid*) data, datalength, rate);
 	return CheckError("SoundBuffer::AlGenBuffer");
 }
