@@ -284,15 +284,13 @@ public:
 	/**
 	 * @brief operator ==
 	 * @param f float3 to test
-	 * @return whether float3s are equal
+	 * @return whether float3s are equal under default CMP_EPS tolerance in x/y/z
 	 *
 	 * Tests if this float3 is equal to another, by
 	 * checking each x/y/z component individually.
 	 */
 	bool operator== (const float3& f) const {
-		return math::fabs(x - f.x) <= math::fabs(float3::CMP_EPS * x)
-			&& math::fabs(y - f.y) <= math::fabs(float3::CMP_EPS * y)
-			&& math::fabs(z - f.z) <= math::fabs(float3::CMP_EPS * z);
+		return (equals(f));
 	}
 
 	/**
@@ -304,7 +302,7 @@ public:
 	 * checking each x/y/z component individually.
 	 */
 	bool operator!= (const float3& f) const {
-		return !(*this == f);
+		return (!equals(f));
 	}
 
 	/**
@@ -320,7 +318,7 @@ public:
 	}
 
 	/**
-	 * @brief operator [] const
+	 * @brief operator[] const
 	 * @param t index in xyz array
 	 * @return const float component at index
 	 *
@@ -331,6 +329,15 @@ public:
 		return (&x)[t];
 	}
 
+	/**
+	 * @see operator==
+	 */
+	bool equals(const float3& f, const float3& eps = float3(float3::CMP_EPS, float3::CMP_EPS, float3::CMP_EPS)) const {
+		return math::fabs(x - f.x) <= math::fabs(eps.x * x)
+			&& math::fabs(y - f.y) <= math::fabs(eps.y * y)
+			&& math::fabs(z - f.z) <= math::fabs(eps.z * z);
+	}
+
 	/**
 	 * @brief dot product
 	 * @param f float3 to use
@@ -570,14 +577,31 @@ public:
 		return (float)(dx*dx + dz*dz);
 	}
 
-	/// Check if this vector is in bounds without clamping x and z
-	bool IsInBounds() const;
-	/// Check if this vector is in bounds and clamp x and z if not
-	bool CheckInBounds();
 
-	SyncedFloat x; ///< x component
-	SyncedFloat y; ///< y component
-	SyncedFloat z; ///< z component
+	/**
+	 * @brief Check against FaceHeightmap bounds
+	 *
+	 * Check if this vector is in bounds [0 .. gs->mapxy-1]
+	 * @note THIS IS THE WRONG SPACE! _ALL_ WORLD SPACE POSITIONS SHOULD BE IN VertexHeightmap RESOLUTION!
+	 */
+	bool IsInBounds() const;
+
+	/**
+	 * @brief Clamps to FaceHeightmap
+	 *
+	 * Clamps to the `face heightmap` resolution [0 .. gs->mapxy-1]
+	 * @note THIS IS THE WRONG SPACE! _ALL_ WORLD SPACE POSITIONS SHOULD BE IN VertexHeightmap RESOLUTION!
+	 */
+	void ClampInBounds();
+
+	/**
+	 * @brief Clamps to VertexHeightmap
+	 *
+	 * Clamps to the `vertex heightmap`/`opengl space` resolution [0 .. gs->mapxy]
+	 * @note USE THIS!
+	 */
+	void ClampInMap();
+	float3 cClampInMap() const { SyncedFloat3 f = *this; f.ClampInMap(); return f; }
 
 	/**
 	 * @brief cast operator
@@ -585,6 +609,11 @@ public:
 	 * @return a float3 with the same x/y/z components as this float3
 	 */
 	operator float3() const { return float3(x, y, z); }
+
+public:
+	SyncedFloat x; ///< x component
+	SyncedFloat y; ///< y component
+	SyncedFloat z; ///< z component
 };
 
 #else // SYNCDEBUG || SYNCCHECK
