@@ -10,7 +10,7 @@
 #include <boost/shared_ptr.hpp>
 
 #include "ISerializer.h"
-#include "Sync/SyncedPrimitive.h"
+#include "System/Sync/SyncedPrimitive.h"
 
 namespace creg {
 
@@ -45,20 +45,20 @@ namespace creg {
 		// Type interface can go here...
 		virtual ~IType();
 
-		virtual void Serialize (ISerializer* s, void *instance) = 0;
-		virtual std::string GetName () = 0;
+		virtual void Serialize(ISerializer* s, void* instance) = 0;
+		virtual std::string GetName() = 0;
 
-		static boost::shared_ptr<IType> CreateBasicType (BasicTypeID t);
-		static boost::shared_ptr<IType> CreateStringType ();
-		static boost::shared_ptr<IType> CreateObjInstanceType (Class *objectType);
-		static boost::shared_ptr<IType> CreateEnumeratedType (size_t size);
+		static boost::shared_ptr<IType> CreateBasicType(BasicTypeID t);
+		static boost::shared_ptr<IType> CreateStringType();
+		static boost::shared_ptr<IType> CreateObjInstanceType(Class* objectType);
+		static boost::shared_ptr<IType> CreateEnumeratedType(size_t size);
 	};
 
 	class IMemberRegistrator
 	{
 	public:
 		virtual ~IMemberRegistrator();
-		virtual void RegisterMembers (Class *cls) = 0;
+		virtual void RegisterMembers(Class* cls) = 0;
 	};
 
 	enum ClassFlags {
@@ -81,16 +81,23 @@ namespace creg {
 	class ClassBinder
 	{
 	public:
-		ClassBinder (const char *className, unsigned int cf, ClassBinder* base, IMemberRegistrator **mreg, int instanceSize, void (*constructorProc)(void *instance), void (*destructorProc)(void *instance));
+		ClassBinder(const char* className, unsigned int cf, ClassBinder* base,
+				IMemberRegistrator** mreg, int instanceSize,
+				void (*constructorProc)(void* instance),
+				void (*destructorProc)(void* instance));
 
-		Class *class_;
-		ClassBinder *base;
+		Class* class_;
+		ClassBinder* base;
 		ClassFlags flags;
-		IMemberRegistrator **memberRegistrator;
-		const char *name;
+		IMemberRegistrator** memberRegistrator;
+		const char* name;
 		int size; // size of an instance in bytes
-		void (*constructor)(void *instance);
-		void (*destructor)(void *instance); // needed for classes without virtual destructor (classes/structs declared with CR_DECLARE_STRUCT)
+		void (*constructor)(void* instance);
+		/**
+		 * Needed for classes without virtual destructor.
+		 * (classes/structs declared with CR_DECLARE_STRUCT)
+		 */
+		void (*destructor)(void* instance);
 
 		ClassBinder* nextBinder;
 	};
@@ -100,21 +107,27 @@ namespace creg {
 	public:
 		/// Return the global list of classes
 		static std::vector<Class*> GetClasses() { return classes; }
-		/// Initialization of creg, collects all the classes and initializes metadata
-		static void InitializeClasses ();
+		/**
+		 * Initialization of creg, collects all the classes and initializes
+		 * metadata.
+		 */
+		static void InitializeClasses();
 		/// Shutdown of creg
-		static void FreeClasses ();
+		static void FreeClasses();
 		/// Find a class by name
 		static Class* GetClass(const std::string& name);
 
 		static void AddClassBinder(ClassBinder* cb);
 
 	protected:
-		static ClassBinder *binderList;
+		static ClassBinder* binderList;
 		static std::vector<Class*> classes;
 	};
 
-	/** Represents a C++ class or struct, declared with CR_DECLARE/CR_DECLARE_STRUCT */
+	/**
+	 * Represents a C++ class or struct, declared with
+	 * CR_DECLARE or CR_DECLARE_STRUCT.
+	 */
 	class Class
 	{
 	public:
@@ -126,35 +139,37 @@ namespace creg {
 			int flags; // combination of ClassMemberFlag's
 		};
 
-		Class ();
-		~Class ();
+		Class();
+		~Class();
 
 		/// Returns true if this class is equal to or derived from other
-		bool IsSubclassOf (Class* other);
-		void DeleteInstance (void *inst);
+		bool IsSubclassOf(Class* other);
+		void DeleteInstance(void* inst);
 		/// Allocate an instance of the class
-		void* CreateInstance ();
+		void* CreateInstance();
 		/// Calculate a checksum from the class metadata
-		void CalculateChecksum (unsigned int& checksum);
-		void AddMember (const char *name, boost::shared_ptr<IType> type, unsigned int offset);
-		void AddMember (const char *name, IType* type, unsigned int offset);
-		void SetMemberFlag (const char *name, ClassMemberFlag f);
-		Member* FindMember (const char *name);
+		void CalculateChecksum(unsigned int& checksum);
+		void AddMember(const char* name, boost::shared_ptr<IType> type, unsigned int offset);
+		void AddMember(const char* name, IType* type, unsigned int offset);
+		void SetMemberFlag(const char* name, ClassMemberFlag f);
+		Member* FindMember(const char* name);
 
-		void BeginFlag (ClassMemberFlag flag);
-		void EndFlag (ClassMemberFlag flag);
+		void BeginFlag(ClassMemberFlag flag);
+		void EndFlag(ClassMemberFlag flag);
 
 		void SetFlag(ClassFlags flag);
 
-		bool IsAbstract() { return (binder->flags & CF_Abstract) != 0; }
+		bool IsAbstract() const { return (binder->flags & CF_Abstract) != 0; }
 
-		std::vector<Class*> GetImplementations(); // get all concrete classes that implement this class
+		/// Returns all concrete classes that implement this class
+		std::vector<Class*> GetImplementations();
 
 		std::vector <Member*> members;
-		std::vector <Class*> derivedClasses; // all classes that derive from this class
+		/// all classes that derive from this class
+		std::vector <Class*> derivedClasses;
 		ClassBinder* binder;
 		std::string name;
-		Class *base;
+		Class* base;
 		void (_DummyStruct::*serializeProc)(ISerializer& s);
 		void (_DummyStruct::*postLoadProc)();
 
@@ -175,22 +190,25 @@ namespace creg {
 
 		boost::shared_ptr<IType> elemType;
 
-		DynamicArrayType (boost::shared_ptr<IType> elemType) : elemType(elemType) {}
-		~DynamicArrayType () {}
+		DynamicArrayType(boost::shared_ptr<IType> et)
+			: elemType(et) {}
+		~DynamicArrayType() {}
 
-		void Serialize (ISerializer *s, void *inst) {
+		void Serialize(ISerializer* s, void* inst) {
 			T& ct = *(T*)inst;
-			if (s->IsWriting ()) {
+			if (s->IsWriting()) {
 				int size = (int)ct.size();
-				s->SerializeInt (&size,sizeof(int));
-				for (int a=0;a<size;a++)
-					elemType->Serialize (s, &ct[a]);
+				s->SerializeInt(&size,sizeof(int));
+				for (int a = 0; a < size; a++) {
+					elemType->Serialize(s, &ct[a]);
+				}
 			} else {
 				int size;
-				s->SerializeInt (&size, sizeof(int));
-				ct.resize (size);
-				for (int a=0;a<size;a++)
-					elemType->Serialize (s, &ct[a]);
+				s->SerializeInt(&size, sizeof(int));
+				ct.resize(size);
+				for (int a = 0; a < size; a++) {
+					elemType->Serialize(s, &ct[a]);
+				}
 			}
 		}
 		std::string GetName() { return elemType->GetName() + "[]"; }
@@ -202,8 +220,8 @@ namespace creg {
 		boost::shared_ptr<IType> elemType;
 		int size, elemSize;
 
-		StaticArrayBaseType(boost::shared_ptr<IType> et, int Size, int ElemSize) :
-			elemType(et), size(Size), elemSize(ElemSize) {}
+		StaticArrayBaseType(boost::shared_ptr<IType> et, int Size, int ElemSize)
+			: elemType(et), size(Size), elemSize(ElemSize) {}
 		~StaticArrayBaseType() {}
 
 		std::string GetName();
@@ -214,12 +232,13 @@ namespace creg {
 	{
 	public:
 		typedef T ArrayType[Size];
-		StaticArrayType(boost::shared_ptr<IType> elemType) : StaticArrayBaseType(elemType, Size, sizeof(ArrayType)/Size) {}
-		void Serialize (ISerializer *s, void *instance)
+		StaticArrayType(boost::shared_ptr<IType> et)
+			: StaticArrayBaseType(et, Size, sizeof(ArrayType)/Size) {}
+		void Serialize(ISerializer* s, void* instance)
 		{
 			T* array = (T*)instance;
-			for (int a=0;a<Size;a++)
-				elemType->Serialize (s, &array[a]);
+			for (int a = 0; a < Size; a++)
+				elemType->Serialize(s, &array[a]);
 		}
 	};
 
@@ -230,14 +249,14 @@ namespace creg {
 		EmptyType(int Size) {size=Size;}
 		~EmptyType() {}
 
-		void Serialize (ISerializer* s, void *instance)
+		void Serialize(ISerializer* s, void* instance)
 		{
 			for (int a=0;a<size;a++) {
 				char c=0;
 				s->Serialize(&c,1);
 			}
 		}
-		std::string GetName ()
+		std::string GetName()
 		{
 			return "void";
 		}
@@ -247,35 +266,38 @@ namespace creg {
 
 /** @def CR_DECLARE
  * Add the definitions for creg binding to the class
- * this should be put within the class definition */
+ * this should be put within the class definition
+ */
 #define CR_DECLARE(TCls)	public:					\
 	static creg::ClassBinder binder;				\
-	static creg::IMemberRegistrator *memberRegistrator;	 \
+	static creg::IMemberRegistrator* memberRegistrator;	 \
 	static void _ConstructInstance(void* d);			\
 	static void _DestructInstance(void* d);			\
 	typedef TCls MyType;							\
 	friend struct TCls##MemberRegistrator;			\
 	virtual creg::Class* GetClass();				\
-	inline static creg::Class *StaticClass() { return binder.class_; }
+	inline static creg::Class* StaticClass() { return binder.class_; }
 
 /** @def CR_DECLARE_STRUCT
  * Use this to declare a structure
  * this should be put in the class definition, instead of CR_DECLARE
- * For creg, the only difference between a class and a structure is having a vtable or not
+ * For creg, the only difference between a class and a structure is having a
+ * vtable or not.
  */
 #define CR_DECLARE_STRUCT(TStr)		public:			\
 	static creg::ClassBinder binder;				\
 	typedef TStr MyType;							\
-	static creg::IMemberRegistrator *memberRegistrator;	\
+	static creg::IMemberRegistrator* memberRegistrator;	\
 	static void _ConstructInstance(void* d);			\
 	static void _DestructInstance(void* d);			\
 	friend struct TStr##MemberRegistrator;			\
 	creg::Class* GetClass();						\
-	inline static creg::Class *StaticClass() { return binder.class_; }
+	inline static creg::Class* StaticClass() { return binder.class_; }
 
 /** @def CR_DECLARE_SUB
  * Use this to declare a sub class. This should be put in the class definition
- * of the superclass, alongside CR_DECLARE(CSuperClass) (or CR_DECLARE_STRUCT). */
+ * of the superclass, alongside CR_DECLARE(CSuperClass) (or CR_DECLARE_STRUCT).
+ */
 #define CR_DECLARE_SUB(cl) \
 	struct cl##MemberRegistrator;
 
@@ -284,12 +306,13 @@ namespace creg {
  * Should be used in the source file
  * @param TCls class to bind
  * @param TBase base class of TCls
+ * @param ctor_args constructor arguments
  */
 #define CR_BIND_DERIVED(TCls, TBase, ctor_args) \
 	creg::IMemberRegistrator* TCls::memberRegistrator=0;	\
 	creg::Class* TCls::GetClass() { return binder.class_; } \
-	void TCls::_ConstructInstance(void *d) { new(d) MyType ctor_args; } \
-	void TCls::_DestructInstance(void *d) { ((MyType*)d)->~MyType(); } \
+	void TCls::_ConstructInstance(void* d) { new(d) MyType ctor_args; } \
+	void TCls::_DestructInstance(void* d) { ((MyType*)d)->~MyType(); } \
 	creg::ClassBinder TCls::binder(#TCls, 0, &TBase::binder, &TCls::memberRegistrator, sizeof(TCls), TCls::_ConstructInstance, TCls::_DestructInstance);
 
 /** @def CR_BIND_DERIVED_SUB
@@ -298,31 +321,33 @@ namespace creg {
  * @param TSuper class that contains the class to register
  * @param TCls subclass to bind
  * @param TBase base class of TCls
+ * @param ctor_args constructor arguments
  */
 #define CR_BIND_DERIVED_SUB(TSuper, TCls, TBase, ctor_args) \
 	creg::IMemberRegistrator* TSuper::TCls::memberRegistrator=0;	 \
 	creg::Class* TSuper::TCls::GetClass() { return binder.class_; }  \
-	void TSuper::TCls::_ConstructInstance(void *d) { new(d) TCls ctor_args; }  \
-	void TSuper::TCls::_DestructInstance(void *d) { ((TCls*)d)->~TCls(); }  \
+	void TSuper::TCls::_ConstructInstance(void* d) { new(d) TCls ctor_args; }  \
+	void TSuper::TCls::_DestructInstance(void* d) { ((TCls*)d)->~TCls(); }  \
 	creg::ClassBinder TSuper::TCls::binder(#TSuper "::" #TCls, 0, &TBase::binder, &TSuper::TCls::memberRegistrator, sizeof(TSuper::TCls), TSuper::TCls::_ConstructInstance, TSuper::TCls::_DestructInstance);
 
 /** @def CR_BIND
  * Bind a class not derived from CObject
  * should be used in the source file
  * @param TCls class to bind
+ * @param ctor_args constructor arguments
  */
 #define CR_BIND(TCls, ctor_args) \
 	creg::IMemberRegistrator* TCls::memberRegistrator=0;	\
 	creg::Class* TCls::GetClass() { return binder.class_; } \
-	void TCls::_ConstructInstance(void *d) { new(d) MyType ctor_args; } \
-	void TCls::_DestructInstance(void *d) { ((MyType*)d)->~MyType(); } \
+	void TCls::_ConstructInstance(void* d) { new(d) MyType ctor_args; } \
+	void TCls::_DestructInstance(void* d) { ((MyType*)d)->~MyType(); } \
 	creg::ClassBinder TCls::binder(#TCls, 0, 0, &TCls::memberRegistrator, sizeof(TCls), TCls::_ConstructInstance, TCls::_DestructInstance);
 // Stupid GCC likes this template<> crap very much
 #define CR_BIND_TEMPLATE(TCls, ctor_args) \
 	template<> creg::IMemberRegistrator* TCls::memberRegistrator=0;	\
 	template<> creg::Class* TCls::GetClass() { return binder.class_; } \
-	template<> void TCls::_ConstructInstance(void *d) { new(d) MyType ctor_args; } \
-	template<> void TCls::_DestructInstance(void *d) { ((MyType*)d)->~MyType(); } \
+	template<> void TCls::_ConstructInstance(void* d) { new(d) MyType ctor_args; } \
+	template<> void TCls::_DestructInstance(void* d) { ((MyType*)d)->~MyType(); } \
 	template<> creg::ClassBinder TCls::binder(#TCls, 0, 0, &TCls::memberRegistrator, sizeof(TCls), TCls::_ConstructInstance, TCls::_DestructInstance);
 
 /** @def CR_BIND_DERIVED_INTERFACE
@@ -339,8 +364,10 @@ namespace creg {
 /** @def CR_BIND_INTERFACE
  * Bind an abstract class
  * should be used in the source file
- * This simply doesn't register a constructor to creg, so you can bind non-abstract class as abstract classes as well.
- * @param TCls abstract class to bind */
+ * This simply does not register a constructor to creg, so you can bind
+ * non-abstract class as abstract classes as well.
+ * @param TCls abstract class to bind
+ */
 #define CR_BIND_INTERFACE(TCls)	\
 	creg::IMemberRegistrator* TCls::memberRegistrator=0;	\
 	creg::Class* TCls::GetClass() { return binder.class_; } \
@@ -390,7 +417,8 @@ namespace creg {
  * Registers a class/struct member variable, of a type that is:
  * - a struct registered with CR_DECLARE_STRUCT/CR_BIND_STRUCT
  * - a class registered with CR_DECLARE/CR_BIND*
- * - an int,short,char,long,double,float or bool, or any of the unsigned variants of those
+ * - an int,short,char,long,double,float or bool, or any of the unsigned
+ *   variants of those
  * - a std::set/multiset included with STL_Set.h
  * - a std::list included with STL_List.h
  * - a std::deque included with STL_Deque.h
@@ -402,12 +430,13 @@ namespace creg {
  * For enumerated type members, @see CR_ENUM_MEMBER
  */
 #define CR_MEMBER(Member) \
-	class_->AddMember ( #Member, creg::GetType (null->Member), (unsigned int)(((char*)&null->Member)-((char*)0)))
+	class_->AddMember ( #Member, creg::GetType(null->Member), (unsigned int)(((char*)&null->Member)-((char*)0)))
 
 /** @def CR_ENUM_MEMBER
- * Registers a class/struct member variable with an enumerated type */
+ * Registers a class/struct member variable with an enumerated type
+ */
 #define CR_ENUM_MEMBER(Member) \
-	class_->AddMember ( #Member, creg::IType::CreateEnumeratedType(sizeof(null->Member)), (unsigned int)(((char*)&null->Member)-((char*)0)))
+	class_->AddMember( #Member, creg::IType::CreateEnumeratedType(sizeof(null->Member)), (unsigned int)(((char*)&null->Member)-((char*)0)))
 
 /** @def CR_RESERVED
  *  @author Victor Muraviev
@@ -433,23 +462,24 @@ namespace creg {
  */
 
 #define CR_RESERVED(Size) \
-	class_->AddMember ( "Reserved", new creg::EmptyType(Size), 0)
+	class_->AddMember("Reserved", new creg::EmptyType(Size), 0)
 
 /** @def CR_SETFLAG
  * Set a flag for a class/struct.
  * @param Flag the class flag @see ClassFlag
  */
 #define CR_SETFLAG(Flag) \
-	class_->SetFlag (creg::Flag)
+	class_->SetFlag(creg::Flag)
 
 /** @def CR_MEMBER_SETFLAG
  * Set a flag for a class/struct member
  * This should come after the CR_MEMBER or CR_ENUM_MEMBER for the member
  * @param Member the class member variable
  * @param Flag the class member flag @see ClassMemberFlag
- * @see ClassMemberFlag */
+ * @see ClassMemberFlag
+ */
 #define CR_MEMBER_SETFLAG(Member, Flag) \
-	class_->SetMemberFlag (#Member, creg::Flag)
+	class_->SetMemberFlag(#Member, creg::Flag)
 
 #define CR_MEMBER_BEGINFLAG(Flag) \
 	class_->BeginFlag(creg::Flag)
@@ -464,15 +494,18 @@ namespace creg {
  * On serialization, the registered members will be serialized first,
  * and then this function will be called if specified
  *
- * @param SerializeFunc the serialize method, should be a member function of the class
+ * @param SerializeFunc the serialize method, should be a member function of the
+ *   class
  */
 #define CR_SERIALIZER(SerializeFunc) \
 	(class_->serializeProc = (void(creg::_DummyStruct::*)(creg::ISerializer&))&Type::SerializeFunc)
 
 /** @def CR_POSTLOAD
  * Registers a custom post-loading method for the class/struct
- * this function will be called during package loading when all serialization is finished
- * There can only be one postload method per class/struct */
+ * this function will be called during package loading when all serialization is
+ * finished.
+ * There can only be one postload method per class/struct
+ */
 #define CR_POSTLOAD(PostLoadFunc) \
 	(class_->postLoadProc = (void(creg::_DummyStruct::*)())&Type::PostLoadFunc)
 };
