@@ -11,7 +11,7 @@
 #define GMLSRV_H
 
 #ifdef USE_GML
-
+#include "System/OffscreenGLContext.h"
 #include <boost/thread/thread.hpp>
 #include <boost/thread/barrier.hpp>
 #include <boost/bind.hpp>
@@ -22,6 +22,8 @@
 #	include "System/Platform/Win/win32.h"
 #endif
 
+extern COffscreenGLContext* ogc[GML_MAX_NUM_THREADS];
+
 EXTERN inline void gmlUpdateServers() {
 	gmlItemsConsumed=0;
 	gmlProgramServer.GenerateItems();
@@ -218,7 +220,7 @@ public:
 			int updsrv=0;
 			if(ex->maxthreads>1) {
 				while(ClientsReady<=gmlThreadCount+1) {
-					if((updsrv++%GML_UPDSRV_INTERVAL)==0 || *(volatile int *)&gmlItemsConsumed>=GML_UPDSRV_INTERVAL)
+					if(!gmlShareLists && ((updsrv++%GML_UPDSRV_INTERVAL)==0 || *(volatile int *)&gmlItemsConsumed>=GML_UPDSRV_INTERVAL))
 						gmlUpdateServers();
 					BOOL_ processed=FALSE;
 
@@ -353,11 +355,18 @@ public:
 	}
 
 	void gmlClient() {
-		set_threadnum(++threadcnt + 2);
+		long thr = ++threadcnt;
+		set_threadnum(thr + 2);
+		if (gmlShareLists) {
+			ogc[thr]->WorkerThreadPost();
+		}
 		streflop_init<streflop::Simple>();
 		while(dorun) {
 			gmlClientSub();
 		}
+		if (gmlShareLists) {
+			ogc[thr]->WorkerThreadFree();
+		}
 	}
 
 	void GetQueue() {
@@ -384,7 +393,7 @@ public:
 		if(!threads[GML_SIM_THREAD_NUM]->joinable())
 			return TRUE;
 		static int updsrvaux=0;
-		if((updsrvaux++%GML_UPDSRV_INTERVAL)==0 || *(volatile int *)&gmlItemsConsumed>=GML_UPDSRV_INTERVAL)
+		if(!gmlShareLists && ((updsrvaux++%GML_UPDSRV_INTERVAL)==0 || *(volatile int *)&gmlItemsConsumed>=GML_UPDSRV_INTERVAL))
 			gmlUpdateServers();
 
 		while(AuxClientsReady<=3) {
@@ -439,6 +448,7 @@ public:
 	}
 
 	void gmlClientAux() {
+		Threading::SetThreadName("sim");
 		Watchdog::RegisterThread(WDT_SIM, true);
 		set_threadnum(GML_SIM_THREAD_NUM);
 		streflop_init<streflop::Simple>();
