@@ -6,12 +6,10 @@
 
 
 #include <stdlib.h>
-
-// Spring
+//SPRING#include <math.h>
 #include "streflop_cond.h"
 #include "System/FastMath.h"
 
-
 #define lmathlib_c
 #define LUA_LIB
 
@@ -26,79 +24,79 @@
 
 
 static int math_abs (lua_State *L) {
-  lua_pushnumber(L, math::fabs(luaL_checknumber(L, 1)));
+  lua_pushnumber(L, math::fabs(luaL_checknumber_noassert(L, 1)));
   return 1;
 }
 
 static int math_sin (lua_State *L) {
-  lua_pushnumber(L, math::sin(luaL_checknumber(L, 1)));
+  lua_pushnumber(L, math::sin(luaL_checknumber_noassert(L, 1)));
   return 1;
 }
 
 static int math_sinh (lua_State *L) {
-  lua_pushnumber(L, math::sinh(luaL_checknumber(L, 1)));
+  lua_pushnumber(L, math::sinh(luaL_checknumber_noassert(L, 1)));
   return 1;
 }
 
 static int math_cos (lua_State *L) {
-  lua_pushnumber(L, math::cos(luaL_checknumber(L, 1)));
+  lua_pushnumber(L, math::cos(luaL_checknumber_noassert(L, 1)));
   return 1;
 }
 
 static int math_cosh (lua_State *L) {
-  lua_pushnumber(L, math::cosh(luaL_checknumber(L, 1)));
+  lua_pushnumber(L, math::cosh(luaL_checknumber_noassert(L, 1)));
   return 1;
 }
 
 static int math_tan (lua_State *L) {
-  lua_pushnumber(L, math::tan(luaL_checknumber(L, 1)));
+  lua_pushnumber(L, math::tan(luaL_checknumber_noassert(L, 1)));
   return 1;
 }
 
 static int math_tanh (lua_State *L) {
-  lua_pushnumber(L, math::tanh(luaL_checknumber(L, 1)));
+  lua_pushnumber(L, math::tanh(luaL_checknumber_noassert(L, 1)));
   return 1;
 }
 
 static int math_asin (lua_State *L) {
-  lua_pushnumber(L, math::asin(luaL_checknumber(L, 1)));
+  lua_pushnumber(L, math::asin(luaL_checknumber_noassert(L, 1)));
   return 1;
 }
 
 static int math_acos (lua_State *L) {
-  lua_pushnumber(L, math::acos(luaL_checknumber(L, 1)));
+  lua_pushnumber(L, math::acos(luaL_checknumber_noassert(L, 1)));
   return 1;
 }
 
 static int math_atan (lua_State *L) {
-  lua_pushnumber(L, math::atan(luaL_checknumber(L, 1)));
+  lua_pushnumber(L, math::atan(luaL_checknumber_noassert(L, 1)));
   return 1;
 }
 
 static int math_atan2 (lua_State *L) {
-  lua_pushnumber(L, math::atan2(luaL_checknumber(L, 1), luaL_checknumber(L, 2)));
+  lua_pushnumber(L, math::atan2(luaL_checknumber_noassert(L, 1), luaL_checknumber_noassert(L, 2)));
   return 1;
 }
 
 static int math_ceil (lua_State *L) {
-  lua_pushnumber(L, math::ceil(luaL_checknumber(L, 1)));
+  lua_pushnumber(L, math::ceil(luaL_checknumber_noassert(L, 1)));
   return 1;
 }
 
 static int math_floor (lua_State *L) {
-  lua_pushnumber(L, math::floor(luaL_checknumber(L, 1)));
+  lua_pushnumber(L, math::floor(luaL_checknumber_noassert(L, 1)));
   return 1;
 }
 
 static int math_fmod (lua_State *L) {
-  lua_pushnumber(L, math::fmod(luaL_checknumber(L, 1), luaL_checknumber(L, 2)));
+  lua_pushnumber(L, math::fmod(luaL_checknumber_noassert(L, 1), luaL_checknumber_noassert(L, 2)));
   return 1;
 }
 
 static int math_modf (lua_State *L) {
   // FIXME -- streflop does not have modf()
-  // double fp = math::modf(luaL_checknumber(L, 1), &ip);
-  const float in = (float)luaL_checknumber(L, 1);
+  // double fp = math::modf(luaL_checknumber_noassert(L, 1), &ip);
+  const float in = (float)luaL_checknumber_noassert(L, 1);
 
   if (math::isnan(in)) {
     lua_pushnumber(L, in);
@@ -118,49 +116,49 @@ static int math_modf (lua_State *L) {
 }
 
 static int math_sqrt (lua_State *L) {
-  lua_pushnumber(L, math::sqrt(luaL_checknumber(L, 1)));
+  lua_pushnumber(L, math::sqrt(luaL_checknumber_noassert(L, 1)));
   return 1;
 }
 
 static int math_pow (lua_State *L) {
-  lua_pushnumber(L, math::pow(luaL_checknumber(L, 1), luaL_checknumber(L, 2)));
+  lua_pushnumber(L, math::pow(luaL_checknumber_noassert(L, 1), luaL_checknumber_noassert(L, 2)));
   return 1;
 }
 
 static int math_log (lua_State *L) {
-  lua_pushnumber(L, math::log(luaL_checknumber(L, 1)));
+  lua_pushnumber(L, math::log(luaL_checknumber_noassert(L, 1)));
   return 1;
 }
 
 static int math_log10 (lua_State *L) {
-  lua_pushnumber(L, math::log10(luaL_checknumber(L, 1)));
+  lua_pushnumber(L, math::log10(luaL_checknumber_noassert(L, 1)));
   return 1;
 }
 
 static int math_exp (lua_State *L) {
-  lua_pushnumber(L, math::exp(luaL_checknumber(L, 1)));
+  lua_pushnumber(L, math::exp(luaL_checknumber_noassert(L, 1)));
   return 1;
 }
 
 static int math_deg (lua_State *L) {
-  lua_pushnumber(L, luaL_checknumber(L, 1)/RADIANS_PER_DEGREE);
+  lua_pushnumber(L, luaL_checknumber_noassert(L, 1)/RADIANS_PER_DEGREE);
   return 1;
 }
 
 static int math_rad (lua_State *L) {
-  lua_pushnumber(L, luaL_checknumber(L, 1)*RADIANS_PER_DEGREE);
+  lua_pushnumber(L, luaL_checknumber_noassert(L, 1)*RADIANS_PER_DEGREE);
   return 1;
 }
 
 static int math_frexp (lua_State *L) {
   int e;
-  lua_pushnumber(L, math::frexp(luaL_checknumber(L, 1), &e));
+  lua_pushnumber(L, math::frexp(luaL_checknumber_noassert(L, 1), &e));
   lua_pushinteger(L, e);
   return 2;
 }
 
 static int math_ldexp (lua_State *L) {
-  lua_pushnumber(L, math::ldexp(luaL_checknumber(L, 1), luaL_checkint(L, 2)));
+  lua_pushnumber(L, math::ldexp(luaL_checknumber_noassert(L, 1), luaL_checkint(L, 2)));
   return 1;
 }
 
@@ -168,10 +166,10 @@ static int math_ldexp (lua_State *L) {
 
 static int math_min (lua_State *L) {
   int n = lua_gettop(L);  /* number of arguments */
-  lua_Number dmin = luaL_checknumber(L, 1);
+  lua_Number dmin = luaL_checknumber_noassert(L, 1);
   int i;
   for (i=2; i<=n; i++) {
-    lua_Number d = luaL_checknumber(L, i);
+    lua_Number d = luaL_checknumber_noassert(L, i);
     if (d < dmin)
       dmin = d;
   }
@@ -182,10 +180,10 @@ static int math_min (lua_State *L) {
 
 static int math_max (lua_State *L) {
   int n = lua_gettop(L);  /* number of arguments */
-  lua_Number dmax = luaL_checknumber(L, 1);
+  lua_Number dmax = luaL_checknumber_noassert(L, 1);
   int i;
   for (i=2; i<=n; i++) {
-    lua_Number d = luaL_checknumber(L, i);
+    lua_Number d = luaL_checknumber_noassert(L, i);
     if (d > dmax)
       dmax = d;
   }
@@ -193,16 +191,15 @@ static int math_max (lua_State *L) {
   return 1;
 }
 
-
 static int lua_streflop_random_seed = 0;
 
 static int math_random (lua_State *L) {
   /* the `%' avoids the (rare) case of r==1, and is needed also because on
      some systems (SunOS!) `rand()' may return a value larger than RAND_MAX */
 
-  // SPRING
-  // respect the original lua code that uses rand,
-  // and rand is auto-seeded always with the same value
+//SPRING
+// respect the original lua code that uses rand,
+// and rand is auto-seeded always with the same value
 #ifdef STREFLOP_H
   if (lua_streflop_random_seed == 0) {
     lua_streflop_random_seed = 1;
@@ -213,7 +210,6 @@ static int math_random (lua_State *L) {
 #else
   lua_Number r = 0.0f;
 #endif
-
   switch (lua_gettop(L)) {  /* check number of arguments */
     case 0: {  /* no arguments */
       lua_pushnumber(L, r);  /* Number between 0 and 1 */
@@ -222,7 +218,7 @@ static int math_random (lua_State *L) {
     case 1: {  /* only upper limit */
       int u = luaL_checkint(L, 1);
       luaL_argcheck(L, 1<=u, 1, "interval is empty");
-      lua_pushnumber(L,math:: floor(r*u)+1);  /* int between 1 and `u' */
+      lua_pushnumber(L, math::floor(r*u)+1);  /* int between 1 and `u' */
       break;
     }
     case 2: {  /* lower and upper limits */
@@ -237,10 +233,8 @@ static int math_random (lua_State *L) {
   return 1;
 }
 
-
 static int math_randomseed (lua_State *L) {
-  /* SPRING srand(luaL_checkint(L, 1)); */
-
+//SPRING srand(luaL_checkint(L, 1));
 #ifdef STREFLOP_H
   math::RandomInit(luaL_checkint(L, 1)); // streflop
 #endif
@@ -250,34 +244,34 @@ static int math_randomseed (lua_State *L) {
 
 
 static const luaL_Reg mathlib[] = {
-  {"abs",   math_abs   },
-  {"acos",  math_acos  },
-  {"asin",  math_asin  },
-  {"atan2", math_atan2 },
-  {"atan",  math_atan  },
-  {"ceil",  math_ceil  },
-  {"cosh",  math_cosh  },
-  {"cos",   math_cos   },
-  {"deg",   math_deg   },
-  {"exp",   math_exp   },
-  {"floor", math_floor },
-  {"fmod",  math_fmod  },
-  {"frexp", math_frexp },
-  {"ldexp", math_ldexp },
-  {"log10", math_log10 },
-  {"log",   math_log   },
-  {"max",   math_max   },
-  {"min",   math_min   },
-  {"modf",  math_modf  },
-  {"pow",   math_pow   },
-  {"rad",   math_rad   },
-  {"random",     math_random },
-  {"randomseed", math_randomseed },
-  {"sinh",  math_sinh  },
-  {"sin",   math_sin   },
-  {"sqrt",  math_sqrt  },
-  {"tanh",  math_tanh  },
-  {"tan",   math_tan   },
+  {"abs",   math_abs},
+  {"acos",  math_acos},
+  {"asin",  math_asin},
+  {"atan2", math_atan2},
+  {"atan",  math_atan},
+  {"ceil",  math_ceil},
+  {"cosh",   math_cosh},
+  {"cos",   math_cos},
+  {"deg",   math_deg},
+  {"exp",   math_exp},
+  {"floor", math_floor},
+  {"fmod",   math_fmod},
+  {"frexp", math_frexp},
+  {"ldexp", math_ldexp},
+  {"log10", math_log10},
+  {"log",   math_log},
+  {"max",   math_max},
+  {"min",   math_min},
+  {"modf",   math_modf},
+  {"pow",   math_pow},
+  {"rad",   math_rad},
+  {"random",     math_random},
+  {"randomseed", math_randomseed},
+  {"sinh",   math_sinh},
+  {"sin",   math_sin},
+  {"sqrt",  math_sqrt},
+  {"tanh",   math_tanh},
+  {"tan",   math_tan},
   {NULL, NULL}
 };
 
@@ -289,13 +283,11 @@ LUALIB_API int luaopen_math (lua_State *L) {
   luaL_register(L, LUA_MATHLIBNAME, mathlib);
   lua_pushnumber(L, PI);
   lua_setfield(L, -2, "pi");
-
 #ifdef STREFLOP_H
   lua_pushnumber(L, math::SimplePositiveInfinity); // streflop
 #else
   lua_pushnumber(L, HUGE_VAL);
 #endif
-
   lua_setfield(L, -2, "huge");
 #if defined(LUA_COMPAT_MOD)
   lua_getfield(L, -1, "fmod");
