@@ -50,32 +50,36 @@ static bool TestLuaParser();
 
 static void PrintMapInfo(const string& mapName)
 {
-  printf("  MAP INFO  (for %s)\n", mapName.c_str());
-  MapInfo mi;
-  char auth[256];
-  char desc[256];
-  mi.author = auth;
-  mi.author[0] = 0;
-  mi.description = desc;
-  mi.description[0] = 0;
-  if (!GetMapInfoEx(mapName.c_str(), &mi, 1)) {
-    printf("ERROR getting info for map %s  (%s)\n",
-    mapName.c_str(), mi.description);
-  }
-  else {
-    printf("    author:    '%s'\n", mi.author);
-    printf("    desc:      '%s'\n", mi.description);
-    printf("    gravity:   %i\n",   mi.gravity);
-    printf("    tidal:     %i\n",   mi.tidalStrength);
-    printf("    maxMetal:  %f\n",   mi.maxMetal);
-    printf("    mexRad:    %i\n",   mi.extractorRadius);
-    printf("    minWind:   %i\n",   mi.minWind);
-    printf("    maxWind:   %i\n",   mi.maxWind);
-    printf("    width:     %i\n",   mi.width);
-    printf("    height:    %i\n",   mi.height);
-    for (int p = 0; p < mi.posCount; p++) {
-      const StartPos& sp = mi.positions[p];
-      printf("    pos %i:     <%5i, %5i>\n", p, sp.x, sp.z);
+    const int map_count = GetMapCount();
+    int mapidx = -1;
+    for (int i = 0; i < map_count; i++){
+      if (GetMapName(i) == mapName) {
+        mapidx = i;
+      }
+    }
+    if (mapidx<0) {
+      printf("Error: Map not found\n");
+      return;
+    }
+    printf("    author:    '%s'\n", GetMapAuthor(mapidx));
+    printf("    desc:      '%s'\n", GetMapDescription(mapidx));
+    printf("    gravity:   %i\n",   GetMapGravity(mapidx));
+    printf("    tidal:     %i\n",   GetMapTidalStrength(mapidx));
+    const int rescount = GetMapResourceCount(mapidx);
+    for (int i = 0; i < rescount; i++) {
+      const char* resName = GetMapResourceName(mapidx, i);
+      printf("    max%s:  %f\n", resName, GetMapResourceMax(mapidx, i));
+      printf("    mex%sRad:    %i\n", resName, GetMapResourceExtractorRadius(mapidx, i));
+    }
+    printf("    minWind:   %i\n",   GetMapWindMin(mapidx));
+    printf("    maxWind:   %i\n",   GetMapWindMax(mapidx));
+    printf("    width:     %i\n",   GetMapWidth(mapidx));
+    printf("    height:    %i\n",   GetMapHeight(mapidx));
+    const int poscount = GetMapPosCount(mapidx);
+    for (int p = 0; p < poscount; p++) {
+      const int x = GetMapPosX(mapidx, p);
+      const int z = GetMapPosZ(mapidx, p);
+      printf("    pos %i:     <%5i, %5i>\n", p, x, z);
     }
 
     const char* infomaps[] = { "height", "grass", "metal", "type", NULL };
@@ -95,7 +99,6 @@ static void PrintMapInfo(const string& mapName)
         free(data);*/
       }
     }
-  }
 }
 
 
@@ -144,17 +147,22 @@ int main(int argc, char** argv)
   }
 
   // mod names
-  printf("  MODS\n");
+  printf("  GAMES\n");
   const int modCount = GetPrimaryModCount();
   for (int i = 0; i < modCount; i++) {
-    const string modName      = GetPrimaryModName(i);
-    const string modShortName = GetPrimaryModShortName(i);
-    const string modVersion   = GetPrimaryModVersion(i);
-    const string modMutator   = GetPrimaryModMutator(i);
     const string modArchive = GetPrimaryModArchive(i);
-    printf("    [mod %3i]   %-32s  <%s> %s %s %s\n", i,
-           modName.c_str(), modArchive.c_str(),
-           modShortName.c_str(), modVersion.c_str(), modMutator.c_str());
+    const int infoCount = GetPrimaryModInfoCount(i);
+    for (int j=0; j < infoCount; j++) {
+      const char* key = GetInfoKey(j);
+      string skey="";
+      string svalue="";
+      if (key!=NULL)
+        skey=key;
+      const char* value = GetInfoValueString(j);
+      if (value!=NULL)
+        svalue=value;
+      printf("    [%s]: %s = %s\n", modArchive.c_str(), skey.c_str(), svalue.c_str());
+    }
   }
 
   // load the mod archives
@@ -162,8 +170,7 @@ int main(int argc, char** argv)
 
   // unit names
   while (true) {
-  //const int left = ProcessUnits();
-    const int left = ProcessUnitsNoChecksum();
+    const int left = ProcessUnits();
   //printf("unitsLeft = %i\n", left);
     if (left <= 0) {
       break;
@@ -195,8 +202,8 @@ int main(int argc, char** argv)
     for (int j = 0; j < skirmishAIInfoCount; j++) {
       const string key = GetInfoKey(j);
       if ((key == SKIRMISH_AI_PROPERTY_SHORT_NAME) || (key == SKIRMISH_AI_PROPERTY_VERSION)) {
-        const string value = GetInfoValue(j);
-      	printf("        %s = %s\n", key.c_str(), value.c_str());
+        const string value = GetInfoValueString(j);
+        printf("        %s = %s\n", key.c_str(), value.c_str());
       }
     }
   }
